<?php 
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 */ 

function optionsframework_option_name() {
	// Change this to use your theme slug
	$themename = wp_get_theme();
	$themename = preg_replace("/\W/", "_", strtolower($themename) );
	return $themename;
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 *
 * If you are making your theme translatable, you should replace 'creator-world-pro'
 * with the actual text domain for your theme.  Read more:
 * http://codex.wordpress.org/Function_Reference/load_theme_textdomain
*/

function optionsframework_options() {
	//array of all custom font types.
	$font_types = array( '' => '',
    'ABeeZee' => 'ABeeZee',
    'Abel' => 'Abel',
    'Abril Fatface' => 'Abril Fatface',
    'Aclonica' => 'Aclonica',
    'Acme' => 'Acme',
    'Actor' => 'Actor',
    'Adamina' => 'Adamina',
    'Advent Pro' => 'Advent Pro',
    'Aguafina Script' => 'Aguafina Script',
    'Akronim' => 'Akronim',
    'Aladin' => 'Aladin',
    'Aldrich' => 'Aldrich',
    'Alegreya' => 'Alegreya',
    'Alegreya Sans SC' => 'Alegreya Sans SC',
    'Alegreya SC' => 'Alegreya SC',
    'Alex Brush' => 'Alex Brush',
    'Alef' => 'Alef',
    'Alfa Slab One' => 'Alfa Slab One',
    'Alice' => 'Alice',
    'Alike' => 'Alike',
    'Alike Angular' => 'Alike Angular',
    'Allan' => 'Allan',
    'Allerta' => 'Allerta',
    'Allerta Stencil' => 'Allerta Stencil',
    'Allura' => 'Allura',
    'Almendra' => 'Almendra',
    'Almendra Display' => 'Almendra Display',
    'Almendra SC' => 'Almendra SC',
    'Amiri' => 'Amiri',
    'Amarante' => 'Amarante',
    'Amaranth' => 'Amaranth',
    'Amatic SC' => 'Amatic SC',
    'Amethysta' => 'Amethysta',
    'Amita' => 'Amita',
    'Anaheim' => 'Anaheim',
    'Andada' => 'Andada',
    'Andika' => 'Andika',
    'Annie Use Your Telescope' => 'Annie Use Your Telescope',
    'Anonymous Pro' => 'Anonymous Pro',
    'Antic' => 'Antic',
    'Antic Didone' => 'Antic Didone',
    'Antic Slab' => 'Antic Slab',
    'Anton' => 'Anton',
    'Angkor' => 'Angkor',
    'Arapey' => 'Arapey',
    'Arbutus' => 'Arbutus',
    'Arbutus Slab' => 'Arbutus Slab',
    'Architects Daughter' => 'Architects Daughter',
    'Archivo White' => 'Archivo White',
    'Archivo Narrow' => 'Archivo Narrow',
    'Arial' => 'Arial',
    'Arimo' => 'Arimo',
    'Arya' => 'Arya',
    'Arizonia' => 'Arizonia',
    'Armata' => 'Armata',
    'Artifika' => 'Artifika',
    'Arvo' => 'Arvo',
    'Asar' => 'Asar',
    'Asap' => 'Asap',
    'Asset' => 'Asset',
    'Astloch' => 'Astloch',
    'Asul' => 'Asul',
    'Atomic Age' => 'Atomic Age',
    'Aubrey' => 'Aubrey',
    'Audiowide' => 'Audiowide',
    'Autour One' => 'Autour One',
    'Average' => 'Average',
    'Average Sans' => 'Average Sans',
    'Averia Gruesa Libre' => 'Averia Gruesa Libre',
    'Averia Libre' => 'Averia Libre',
    'Averia Sans Libre' => 'Averia Sans Libre',
    'Averia Serif Libre' => 'Averia Serif Libre',
    'Battambang' => 'Battambang',
    'Bad Script' => 'Bad Script',
    'Bayon' => 'Bayon',
    'Balthazar' => 'Balthazar',
    'Bangers' => 'Bangers',
    'Basic' => 'Basic',
    'Baumans' => 'Baumans',
    'Belgrano' => 'Belgrano',
    'Belleza' => 'Belleza',
    'BenchNine' => 'BenchNine',
    'Bentham' => 'Bentham',
    'Berkshire Swash' => 'Berkshire Swash',
    'Bevan' => 'Bevan',
    'Bigelow Rules' => 'Bigelow Rules',
    'Bigshot One' => 'Bigshot One',
    'Bilbo' => 'Bilbo',
    'Bilbo Swash Caps' => 'Bilbo Swash Caps',
    'Biryani' => 'Biryani',
    'Bitter' => 'Bitter',
    'White Ops One' => 'White Ops One',
    'Bokor' => 'Bokor',
    'Bonbon' => 'Bonbon',
    'Boogaloo' => 'Boogaloo',
    'Bowlby One' => 'Bowlby One',
    'Bowlby One SC' => 'Bowlby One SC',
    'Brawler' => 'Brawler',
    'Bree Serif' => 'Bree Serif',
    'Bubblegum Sans' => 'Bubblegum Sans',
    'Bubbler One' => 'Bubbler One',
    'Buda' => 'Buda',
    'Buenard' => 'Buenard',
    'Butcherman' => 'Butcherman',
    'Butcherman Caps' => 'Butcherman Caps',
    'Butterfly Kids' => 'Butterfly Kids',
    'Cabin' => 'Cabin',
    'Cabin Condensed' => 'Cabin Condensed',
    'Cabin Sketch' => 'Cabin Sketch',
    'Cabin' => 'Cabin',
    'Caesar Dressing' => 'Caesar Dressing',
    'Cagliostro' => 'Cagliostro',
    'Calligraffitti' => 'Calligraffitti',
    'Cambay' => 'Cambay',
    'Cambo' => 'Cambo',
    'Candal' => 'Candal',
    'Cantarell' => 'Cantarell',
    'Cantata One' => 'Cantata One',
    'Cantora One' => 'Cantora One',
    'Capriola' => 'Capriola',
    'Cardo' => 'Cardo',
    'Carme' => 'Carme',
    'Carrois Gothic' => 'Carrois Gothic',
    'Carrois Gothic SC' => 'Carrois Gothic SC',
    'Carter One' => 'Carter One',
    'Caveat' => 'Caveat',
    'Caveat Brush' => 'Caveat Brush',
    'Catamaran' => 'Catamaran',
    'Caudex' => 'Caudex',
    'Cedarville Cursive' => 'Cedarville Cursive',
    'Ceviche One' => 'Ceviche One',
    'Changa One' => 'Changa One',
    'Chango' => 'Chango',
    'Chau Philomene One' => 'Chau Philomene One',
    'Chenla' => 'Chenla',
    'Chela One' => 'Chela One',
    'Chelsea Market' => 'Chelsea Market',
    'Cherry Cream Soda' => 'Cherry Cream Soda',
    'Cherry Swash' => 'Cherry Swash',
    'Chewy' => 'Chewy',
    'Chicle' => 'Chicle',
    'Chivo' => 'Chivo',
    'Chonburi' => 'Chonburi',
    'Cinzel' => 'Cinzel',
    'Cinzel Decorative' => 'Cinzel Decorative',
    'Clicker Script' => 'Clicker Script',
    'Coda' => 'Coda',
    'Codystar' => 'Codystar',
    'Combo' => 'Combo',
    'Comfortaa' => 'Comfortaa',
    'Coming Soon' => 'Coming Soon',
    'Condiment' => 'Condiment',
    'Content' => 'Content',
    'Contrail One' => 'Contrail One',
    'Convergence' => 'Convergence',
    'Cookie' => 'Cookie',
    'Comic Sans MS' => 'Comic Sans MS',
    'Copse' => 'Copse',
    'Corben' => 'Corben',
    'Courgette' => 'Courgette',
    'Cousine' => 'Cousine',
    'Coustard' => 'Coustard',
    'Covered By Your Grace' => 'Covered By Your Grace',
    'Crafty Girls' => 'Crafty Girls',
    'Creepster' => 'Creepster',
    'Creepster Caps' => 'Creepster Caps',
    'Crete Round' => 'Crete Round',
    'Crimson' => 'Crimson',
    'Croissant One' => 'Croissant One',
    'Crushed' => 'Crushed',
    'Cuprum' => 'Cuprum',
    'Cutive' => 'Cutive',
    'Cutive Mono' => 'Cutive Mono',
    'Damion' => 'Damion',
    'Dangrek' => 'Dangrek',
    'Dancing Script' => 'Dancing Script',
    'Dawning of a New Day' => 'Dawning of a New Day',
    'Days One' => 'Days One',
    'Dekko' => 'Dekko',
    'Delius' => 'Delius',
    'Delius Swash Caps' => 'Delius Swash Caps',
    'Delius Unicase' => 'Delius Unicase',
    'Della Respira' => 'Della Respira',
    'Denk One' => 'Denk One',
    'Devonshire' => 'Devonshire',
    'Dhurjati' => 'Dhurjati',
    'Didact Gothic' => 'Didact Gothic',
    'Diplomata' => 'Diplomata',
    'Diplomata SC' => 'Diplomata SC',
    'Domine' => 'Domine',
    'Donegal One' => 'Donegal One',
    'Doppio One' => 'Doppio One',
    'Dorsa' => 'Dorsa',
    'Dosis' => 'Dosis',
    'Dr Sugiyama' => 'Dr Sugiyama',
    'Droid Sans' => 'Droid Sans',
    'Droid Sans Mono' => 'Droid Sans Mono',
    'Droid Serif' => 'Droid Serif',
    'Duru Sans' => 'Duru Sans',
    'Dynalight' => 'Dynalight',
    'EB Garamond' => 'EB Garamond',
    'Eczar' => 'Eczar',
    'Eagle Lake' => 'Eagle Lake',
    'Eater' => 'Eater',
    'Eater Caps' => 'Eater Caps',
    'Economica' => 'Economica',
    'Ek Mukta' => 'Ek Mukta',
    'Electrolize' => 'Electrolize',
    'Elsie' => 'Elsie',
    'Elsie Swash Caps' => 'Elsie Swash Caps',
    'Emblema One' => 'Emblema One',
    'Emilys Candy' => 'Emilys Candy',
    'Engagement' => 'Engagement',
    'Englebert' => 'Englebert',
    'Enriqueta' => 'Enriqueta',
    'Erica One' => 'Erica One',
    'Esteban' => 'Esteban',
    'Euphoria Script' => 'Euphoria Script',
    'Ewert' => 'Ewert',
    'Exo' => 'Exo',
    'Exo 2' => 'Exo 2',
    'Expletus Sans' => 'Expletus Sans',
    'Fanwood Text' => 'Fanwood Text',
    'Fascinate' => 'Fascinate',
    'Fascinate Inline' => 'Fascinate Inline',
    'Fasthand' => 'Fasthand',
    'Faster One' => 'Faster One',
    'Federant' => 'Federant',
    'Federo' => 'Federo',
    'Felipa' => 'Felipa',
    'Fenix' => 'Fenix',
    'Finger Paint' => 'Finger Paint',
    'Fira Mono' => 'Fira Mono',
    'Fira Sans' => 'Fira Sans',
    'Fjalla One' => 'Fjalla One',
    'Fjord One' => 'Fjord One',
    'Flamenco' => 'Flamenco',
    'Flavors' => 'Flavors',
    'Fondamento' => 'Fondamento',
    'Fontdiner Swanky' => 'Fontdiner Swanky',
    'Forum' => 'Forum',
    'Francois One' => 'Francois One',
    'FreeSans' => 'FreeSans',

    'Freckle Face' => 'Freckle Face',
    'Fredericka the Great' => 'Fredericka the Great',
    'Fredoka One' => 'Fredoka One',
    'Fresca' => 'Fresca',
    'Freehand' => 'Freehand',
    'Frijole' => 'Frijole',
    'Fruktur' => 'Fruktur',
    'Fugaz One' => 'Fugaz One',
    'Gafata' => 'Gafata',
    'Galdeano' => 'Galdeano',
    'Galindo' => 'Galindo',
    'Gentium Basic' => 'Gentium Basic',
    'Gentium Book Basic' => 'Gentium Book Basic',
    'Geo' => 'Geo',
    'Georgia' => 'Georgia',
    'Geostar' => 'Geostar',
    'Geostar Fill' => 'Geostar Fill',
    'Germania One' => 'Germania One',
    'Gilda Display' => 'Gilda Display',
    'Give You Glory' => 'Give You Glory',
    'Glass Antiqua' => 'Glass Antiqua',
    'Glegoo' => 'Glegoo',
    'Gloria Hallelujah' => 'Gloria Hallelujah',
    'Goblin One' => 'Goblin One',
    'Gochi Hand' => 'Gochi Hand',
    'Gorditas' => 'Gorditas',
    'Gurajada' => 'Gurajada',
    'Goudy Bookletter 1911' => 'Goudy Bookletter 1911',
    'Graduate' => 'Graduate',
    'Grand Hotel' => 'Grand Hotel',
    'Gravitas One' => 'Gravitas One',
    'Great Vibes' => 'Great Vibes',
    'Griffy' => 'Griffy',
    'Gruppo' => 'Gruppo',
    'Gudea' => 'Gudea',
    'Gidugu' => 'Gidugu',
    'GFS Didot' => 'GFS Didot',
    'GFS Neohellenic' => 'GFS Neohellenic',
    'Habibi' => 'Habibi',
    'Hammersmith One' => 'Hammersmith One',
    'Halant' => 'Halant',
    'Hanalei' => 'Hanalei',
    'Hanalei Fill' => 'Hanalei Fill',
    'Handlee' => 'Handlee',
    'Hanuman' => 'Hanuman',
    'Happy Monkey' => 'Happy Monkey',
    'Headland One' => 'Headland One',
    'Henny Penny' => 'Henny Penny',
    'Herr Von Muellerhoff' => 'Herr Von Muellerhoff',
    'Hind' => 'Hind',
    'Hind Siliguri' => 'Hind Siliguri',
    'Hind Vadodara' => 'Hind Vadodara',
    'Holtwood One SC' => 'Holtwood One SC',
    'Homemade Apple' => 'Homemade Apple',
    'Homenaje' => 'Homenaje',
    'IM Fell' => 'IM Fell',
    'Itim' => 'Itim',
    'Iceberg' => 'Iceberg',
    'Iceland' => 'Iceland',
    'Imprima' => 'Imprima',
    'Inconsolata' => 'Inconsolata',
    'Inder' => 'Inder',
    'Indie Flower' => 'Indie Flower',
    'Inknut Antiqua' => 'Inknut Antiqua',
    'Inika' => 'Inika',
    'Irish Growler' => 'Irish Growler',
    'Istok Web' => 'Istok Web',
    'Italiana' => 'Italiana',
    'Italianno' => 'Italianno',
    'Jacques Francois' => 'Jacques Francois',
    'Jacques Francois Shadow' => 'Jacques Francois Shadow',
    'Jim Nightshade' => 'Jim Nightshade',
    'Jockey One' => 'Jockey One',
    'Jaldi' => 'Jaldi',
    'Jolly Lodger' => 'Jolly Lodger',
    'Josefin Sans' => 'Josefin Sans',
    'Josefin Sans' => 'Josefin Sans',
    'Josefin Slab' => 'Josefin Slab',
    'Joti One' => 'Joti One',
    'Judson' => 'Judson',
    'Julee' => 'Julee',
    'Julius Sans One' => 'Julius Sans One',
    'Junge' => 'Junge',
    'Jura' => 'Jura',
    'Just Another Hand' => 'Just Another Hand',
    'Just Me Again Down Here' => 'Just Me Again Down Here',
    'Kadwa' => 'Kadwa',
    'Kdam Thmor' => 'Kdam Thmor',
    'Kalam' => 'Kalam', 
    'Kameron' => 'Kameron',
    'Kantumruy' => 'Kantumruy',
    'Karma' => 'Karma',
    'Karla' => 'Karla',
    'Kaushan Script' => 'Kaushan Script',
    'Kavoon' => 'Kavoon',
    'Keania One' => 'Keania One',
    'Kelly Slab' => 'Kelly Slab',
    'Kenia' => 'Kenia',
    'Khand' => 'Khand',
    'Khmer' => 'Khmer',
    'Khula' => 'Khula',
    'Kite One' => 'Kite One',
    'Knewave' => 'Knewave',
    'Kotta One' => 'Kotta One',
    'Kranky' => 'Kranky',
    'Kreon' => 'Kreon',
    'Kristi' => 'Kristi',
    'Koulen' => 'Koulen',
    'Krona One' => 'Krona One',
    'Kurale' => 'Kurale',
    'Lakki Reddy' => 'Lakki Reddy',
    'La Belle Aurore' => 'La Belle Aurore',
    'Lancelot' => 'Lancelot',
    'Laila' => 'Laila',
    'Lato' => 'Lato',
    'Lateef' => 'Lateef',
    'League Script' => 'League Script',
    'Leckerli One' => 'Leckerli One',
    'Ledger' => 'Ledger',
    'Lekton' => 'Lekton',
    'Lemon' => 'Lemon',

    'Libre Baskerville' => 'Libre Baskerville',
    'Life Savers' => 'Life Savers',
    'Lilita One' => 'Lilita One',
    'Limelight' => 'Limelight',
    'Linden Hill' => 'Linden Hill',
    'Lobster' => 'Lobster',
    'Lobster Two' => 'Lobster Two',
    'Londrina Outline' => 'Londrina Outline',
    'Londrina Shadow' => 'Londrina Shadow',
    'Londrina Sketch' => 'Londrina Sketch',
    'Londrina Solid' => 'Londrina Solid',
    'Lora' => 'Lora',
    'Love Ya Like A Sister' => 'Love Ya Like A Sister',
    'Loved by the King' => 'Loved by the King',
    'Lovers Quarrel' => 'Lovers Quarrel',
    'Lucida Sans Unicode' => 'Lucida Sans Unicode',
    'Luckiest Guy' => 'Luckiest Guy',
    'Lusitana' => 'Lusitana',
    'Lustria' => 'Lustria',
    'Macondo' => 'Macondo',
    'Macondo Swash Caps' => 'Macondo Swash Caps',
    'Magra' => 'Magra',
    'Maiden Orange' => 'Maiden Orange',
    'Mallanna' => 'Mallanna',
    'Mandali' => 'Mandali',
    'Mako' => 'Mako',
    'Marcellus' => 'Marcellus',
    'Marcellus SC' => 'Marcellus SC',
    'Marck Script' => 'Marck Script',
    'Margarine' => 'Margarine',
    'Marko One' => 'Marko One',
    'Marmelad' => 'Marmelad',
    'Marvel' => 'Marvel',
    'Martel' => 'Martel',
    'Martel Sans' => 'Martel Sans',
    'Mate' => 'Mate',
    'Mate SC' => 'Mate SC',
    'Maven Pro' => 'Maven Pro',
    'McLaren' => 'McLaren',
    'Meddon' => 'Meddon',
    'MedievalSharp' => 'MedievalSharp',
    'Medula One' => 'Medula One',
    'Megrim' => 'Megrim',
    'Meie Script' => 'Meie Script',
    'Merienda' => 'Merienda',
    'Merienda One' => 'Merienda One',
    'Merriweather' => 'Merriweather',
    'Metal' => 'Metal',
    'Metal Mania' => 'Metal Mania',
    'Metamorphous' => 'Metamorphous',
    'Metrophobic' => 'Metrophobic',
    'Michroma' => 'Michroma',
    'Milonga' => 'Milonga',
    'Miltonian' => 'Miltonian',
    'Miltonian Tattoo' => 'Miltonian Tattoo',
    'Miniver' => 'Miniver',
    'Miss Fajardose' => 'Miss Fajardose',
    'Miss Saint Delafield' => 'Miss Saint Delafield',
    'Modak' => 'Modak',
    'Modern Antiqua' => 'Modern Antiqua',
    'Molengo' => 'Molengo',
    'Molle' => 'Molle',
    'Moulpali' => 'Moulpali',
    'Monda' => 'Monda',
    'Monofett' => 'Monofett',
    'Monoton' => 'Monoton',
    'Monsieur La Doulaise' => 'Monsieur La Doulaise',
    'Montaga' => 'Montaga',
    'Montez' => 'Montez',
    'Montserrat' => 'Montserrat',
    'Montserrat Alternates' => 'Montserrat Alternates',
    'Montserrat Subrayada' => 'Montserrat Subrayada',
    'Mountains of Christmas' => 'Mountains of Christmas',
    'Mouse Memoirs' => 'Mouse Memoirs',
    'Moul' => 'Moul',
    'Mr Bedford' => 'Mr Bedford',
    'Mr Bedfort' => 'Mr Bedfort',
    'Mr Dafoe' => 'Mr Dafoe',
    'Mr De Haviland' => 'Mr De Haviland',
    'Mrs Saint Delafield' => 'Mrs Saint Delafield',
    'Mrs Sheppards' => 'Mrs Sheppards',
    'Muli' => 'Muli',
    'Mystery Quest' => 'Mystery Quest',
    'Neucha' => 'Neucha',
    'Neuton' => 'Neuton',
    'New Rocker' => 'New Rocker',
    'News Cycle' => 'News Cycle',
    'Niconne' => 'Niconne',
    'Nixie One' => 'Nixie One',
    'Nobile' => 'Nobile',
    'Nokora' => 'Nokora',
    'Norican' => 'Norican',
    'Nosifer' => 'Nosifer',
    'Nosifer Caps' => 'Nosifer Caps',
    'Nova Mono' => 'Nova Mono',
    'Noticia Text' => 'Noticia Text',
    'Noto Sans' => 'Noto Sans',
    'Noto Serif' => 'Noto Serif',
    'Nova Round' => 'Nova Round',
    'Numans' => 'Numans',
    'Nunito' => 'Nunito',
    'NTR' => 'NTR',
    'Offside' => 'Offside',
    'Oldenburg' => 'Oldenburg',
    'Oleo Script' => 'Oleo Script',
    'Oleo Script Swash Caps' => 'Oleo Script Swash Caps',
    'Open Sans' => 'Open Sans',
    'Open Sans Condensed' => 'Open Sans Condensed',
    'Oranienbaum' => 'Oranienbaum',
    'Orbitron' => 'Orbitron',
    'Odor Mean Chey' => 'Odor Mean Chey',
    'Oregano' => 'Oregano',
    'Orienta' => 'Orienta',
    'Original Surfer' => 'Original Surfer',
    'Oswald' => 'Oswald',
    'Over the Rainbow' => 'Over the Rainbow',
    'Overlock' => 'Overlock',
    'Overlock SC' => 'Overlock SC',
    'Ovo' => 'Ovo',
    'Oxygen' => 'Oxygen',
    'Oxygen Mono' => 'Oxygen Mono',
    'Palanquin Dark' => 'Palanquin Dark',
    'Peddana' => 'Peddana',
    'Poppins' => 'Poppins',
    'PT Mono' => 'PT Mono',
    'PT Sans' => 'PT Sans',
    'PT Sans Caption' => 'PT Sans Caption',
    'PT Sans Narrow' => 'PT Sans Narrow',
    'PT Serif' => 'PT Serif',
    'PT Serif Caption' => 'PT Serif Caption',
    'Pacifico' => 'Pacifico',
    'Paprika' => 'Paprika',
    'Parisienne' => 'Parisienne',
    'Passero One' => 'Passero One',
    'Passion One' => 'Passion One',
    'Patrick Hand' => 'Patrick Hand',
    'Patrick Hand SC' => 'Patrick Hand SC',
    'Patua One' => 'Patua One',
    'Paytone One' => 'Paytone One',
    'Peralta' => 'Peralta',
    'Permanent Marker' => 'Permanent Marker',
    'Petit Formal Script' => 'Petit Formal Script',
    'Petrona' => 'Petrona',
    'Philosopher' => 'Philosopher',
    'Piedra' => 'Piedra',
    'Pinyon Script' => 'Pinyon Script',
    'Pirata One' => 'Pirata One',
    'Plaster' => 'Plaster',
    'Palatino Linotype' => 'Palatino Linotype',
    'Play' => 'Play',
    'Playball' => 'Playball',
    'Playfair Display' => 'Playfair Display',
    'Playfair Display SC' => 'Playfair Display SC',
    'Podkova' => 'Podkova',
    'Poiret One' => 'Poiret One',
    'Poller One' => 'Poller One',
    'Poly' => 'Poly',
    'Pompiere' => 'Pompiere',
    'Pontano Sans' => 'Pontano Sans',
    'Port Lligat Sans' => 'Port Lligat Sans',
    'Port Lligat Slab' => 'Port Lligat Slab',
    'Prata' => 'Prata',
    'Pragati Narrow' => 'Pragati Narrow',
    'Preahvihear' => 'Preahvihear',
    'Press Start 2P' => 'Press Start 2P',
    'Princess Sofia' => 'Princess Sofia',
    'Prociono' => 'Prociono',
    'Prosto One' => 'Prosto One',
    'Puritan' => 'Puritan',
    'Purple Purse' => 'Purple Purse',
    'Quando' => 'Quando',
    'Quantico' => 'Quantico',
    'Quattrocento' => 'Quattrocento',
    'Quattrocento Sans' => 'Quattrocento Sans',
    'Questrial' => 'Questrial',
    'Quicksand' => 'Quicksand',
    'Quintessential' => 'Quintessential',
    'Qwigley' => 'Qwigley',
    'Racing Sans One' => 'Racing Sans One',
    'Radley' => 'Radley',
    'Rajdhani' => 'Rajdhani',
    'Raleway Dots' => 'Raleway Dots',
    'Raleway' => 'Raleway',
    'Rambla' => 'Rambla',
    'Ramabhadra' => 'Ramabhadra',
    'Ramaraja' => 'Ramaraja',
    'Rammetto One' => 'Rammetto One',
    'Ranchers' => 'Ranchers',
    'Rancho' => 'Rancho',
    'Ranga' => 'Ranga',
    'Ravi Prakash' => 'Ravi Prakash',
    'Rationale' => 'Rationale',
    'Redressed' => 'Redressed',
    'Reenie Beanie' => 'Reenie Beanie',
    'Revalia' => 'Revalia',
    'Rhodium Libre' => 'Rhodium Libre',
    'Ribeye' => 'Ribeye',
    'Ribeye Marrow' => 'Ribeye Marrow',
    'Righteous' => 'Righteous',
    'Risque' => 'Risque',
    'Roboto' => 'Roboto',
    'Roboto Condensed' => 'Roboto Condensed',
    'Roboto Mono' => 'Roboto Mono',
    'Roboto Slab' => 'Roboto Slab',
    'Rochester' => 'Rochester',
    'Rock Salt' => 'Rock Salt',
    'Rokkitt' => 'Rokkitt',
    'Romanesco' => 'Romanesco',
    'Ropa Sans' => 'Ropa Sans',
    'Rosario' => 'Rosario',
    'Rosarivo' => 'Rosarivo',
    'Rouge Script' => 'Rouge Script',
    'Rozha One' => 'Rozha One',
    'Rubik' => 'Rubik',
    'Rubik One' => 'Rubik One',
    'Rubik Mono One' => 'Rubik Mono One',
    'Ruda' => 'Ruda',
    'Rufina' => 'Rufina',
    'Ruge Boogie' => 'Ruge Boogie',
    'Ruluko' => 'Ruluko',
    'Rum Raisin' => 'Rum Raisin',
    'Ruslan Display' => 'Ruslan Display',
    'Russo One' => 'Russo One',
    'Ruthie' => 'Ruthie',
    'Rye' => 'Rye',
    'Sacramento' => 'Sacramento',
    'Sail' => 'Sail',
    'Salsa' => 'Salsa',
    'Sanchez' => 'Sanchez',
    'Sancreek' => 'Sancreek',
    'Sahitya' => 'Sahitya',
    'Sansita One' => 'Sansita One',
    'Sarpanch' => 'Sarpanch',
    'Sarina' => 'Sarina',
    'Satisfy' => 'Satisfy',
    'Scada' => 'Scada',
    'Scheherazade' => 'Scheherazade',
    'Schoolbell' => 'Schoolbell',
    'Seaweed Script' => 'Seaweed Script',
    'Sarala' => 'Sarala',
    'Sevillana' => 'Sevillana',
    'Seymour One' => 'Seymour One',
    'Shadows Into Light' => 'Shadows Into Light',
    'Shadows Into Light Two' => 'Shadows Into Light Two',
    'Shanti' => 'Shanti',
    'Share' => 'Share',
    'Share Tech' => 'Share Tech',
    'Share Tech Mono' => 'Share Tech Mono',
    'Shojumaru' => 'Shojumaru',
    'Short Stack' => 'Short Stack',
    'Sigmar One' => 'Sigmar One',
    'Suranna' => 'Suranna',
    'Suravaram' => 'Suravaram',
    'Suwannaphum' => 'Suwannaphum',
    'Signika' => 'Signika',
    'Signika Negative' => 'Signika Negative',
    'Simonetta' => 'Simonetta',
    'Siemreap' => 'Siemreap',
    'Sirin Stencil' => 'Sirin Stencil',
    'Six Caps' => 'Six Caps',
    'Skranji' => 'Skranji',
    'Slackey' => 'Slackey',
    'Smokum' => 'Smokum',
    'Smythe' => 'Smythe',
    'Sniglet' => 'Sniglet',
    'Snippet' => 'Snippet',
    'Snowburst One' => 'Snowburst One',
    'Sofadi One' => 'Sofadi One',
    'Sofia' => 'Sofia',
    'Sonsie One' => 'Sonsie One',
    'Sorts Mill Goudy' => 'Sorts Mill Goudy',
    'Sorts Mill Goudy' => 'Sorts Mill Goudy',
    'Source Code Pro' => 'Source Code Pro',
    'Source Sans Pro' => 'Source Sans Pro',
    'Special I am one' => 'Special I am one',
    'Spicy Rice' => 'Spicy Rice',
    'Spinnaker' => 'Spinnaker',
    'Spirax' => 'Spirax',
    'Squada One' => 'Squada One',
    'Sree Krushnadevaraya' => 'Sree Krushnadevaraya',
    'Stalemate' => 'Stalemate',
    'Stalinist One' => 'Stalinist One',
    'Stardos Stencil' => 'Stardos Stencil',
    'Stint Ultra Condensed' => 'Stint Ultra Condensed',
    'Stint Ultra Expanded' => 'Stint Ultra Expanded',
    'Stoke' => 'Stoke',
    'Stoke' => 'Stoke',
    'Strait' => 'Strait',
    'Sura' => 'Sura',
    'Sumana' => 'Sumana',
    'Sue Ellen Francisco' => 'Sue Ellen Francisco',
    'Sunshiney' => 'Sunshiney',
    'Supermercado One' => 'Supermercado One',
    'Swanky and Moo Moo' => 'Swanky and Moo Moo',
    'Syncopate' => 'Syncopate',
    'Symbol' => 'Symbol',
    'Timmana' => 'Timmana',
    'Taprom' => 'Taprom',
    'Tangerine' => 'Tangerine',
    'Tahoma' => 'Tahoma',
    'Teko' => 'Teko',
    'Telex' => 'Telex',
    'Tenali Ramakrishna' => 'Tenali Ramakrishna',
    'Tenor Sans' => 'Tenor Sans',
    'Terminal Dosis' => 'Terminal Dosis',
    'Terminal Dosis Light' => 'Terminal Dosis Light',
    'Text Me One' => 'Text Me One',
    'The Girl Next Door' => 'The Girl Next Door',
    'Tienne' => 'Tienne',
    'Tillana' => 'Tillana',
    'Tinos' => 'Tinos',
    'Titan One' => 'Titan One',
    'Titillium Web' => 'Titillium Web',
    'Trade Winds' => 'Trade Winds',
    'Trebuchet MS' => 'Trebuchet MS',
    'Trocchi' => 'Trocchi',
    'Trochut' => 'Trochut',
    'Trykker' => 'Trykker',
    'Tulpen One' => 'Tulpen One',
    'Ubuntu' => 'Ubuntu',
    'Ubuntu Condensed' => 'Ubuntu Condensed',
    'Ubuntu Mono' => 'Ubuntu Mono',
    'Ultra' => 'Ultra',
    'Uncial Antiqua' => 'Uncial Antiqua',
    'Underdog' => 'Underdog',
    'Unica One' => 'Unica One',
    'UnifrakturCook' => 'UnifrakturCook',
    'UnifrakturMaguntia' => 'UnifrakturMaguntia',
    'Unkempt' => 'Unkempt',
    'Unlock' => 'Unlock',
    'Unna' => 'Unna',
    'VT323' => 'VT323',
    'Vampiro One' => 'Vampiro One',
    'Varela' => 'Varela',
    'Varela Round' => 'Varela Round',
    'Vast Shadow' => 'Vast Shadow',
    'Vesper Libre' => 'Vesper Libre',
    'Verdana' => 'Verdana',
    'Vibur' => 'Vibur',
    'Vidaloka' => 'Vidaloka',
    'Viga' => 'Viga',
    'Voces' => 'Voces',
    'Volkhov' => 'Volkhov',
    'Vollkorn' => 'Vollkorn',
    'Voltaire' => 'Voltaire',
    'Waiting for the Sunrise' => 'Waiting for the Sunrise',
    'Wallpoet' => 'Wallpoet',
    'Walter Turncoat' => 'Walter Turncoat',
    'Warnes' => 'Warnes',
    'Wellfleet' => 'Wellfleet',
    'Wendy One' => 'Wendy One',
    'Wire One' => 'Wire One',
    'Yanone Kaffeesatz' => 'Yanone Kaffeesatz',
    'Yantramanav' => 'Yantramanav',
    'Yellowtail' => 'Yellowtail',
    'Yeseva One' => 'Yeseva One',
    'Yesteryear' => 'Yesteryear',
    'Zeyada' => 'Zeyada'
  );

	//array of all font sizes.
	$font_sizes = array( 
		'10px' => '10px',
		'11px' => '11px',
	);
	
	$options = array();
	$imagepath =  get_template_directory_uri() . '/images/';

	
	for($n=12;$n<=200;$n+=1){
		$font_sizes[$n.'px'] = $n.'px';
	}
	
	// Pull all the pages into an array
	 $options_pages = array();
	 $options_pages_obj = get_pages('sort_column=post_parent,menu_order');
	 $options_pages[''] = 'Select a page:';
	 foreach ($options_pages_obj as $page) {
	  $options_pages[$page->ID] = $page->post_title;
	 }

	// array of section content.
	$section_text = array(
	
		 1 => array(
			'section_title'	=> 'Our Theme Features',
			'menutitle'		=> 'themefeatures',
			'bgcolor' 		=> '#ffffff',
			'bgimage'		=> '',
			'class'			=> 'featureswrap',
			'content'		=> '[column_content type="one_half"]
	<img src="'.get_template_directory_uri().'/images/responsive.png" />
[/column_content]

[column_content type="one_half_last"][features iconname="gavel" title="20 Years Experience"  description="Lorem ipsum dolor sit amet,sodales suscipit tellus, ut tristique consectetur adipiscing elit.Integer sodales suscipit tellus."][features iconname="building" title="More than 200 Projects"  description="Lorem ipsum dolor sit amet,sodales suscipit tellus, ut tristique consectetur adipiscing elit.Integer sodales suscipit tellus."][features iconname="diamond" title="Unique Construction Design"  description="Lorem ipsum dolor sit amet,sodales suscipit tellus, ut tristique consectetur adipiscing elit.Integer sodales suscipit tellus."][features iconname="group" title="Toper Builders"  description="Lorem ipsum dolor sit amet,sodales suscipit tellus, ut tristique consectetur adipiscing elit.Integer sodales suscipit tellus."][/column_content]
',
		 ),	
		
		 2 => array(
			'section_title'	=> 'Our Projects',
			'menutitle'		=> 'clientsection',
			'bgcolor' 		=> '#f7f6f6',
			'bgimage'		=> '',
			'class'			=> 'projectwrap',
			'content'		=> '[project_lists][project title="Project Name" image="'.get_template_directory_uri().'/images/project1.jpg" link="#"][project title="Project Name" image="'.get_template_directory_uri().'/images/project2.jpg" link="#"][project title="Project Name" image="'.get_template_directory_uri().'/images/project3.jpg" link="#"][project title="Project Name" image="'.get_template_directory_uri().'/images/project4.jpg" link="#"][project title="Project Name" image="'.get_template_directory_uri().'/images/project5.jpg" link="#"][/project_lists]',
		 ),
		 
		 3 => array(
			'section_title'	=> 'Our Services',
			'menutitle'		=> 'servicessection',
			'bgcolor' 		=> '#f0efef',
			'bgimage'		=> get_template_directory_uri().'/images/servicesbg.jpg',
			'class'			=> 'serviceswrap',
			'content'		=> '[column_content type="one_fourth"]
			<h4>Our Services 1</h4>
	Nulla consequat massa quis enim.Donec pede justo, fringilla vel, aliquet nec, vulputate eget, arcu.In enim justo, rhoncus ut, imperdiet a, venenatis vitae, justo. Nullam dictum felis eu pede mollis pretium.Integer tincidunt Cras dapibus.
[/column_content]

[column_content type="one_fourth"]
<h4>Our Services 2</h4>
	Nulla consequat massa quis enim.Donec pede justo, fringilla vel, aliquet nec, vulputate eget, arcu.In enim justo, rhoncus ut, imperdiet a, venenatis vitae, justo. Nullam dictum felis eu pede mollis pretium.Integer tincidunt Cras dapibus.
[/column_content]

[column_content type="one_fourth"]
<h4>Our Services 3</h4>
	Nulla consequat massa quis enim.Donec pede justo, fringilla vel, aliquet nec, vulputate eget, arcu.In enim justo, rhoncus ut, imperdiet a, venenatis vitae, justo. Nullam dictum felis eu pede mollis pretium.Integer tincidunt Cras dapibus.
[/column_content]

[column_content type="one_fourth_last"]
<h4>Our Services 4</h4>
	Nulla consequat massa quis enim.Donec pede justo, fringilla vel, aliquet nec, vulputate eget, arcu.In enim justo, rhoncus ut, imperdiet a, venenatis vitae, justo. Nullam dictum felis eu pede mollis pretium.Integer tincidunt Cras dapibus.
[/column_content]',
		),	
		 
		 4 => array(
			'section_title'	=> 'Our Team',
			'menutitle'		=> 'teamsection',
			'bgcolor' 		=> '#ffffff',
			'bgimage'		=> '',
			'class'			=> 'teamwrap',
			'content'		=> '[our-team show="4"] ',
		),			
		
		5 => array(
			'section_title'	=> '',
			'menutitle'		=> 'ourskills',
			'bgcolor' 		=> '',
			'bgimage'		=>  get_template_directory_uri().'/images/skillbg.jpg',
			'class'			=> 'skillwrap',
			'content'		=> '[counter iconname="building" value="4599" title="Our Projects"][counter iconname="group" value="9560" title="Our Clients"][counter iconname="list" value="9560" title="Worker Employed"] [counter iconname="graduation-cap" value="560" title="Winning Awards"]'
		),
		
		
		6 => array(
			'section_title'	=> 'Latest News',
			'menutitle'		=> 'newswraper',
			'bgcolor' 		=> '#ffffff',
			'bgimage'		=> '',
			'class'			=> 'newswrap',
			'content'		=> '[latest-news showposts="4" comment="show" date="show" author="show"]',
		),		

		
		7 => array(
			'section_title'	=> 'Clients Testimonials',
			'menutitle'		=> 'testimonialswrap',
			'bgcolor' 		=> '#f7f6f6',
			'bgimage'		=> '',
			'class'			=> 'tmnlwrap',
			'content'		=> '[testimonials]'
		),
		
		8 => array(
			'section_title'	=> 'Our Gallery',
			'menutitle'		=> 'home-gallery',
			'bgcolor' 		=> '#ffffff',
			'bgimage'		=> '',
			'class'			=> 'gallerywrap',
			'content'		=> '[photogallery filter="true" show="8"]',
		),		

	);

	$options = array();

	//Basic Settings
	$options[] = array(
		'name' => __('Basic Settings', 'creator-world-pro'),
		'type' => 'heading');

	$options[] = array(
		'name' => __('Logo', 'creator-world-pro'),
		'desc' => __('Upload your main logo here', 'creator-world-pro'),
		'id' => 'logo',
		'class' => '',
		'std'	=> get_template_directory_uri()."/images/logo.png",
		'type' => 'upload');
		
	$options[] = array(		
		'desc' => __('Change your custom logo height', 'creator-world-pro'),
		'id' => 'logoheight',
		'std' => '54',
		'type' => 'text');
		
	$options[] = array(	
		'name' => __('Site title & Description', 'creator-world-pro'),		
		'desc'	=> __('Check To hide site title and description', 'creator-world-pro'),
		'id'	=> 'hide_titledesc',
		'type'	=> 'checkbox',
		'std'	=> 'true');	
		
	$options[] = array(
		'name' => __('Sticky Header', 'creator-world-pro'),
		'desc' => __('Check this to disable sticky header on scroll', 'creator-world-pro'),
		'id' => 'headstick',
		'std' => '',
		'type' => 'checkbox');	
		
	$options[] = array(	
		'name' => __('Layout Option', 'creator-world-pro'),		
		'desc'	=> __('Check to View Box Width Layout ', 'creator-world-pro'),
		'id'	=> 'boxwidthlayout',
		'type'	=> 'checkbox',
		'std'	=> '');
			
	$options[] = array(
		'name' => __('Disable Animation', 'creator-world-pro'),
		'desc' => __('Check this to disable animation on scroll', 'creator-world-pro'),
		'id' => 'scrollanimation',
		'std' => '',
		'type' => 'checkbox');	
		
	$options[] = array(
		'name' => __('Header Top Social Icons', 'creator-world-pro'),
		'desc' => __('Edit select social icons for header top', 'creator-world-pro'),
		'id' => 'headersocial',
		'std' => ' [social_area] [social icon="facebook" link="#"] [social icon="twitter" link="#"] [social icon="google-plus" link="#"] [social icon="linkedin" link="#"][/social_area]',
		'type' => 'textarea');	
		
	$options[] = array(
		'name' => __('Header Top Info', 'creator-world-pro'),
		'desc' => __('Edit header info from here. NOTE: Icon name should be in lowercase without space.(exa.phone) More social icons can be found at: http://fortawesome.github.io/Font-Awesome/icons/', 'creator-world-pro'),
		'id' => 'headerinfo',
		'std' => '<i class="fa fa-phone"></i> <span class="phno">+11 123 456 7890</span> <i class="fa fa-map-marker"></i>1600 Demo Address Parkway Mountain View, CA 94043 ',
		'type' => 'textarea');
		
	$options[] = array(
		'name' => __('Disable Header Contact info strip', 'creator-world-pro'),
		'desc' => __('Check to disable header contact info(phone,email,address) and social icons', 'creator-world-pro'),
		'id' => 'headtopstrip',
		'std' => '',
		'type' => 'checkbox');	
		
	$options[] = array(
		'name' => __('Custom CSS', 'creator-world-pro'),
		'desc' => __('Some Custom Styling for your site. Place any css codes here instead of the style.css file.', 'creator-world-pro'),
		'id' => 'style2',
		'std' => '',
		'type' => 'textarea');				
		
	// font family start 		
	$options[] = array(
		'name' => __('Font Faces', 'creator-world-pro'),
		'desc' => __('Select font for the body text', 'creator-world-pro'),
		'id' => 'bodyfontface',
		'type' => 'select',
		'std' => 'Open Sans',
		'options' => $font_types );
		
	$options[] = array(
		'desc' => __('Select font for the textual logo', 'creator-world-pro'),
		'id' => 'logofontface',
		'type' => 'select',
		'std' => 'Roboto Condensed',
		'options' => $font_types );
		
	$options[] = array(
		'desc' => __('Select font for the navigation text', 'creator-world-pro'),
		'id' => 'navfontface',
		'type' => 'select',
		'std' => 'Roboto',
		'options' => $font_types );
		
	$options[] = array(
		'desc' => __('Select font family for all heading tag.', 'creator-world-pro'),
		'id' => 'headfontface',
		'type' => 'select',
		'std' => 'Roboto',
		'options' => $font_types );
			
	$options[] = array(
		'desc' => __('Select font for Slide title', 'creator-world-pro'),
		'id' => 'slidetitlefontface',
		'type' => 'select',
		'std' => 'Roboto Condensed',
		'options' => $font_types );	
		
	$options[] = array(
		'desc' => __('Select font for Slide Description', 'creator-world-pro'),
		'id' => 'slidedesfontface',
		'type' => 'select',
		'std' => 'Roboto Condensed',
		'options' => $font_types );	

		
	// font sizes start	
	$options[] = array(
		'name' => __('Font Sizes', 'creator-world-pro'),
		'desc' => __('Select font size for body text', 'creator-world-pro'),
		'id' => 'bodyfontsize',
		'type' => 'select',
		'std' => '12px',
		'options' => $font_sizes );
		
	$options[] = array(
		'desc' => __('Select font size for textual logo', 'creator-world-pro'),
		'id' => 'logofontsize',
		'type' => 'select',
		'std' => '40px',
		'options' => $font_sizes );
		
	$options[] = array(
		'desc' => __('Select font size for navigation', 'creator-world-pro'),
		'id' => 'navfontsize',
		'type' => 'select',
		'std' => '14px',
		'options' => $font_sizes );	
		
	$options[] = array(
		'desc' => __('Select font size for section title', 'creator-world-pro'),
		'id' => 'sectitlesize',
		'type' => 'select',
		'std' => '34px',
		'options' => $font_sizes );
		
	$options[] = array(
		'desc' => __('Select font size for footer title', 'creator-world-pro'),
		'id' => 'ftfontsize',
		'type' => 'select',
		'std' => '20px',
		'options' => $font_sizes );	

	$options[] = array(
		'desc' => __('Select h1 font size', 'creator-world-pro'),
		'id' => 'h1fontsize',
		'std' => '32px',
		'type' => 'select',
		'options' => $font_sizes);

	$options[] = array(
		'desc' => __('Select h2 font size', 'creator-world-pro'),
		'id' => 'h2fontsize',
		'std' => '28px',
		'type' => 'select',
		'options' => $font_sizes);

	$options[] = array(
		'desc' => __('Select h3 font size', 'creator-world-pro'),
		'id' => 'h3fontsize',
		'std' => '18px',
		'type' => 'select',
		'options' => $font_sizes);

	$options[] = array(
		'desc' => __('Select h4 font size', 'creator-world-pro'),
		'id' => 'h4fontsize',
		'std' => '22px',
		'type' => 'select',
		'options' => $font_sizes);

	$options[] = array(
		'desc' => __('Select h5 font size', 'creator-world-pro'),
		'id' => 'h5fontsize',
		'std' => '20px',
		'type' => 'select',
		'options' => $font_sizes);

	$options[] = array(
		'desc' => __('Select h6 font size', 'creator-world-pro'),
		'id' => 'h6fontsize',
		'std' => '14px',
		'type' => 'select',
		'options' => $font_sizes);


	// font colors start

	$options[] = array(
		'name' => __('Font Colors', 'creator-world-pro'),
		'desc' => __('Select font color for the body text', 'creator-world-pro'),
		'id' => 'bodyfontcolor',
		'std' => '#555555',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for textual logo', 'creator-world-pro'),
		'id' => 'logofontcolor',
		'std' => '#e19105',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for logo tagline', 'creator-world-pro'),
		'id' => 'logotaglinecolor',
		'std' => '#828181',
		'type' => 'color');
		
	

	$options[] = array(
		'desc' => __('Select font color for social icons', 'creator-world-pro'),
		'id' => 'socialfontcolor',
		'std' => '#ffffff',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font hover color for social icons', 'creator-world-pro'),
		'id' => 'socialfonthvcolor',
		'std' => '#cccccc',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for section title', 'creator-world-pro'),
		'id' => 'sectitlecolor',
		'std' => '#515151',
		'type' => 'color');	
		
	
	$options[] = array(
		'desc' => __('Select font color for navigation', 'creator-world-pro'),
		'id' => 'navfontcolor',
		'std' => '#515151',
		'type' => 'color');

	$options[] = array(
		'desc' => __('Select font color for navigation hover', 'creator-world-pro'),
		'id' => 'navhovercolor',
		'std' => '#e19105',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for widget title', 'creator-world-pro'),
		'id' => 'wdgttitleccolor',
		'std' => '#515151',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for footer title', 'creator-world-pro'),
		'id' => 'foottitlecolor',
		'std' => '#ffffff',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for footer', 'creator-world-pro'),
		'id' => 'footdesccolor',
		'std' => '#595959',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font hover color for footer menu ', 'creator-world-pro'),
		'id' => 'footermenucolor',
		'std' => '#e19105',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for footer left text (copyright)', 'creator-world-pro'),
		'id' => 'copycolor',
		'std' => '#ffffff',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for footer right text (design by)', 'creator-world-pro'),
		'id' => 'designcolor',
		'std' => '#ffffff',
		'type' => 'color');

	$options[] = array(
		'desc' => __('Select font color for links / anchor tags', 'creator-world-pro'),
		'id' => 'linkcolor',
		'std' => '#e19105',
		'type' => 'color');

	$options[] = array(
		'desc' => __('Select font hover color for links / anchor tags', 'creator-world-pro'),
		'id' => 'linkhovercolor',
		'std' => '#272727',
		'type' => 'color');			
		
	$options[] = array(
		'desc' => __('Select font color for sidebar li a', 'creator-world-pro'),
		'id' => 'sidebarfontcolor',
		'std' => '#78797c',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font hover color for sidebar li a', 'creator-world-pro'),
		'id' => 'sidebarfonthvcolor',
		'std' => '#e19105',
		'type' => 'color');			
			
	
	$options[] = array(
		'desc' => __('Select font color for footer copyright links', 'creator-world-pro'),
		'id' => 'copylinks',
		'std' => '#000000',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font hover color for footer copyright links', 'creator-world-pro'),
		'id' => 'copylinkshover',
		'std' => '#ffffff',
		'type' => 'color');	

	$options[] = array(
		'desc' => __('Select h1 font color', 'creator-world-pro'),
		'id' => 'h1fontcolor',
		'std' => '#515151',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select h2 font color', 'creator-world-pro'),
		'id' => 'h2fontcolor',
		'std' => '#515151',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select h3 font color', 'creator-world-pro'),
		'id' => 'h3fontcolor',
		'std' => '#515151',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select h4 font color', 'creator-world-pro'),
		'id' => 'h4fontcolor',
		'std' => '#515151',
		'type' => 'color');	

	$options[] = array(
		'desc' => __('Select h5 font color', 'creator-world-pro'),
		'id' => 'h5fontcolor',
		'std' => '#515151',
		'type' => 'color');	

	$options[] = array(
		'desc' => __('Select h6 font color', 'creator-world-pro'),
		'id' => 'h6fontcolor',
		'std' => '#515151',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for counter circle box', 'creator-world-pro'),
		'id' => 'countercirclecolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for counter circle number', 'creator-world-pro'),
		'id' => 'countercirclenumber',
		'std' => '#e19105',
		'type' => 'color');	

		
	$options[] = array(
		'desc' => __('Select font color for testimonials title', 'creator-world-pro'),
		'id' => 'testimonialtitle',
		'std' => '#E19105',
		'type' => 'color');		
		
	$options[] = array(
		'desc' => __('Select font color for testimonials decription', 'creator-world-pro'),
		'id' => 'testimonialdesc',
		'std' => '#555555',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for footer social icons', 'creator-world-pro'),
		'id' => 'footsocialcolor',
		'std' => '#303030',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font hover color for footer social icons', 'creator-world-pro'),
		'id' => 'footsocialhvcolor',
		'std' => '#e19105',
		'type' => 'color');	
	
	$options[] = array(
		'desc' => __('Select font color for header top', 'creator-world-pro'),
		'id' => 'headertopcolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for team member designation', 'creator-world-pro'),
		'id' => 'teamdisignationcolor',
		'std' => '#E19105',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for gallery filter ', 'creator-world-pro'),
		'id' => 'galleryfiltercolor',
		'std' => '#555555',
		'type' => 'color');			
		
	$options[] = array(
		'desc' => __('Select font hover color for gallery filter ', 'creator-world-pro'),
		'id' => 'galleryfiltercolorhv',
		'std' => '#ffffff',
		'type' => 'color');			
					
		
	// Background start		
	$options[] = array(	
		'name' => __('Background Colors', 'creator-world-pro'),	
		'desc' => __('Select background color for header', 'creator-world-pro'),
		'id' => 'headerbgcolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background color for site main wrapper', 'creator-world-pro'),
		'id' => 'mainwrapperbgcolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(		
		'desc' => __('Select background color opacity for site main wrapper', 'creator-world-pro'),
		'id' => 'wrapperopacity',
		'std' => '0.9',
		'type' => 'select',
		'options'	=> array('1'=>1, '0.9'=>0.9,'0.8'=>0.8,'0.7'=>0.7,'0.6'=>0.6,'0.5'=>0.5,'0.4'=>0.4,'0.3'=>0.3,'0.2'=>0.2, '0.1'=>0.1, '0.0'=>0.0,));			
	
	$options[] = array(
		'desc' => __('Select background color for header nav dropdown', 'creator-world-pro'),
		'id' => 'navdpbgcolor',
		'std' => '#ffffff',
		'type' => 'color');	

	$options[] = array(
		'desc' => __('Select background color for footer', 'creator-world-pro'),
		'id' => 'footerbgcolor',
		'std' => '#1a191a',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select background color for copyright section', 'creator-world-pro'),
		'id' => 'copybgcolor',
		'std' => '#E19105',
		'type' => 'color');	

	$options[] = array(
		'desc' => __('Select background color for toggle menu', 'creator-world-pro'),
		'id' => 'togglemenu',
		'std' => '#e19105',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background color for our team member boxes', 'creator-world-pro'),
		'id' => 'teambgcolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background color for header top', 'creator-world-pro'),
		'id' => 'headertopbgcolor',
		'std' => '#e19105',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select background color for fhotogallery filter', 'creator-world-pro'),
		'id' => 'galleryfilter',
		'std' => '#ffffff',
		'type' => 'color');			
		
	$options[] = array(
		'desc' => __('Select background active/hover color for fhotogallery filter', 'creator-world-pro'),
		'id' => 'galleryfilterhover',
		'std' => '#E19105',
		'type' => 'color');			

	// Border colors
	$options[] = array(
		'name' => __('Border Colors', 'creator-world-pro'),	
		'desc' => __('Select border color for All', 'creator-world-pro'),
		'id' => 'allbdcolor',
		'std' => '#e19105',
		'type' => 'color');
			
	$options[] = array(	
		'desc' => __('Select border color for footer posts', 'creator-world-pro'),
		'id' => 'footerpostborder',
		'std' => '#5e6162',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for sidebar li a', 'creator-world-pro'),
		'id' => 'sidebarliaborder',
		'std' => '#d0cfcf',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for our staff degignation', 'creator-world-pro'),
		'id' => 'teamborder',
		'std' => '#EAEAEA',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for sidebar widget title', 'creator-world-pro'),
		'id' => 'widgettitleborder',
		'std' => '#E8E8E8',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for sidebar widget box', 'creator-world-pro'),
		'id' => 'widgetboxborder',
		'std' => '#E8E8E8',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for footer all underline', 'creator-world-pro'),
		'id' => 'footerallborder',
		'std' => '#303030',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for top navigation dropdown li', 'creator-world-pro'),
		'id' => 'navlibdcolor',
		'std' => '#E7E6E6',
		'type' => 'color');
		
	$options[] = array(			
		'desc' => __('Select border color for gallery filter', 'creator-world-pro'),
		'id' => 'galleryfilterbdr',
		'std' => '#E5E5E5',
		'type' => 'color');	
		
	

	// Default Buttons		
	$options[] = array(
		'name' => __('Button Colors', 'creator-world-pro'),		
		'desc' => __('Select background color for default button', 'creator-world-pro'),
		'id' => 'btnbgcolor',
		'std' => '#e19105',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select background hover color for default button', 'creator-world-pro'),
		'id' => 'btnbghvcolor',
		'std' => '#424242',
		'type' => 'color');		

	$options[] = array(
		'desc' => __('Select font color default button', 'creator-world-pro'),
		'id' => 'btntxtcolor',
		'std' => '#ffffff',
		'type' => 'color');

	$options[] = array(
		'desc' => __('Select font hover color for default button', 'creator-world-pro'),
		'id' => 'btntxthvcolor',
		'std' => '#ffffff',
		'type' => 'color');

	// Slider Caption colors
	$options[] = array(	
		'name' => __('Slider Caption Colors', 'creator-world-pro'),			
		'desc' => __('Select background color for slider caption', 'creator-world-pro'),
		'id' => 'slidecaptionbgcolor',
		'std' => '#000000',
		'type' => 'color');	
		
	$options[] = array(		
		'desc' => __('Select background color opacity for slider caption', 'creator-world-pro'),
		'id' => 'captionopacity',
		'std' => '0.6',
		'type' => 'select',
		'options'	=> array('1'=>1, '0.9'=>0.9,'0.8'=>0.8,'0.7'=>0.7,'0.6'=>0.6,'0.5'=>0.5,'0.4'=>0.4,'0.3'=>0.3,'0.2'=>0.2,));	
		
	$options[] = array(			
		'desc' => __('Select border color for slider caption', 'creator-world-pro'),
		'id' => 'captionborder',
		'std' => '#E19105',
		'type' => 'color');			
			
	$options[] = array(			
		'desc' => __('Select font color for slider title', 'creator-world-pro'),
		'id' => 'slidetitlecolor',
		'std' => '#ffffff',
		'type' => 'color');			
		
	$options[] = array(		
		'desc' => __('Select font color for slider description', 'creator-world-pro'),
		'id' => 'slidedesccolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font size for slider title', 'creator-world-pro'),
		'id' => 'slidetitlefontsize',
		'type' => 'select',
		'std' => '32px',
		'options' => $font_sizes );
		
	$options[] = array(
		'desc' => __('Select font size for slider description', 'creator-world-pro'),
		'id' => 'slidedescfontsize',
		'type' => 'select',
		'std' => '16px',
		'options' => $font_sizes );
		
	// Slider controls colors		
	$options[] = array(
		'name' => __('Slider controls Colors', 'creator-world-pro'),
		'desc' => __('Select background color for slider pager', 'creator-world-pro'),
		'id' => 'sldpagebg',
		'std' => '#ffffff',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select background active color for slider pager', 'creator-world-pro'),
		'id' => 'sldpagehvbg',
		'std' => '#e19105',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select Border color for slider pager', 'creator-world-pro'),
		'id' => 'sldpagehvbd',
		'std' => '#ffffff',
		'type' => 'color');	

	$options[] = array(
		'name' => __('Blog Single Layout', 'creator-world-pro'),
		'desc' => __('Select layout. eg:Boxed, Wide', 'creator-world-pro'),
		'id' => 'singlelayout',
		'type' => 'select',
		'std' => 'singleright',
		'options' => array('singleright'=>'Blog Single Right Sidebar', 'singleleft'=>'Blog Single Left Sidebar', 'sitefull'=>'Blog Single Full Width', 'nosidebar'=>'Blog Single No Sidebar') );
	
		
	$options[] = array(
		'name' => __('Excerpt Lenth', 'creator-world-pro'),	
		'desc' => __('Select excerpt length for services four boxes section', 'creator-world-pro'),
		'id' => 'servicesfourbxlength',
		'std' => '20',
		'type' => 'text');
		
	$options[] = array(		
		'desc' => __('Select excerpt length for team member boxes section', 'creator-world-pro'),
		'id' => 'teammemberlength',
		'std' => '20',
		'type' => 'text');
		
	$options[] = array(		
		'desc' => __('Select excerpt length for latest news boxes section', 'creator-world-pro'),
		'id' => 'latestnewslength',
		'std' => '15',
		'type' => 'text');	
		
	$options[] = array(		
		'desc' => __('Select excerpt length for testimonials section', 'creator-world-pro'),
		'id' => 'testimonialsexcerptlength',
		'std' => '40',
		'type' => 'text');
		
	$options[] = array(		
		'desc' => __('Select excerpt length for blog post', 'creator-world-pro'),
		'id' => 'blogpostexcerptlength',
		'std' => '50',
		'type' => 'text');	
		
	$options[] = array(
		'name' => __('Read More Text', 'creator-world-pro'),	
		'desc' => __('Change read more button text for blog posts ', 'creator-world-pro'),
		'id' => 'blogpostreadmoretext',
		'std' => 'Read More',
		'type' => 'text');	
		
	$options[] = array(		
		'desc' => __('Change read more button text for home page latest news boxes', 'creator-world-pro'),
		'id' => 'latestnewsreadmore',
		'std' => 'Read More',
		'type' => 'text');	
		
	$options[] = array(		
		'desc' => __('Change default All Text for photo gallery', 'creator-world-pro'),
		'id' => 'galleryalltext',
		'std' => 'Show All',
		'type' => 'text');		
		
	$options[] = array(
		'name' => __('Responsive View Menu word Changeable', 'creator-world-pro'),
		'desc' => __('Change menu word on responsive view', 'creator-world-pro'),
		'id' => 'menuwordchange',
		'std' => 'Menu',
		'type' => 'text');	
		
	$options[] = array(
		'name' => __('Woocommerce Page Layout', 'creator-world-pro'),
		'desc' => __('Select layout. eg:right-sidebar, left-sidebar, full-width', 'creator-world-pro'),
		'id' => 'woocommercelayout',
		'type' => 'select',
		'std' => 'woocommercesitefull',
		'options' => array('woocommerceright'=>'Woocommerce Right Sidebar', 'woocommerceleft'=>'Woocommerce Left Sidebar', 'woocommercesitefull'=>'Woocommerce Full Width') );	
		
	$options[] = array(	
		'name' => __('Testimonials Rotating Speed', 'creator-world-pro'),	
		'desc' => __('manage your testimonials rotating speed', 'creator-world-pro'),
		'id' => 'testimonialspeed',
		'std' => '8000',
		'type' => 'text');		
		

	//Layout Settings
	$options[] = array(
		'name' => __('Sections', 'creator-world-pro'),
		'type' => 'heading');
		
	$options[] = array(	
		'desc'	=> __('welcome page content','creator-world-pro'),
		'id' 	=> 'welcomebox',
		'type'	=> 'select',
		'options' => $options_pages,
	);	
	
	$options[] = array(			
			'desc'	=> __('Check to hide welcome section', 'creator-world-pro'),
			'id'	=> 'hidewelcomesec',
			'type'	=> 'checkbox',
			'std'	=> '');
	
	$options[] = array(	
		'desc'	=> __('first Services box for frontpage section','creator-world-pro'),
		'id' 	=> 'box1',
		'type'	=> 'select',
		'options' => $options_pages,
	);
	
	$options[] = array(		
		'desc' => __('upload image for first box.', 'creator-world-pro'),
		'id' => 'boximg1',
		'class' => '',
		'std'	=> '',
		'type' => 'upload');
	
	$options[] = array(	
		'desc'	=> __('Second Services box for frontpage section','creator-world-pro'),
		'id' 	=> 'box2',
		'type'	=> 'select',
		'options' => $options_pages,
	);
	
	$options[] = array(		
		'desc' => __('upload image for second box.', 'creator-world-pro'),
		'id' => 'boximg2',
		'class' => '',
		'std'	=> '',
		'type' => 'upload');
	
	$options[] = array(	
		'desc'	=> __('Third Services box for frontpage section','creator-world-pro'),
		'id' 	=> 'box3',
		'type'	=> 'select',
		'options' => $options_pages,
	);
	
	$options[] = array(		
		'desc' => __('upload image for third box.', 'creator-world-pro'),
		'id' => 'boximg3',
		'class' => '',
		'std'	=> '',
		'type' => 'upload');
	
	$options[] = array(	
		'desc'	=> __('Fourth Services box for frontpage section','creator-world-pro'),
		'id' 	=> 'box4',
		'type'	=> 'select',
		'options' => $options_pages,
	);
	
	$options[] = array(		
		'desc' => __('upload image  for fourth box.', 'creator-world-pro'),
		'id' => 'boximg4',
		'class' => '',
		'std'	=> '',
		'type' => 'upload');
		
	$options[] = array(	
		'desc'	=> __('fifth Services box for frontpage section','creator-world-pro'),
		'id' 	=> 'box5',
		'type'	=> 'select',
		'options' => $options_pages,
	);
	
	$options[] = array(		
		'desc' => __('upload image for fifth box.', 'creator-world-pro'),
		'id' => 'boximg5',
		'class' => '',
		'std'	=> '',
		'type' => 'upload');		
	
	$options[] = array(			
			'desc'	=> __('Check to hide above our services four column section', 'creator-world-pro'),
			'id'	=> 'hidefourbxsec',
			'type'	=> 'checkbox',
			'std'	=> '');
	
	$options[] = array(
		'name' => __('Number of Sections', 'creator-world-pro'),
		'desc' => __('Select number of sections', 'creator-world-pro'),
		'id' => 'numsection',
		'type' => 'select',
		'std' => '8',
		'options' => array_combine(range(1,30), range(1,30)) );

	$numsecs = of_get_option( 'numsection', 8 );

	for( $n=1; $n<=$numsecs; $n++){
		$options[] = array(
			'desc' => __("<h3>Section ".$n."</h3>", 'creator-world-pro'),
			'class' => 'toggle_title',
			'type' => 'info');	
	
		$options[] = array(
			'name' => __('Section Title', 'creator-world-pro'),
			'id' => 'sectiontitle'.$n,
			'std' => ( ( isset($section_text[$n]['section_title']) ) ? $section_text[$n]['section_title'] : '' ),
			'type' => 'text');

		$options[] = array(
			'name' => __('Section ID', 'creator-world-pro'),
			'desc'	=> __('Enter your section ID here. SECTION ID MUST BE IN SMALL LETTERS ONLY AND DO NOT ADD SPACE OR SYMBOL.', 'creator-world-pro'),
			'id' => 'menutitle'.$n,
			'std' => ( ( isset($section_text[$n]['menutitle']) ) ? $section_text[$n]['menutitle'] : '' ),
			'type' => 'text');

		$options[] = array(
			'name' => __('Section Background Color', 'creator-world-pro'),
			'desc' => __('Select background color for section', 'creator-world-pro'),
			'id' => 'sectionbgcolor'.$n,
			'std' => ( ( isset($section_text[$n]['bgcolor']) ) ? $section_text[$n]['bgcolor'] : '' ),
			'type' => 'color');
			
		$options[] = array(
			'name' => __('Background Image', 'creator-world-pro'),
			'id' => 'sectionbgimage'.$n,
			'class' => '',
			'std' => ( ( isset($section_text[$n]['bgimage']) ) ? $section_text[$n]['bgimage'] : '' ),
			'type' => 'upload');

		$options[] = array(
			'name' => __('Section CSS Class', 'creator-world-pro'),
			'desc' => __('Set class for this section.', 'creator-world-pro'),
			'id' => 'sectionclass'.$n,
			'std' => ( ( isset($section_text[$n]['class']) ) ? $section_text[$n]['class'] : '' ),
			'type' => 'text');
			
		$options[] = array(
			'name'	=> __('Hide Section', 'creator-world-pro'),
			'desc'	=> __('Check to hide this section', 'creator-world-pro'),
			'id'	=> 'hidesec'.$n,
			'type'	=> 'checkbox',
			'std'	=> '');

		$options[] = array(
			'name' => __('Section Content', 'creator-world-pro'),
			'id' => 'sectioncontent'.$n,
			'std' => ( ( isset($section_text[$n]['content']) ) ? $section_text[$n]['content'] : '' ),
			'type' => 'editor');
	}


	//SLIDER SETTINGS
	$options[] = array(
		'name' => __('Homepage Slider', 'creator-world-pro'),
		'type' => 'heading');
		
	$options[] = array(
		'name' => __('Inner Page Banner', 'creator-world-pro'),
		'desc' => __('Upload inner page banner for site', 'creator-world-pro'),
		'id' => 'innerpagebanner',
		'class' => '',
		'std'	=> get_template_directory_uri()."/images/inner-banner.jpg",
		'type' => 'upload');
		
		
	$options[] = array(
		'name' => __('Custom Slider Shortcode Area For Home Page', 'creator-world-pro'),
		'desc' => __('Enter here your slider shortcode without php tag', 'creator-world-pro'),
		'id' => 'customslider',
		'std' => '',
		'type' => 'textarea');		
		
	$options[] = array(
		'name' => __('Slider Effects and Timing', 'creator-world-pro'),
		'desc' => __('Select slider effect.','creator-world-pro'),
		'id' => 'slideefect',
		'std' => 'random',
		'type' => 'select',
		'options' => array('random'=>'Random', 'fade'=>'Fade', 'fold'=>'Fold', 'sliceDown'=>'Slide Down', 'sliceDownLeft'=>'Slide Down Left', 'sliceUp'=>'Slice Up', 'sliceUpLeft'=>'Slice Up Left', 'sliceUpDown'=>'Slice Up Down', 'sliceUpDownLeft'=>'Slice Up Down Left', 'slideInRight'=>'SlideIn Right', 'slideInLeft'=>'SlideIn Left', 'boxRandom'=>'Box Random', 'boxRain'=>'Box Rain', 'boxRainReverse'=>'Box Rain Reverse', 'boxRainGrow'=>'Box Rain Grow', 'boxRainGrowReverse'=>'Box Rain Grow Reverse' ));
		
	$options[] = array(
		'desc' => __('Animation speed should be multiple of 100.', 'creator-world-pro'),
		'id' => 'slideanim',
		'std' => 500,
		'type' => 'text');
		
	$options[] = array(
		'desc' => __('Add slide pause time.', 'creator-world-pro'),
		'id' => 'slidepause',
		'std' => 4000,
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slide Controllers', 'creator-world-pro'),
		'desc' => __('Hide/Show Direction Naviagtion of slider.','creator-world-pro'),
		'id' => 'slidenav',
		'std' => 'true',
		'type' => 'select',
		'options' => array('true'=>'Show', 'false'=>'Hide'));
		
	$options[] = array(
		'desc' => __('Hide/Show pager of slider.','creator-world-pro'),
		'id' => 'slidepage',
		'std' => 'true',
		'type' => 'select',
		'options' => array('true'=>'Show', 'false'=>'Hide'));
		
	$options[] = array(
		'desc' => __('Pause Slide on Hover.','creator-world-pro'),
		'id' => 'slidepausehover',
		'std' => 'false',
		'type' => 'select',
		'options' => array('true'=>'Yes', 'false'=>'No'));
		
	$options[] = array(
		'name' => __('Slider Image 1', 'creator-world-pro'),
		'desc' => __('First Slide', 'creator-world-pro'),
		'id' => 'slide1',
		'class' => '',
		'std' => get_template_directory_uri()."/images/slides/slider1.jpg",
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 1', 'creator-world-pro'),
		'id' => 'slidetitle1',
		'std' => 'We create your dream project with world class material.',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'creator-world-pro'),
		'id' => 'slidedesc1',
		'std' => 'Lorem ipsum dolor sit amet,sodales suscipit tellus, ut tristique consectetur adipiscing sodales suscipit tellus elit.',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'creator-world-pro'),
		'id' => 'slidebutton1',
		'std' => '',
		'type' => 'text');	

	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'creator-world-pro'),
		'id' => 'slideurl1',
		'std' => '',
		'type' => 'text');		
		
	
	$options[] = array(
		'name' => __('Slider Image 2', 'creator-world-pro'),
		'desc' => __('Second Slide', 'creator-world-pro'),
		'class' => '',
		'id' => 'slide2',
		'std' => get_template_directory_uri()."/images/slides/slider2.jpg",
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 2', 'creator-world-pro'),
		'id' => 'slidetitle2',
		'std' => 'We create your dream project with world class material.',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'creator-world-pro'),
		'id' => 'slidedesc2',
		'std' => 'Lorem ipsum dolor sit amet,sodales suscipit tellus, ut tristique consectetur adipiscing sodales suscipit tellus elit.',
		'type' => 'textarea');	
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'creator-world-pro'),
		'id' => 'slidebutton2',
		'std' => '',
		'type' => 'text');			
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'creator-world-pro'),
		'id' => 'slideurl2',
		'std' => '',
		'type' => 'text');	
	
	$options[] = array(
		'name' => __('Slider Image 3', 'creator-world-pro'),
		'desc' => __('Third Slide', 'creator-world-pro'),
		'id' => 'slide3',
		'class' => '',
		'std' => get_template_directory_uri()."/images/slides/slider3.jpg",
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 3', 'creator-world-pro'),
		'id' => 'slidetitle3',
		'std' => 'We create your dream project with world class material.',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'creator-world-pro'),
		'id' => 'slidedesc3',
		'std' => 'Lorem ipsum dolor sit amet,sodales suscipit tellus, ut tristique consectetur adipiscing sodales suscipit tellus elit.',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'creator-world-pro'),
		'id' => 'slidebutton3',
		'std' => '',
		'type' => 'text');			
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'creator-world-pro'),
		'id' => 'slideurl3',
		'std' => '',
		'type' => 'text');	
	
	$options[] = array(
		'name' => __('Slider Image 4', 'creator-world-pro'),
		'desc' => __('Third Slide', 'creator-world-pro'),
		'id' => 'slide4',
		'class' => '',
		'std' => get_template_directory_uri()."/images/slides/slider4.jpg",
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 4', 'creator-world-pro'),
		'id' => 'slidetitle4',
		'std' => 'We create your dream project with word class material.',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'creator-world-pro'),
		'id' => 'slidedesc4',
		'std' => 'Lorem ipsum dolor sit amet,sodales suscipit tellus, ut tristique consectetur adipiscing sodales suscipit tellus elit.',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'creator-world-pro'),
		'id' => 'slidebutton4',
		'std' => '',
		'type' => 'text');			
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'creator-world-pro'),
		'id' => 'slideurl4',
		'std' => '',
		'type' => 'text');				
	
	$options[] = array(
		'name' => __('Slider Image 5', 'creator-world-pro'),
		'desc' => __('Fifth Slide', 'creator-world-pro'),
		'id' => 'slide5',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 5', 'creator-world-pro'),
		'id' => 'slidetitle5',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'creator-world-pro'),
		'id' => 'slidedesc5',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'creator-world-pro'),
		'id' => 'slidebutton5',
		'std' => '',
		'type' => 'text');			
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'creator-world-pro'),
		'id' => 'slideurl5',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 6', 'creator-world-pro'),
		'desc' => __('Sixth Slide', 'creator-world-pro'),
		'id' => 'slide6',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 6', 'creator-world-pro'),
		'id' => 'slidetitle6',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'creator-world-pro'),
		'id' => 'slidedesc6',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'creator-world-pro'),
		'id' => 'slidebutton6',
		'std' => '',
		'type' => 'text');		
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'creator-world-pro'),
		'id' => 'slideurl6',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 7', 'creator-world-pro'),
		'desc' => __('Seventh Slide', 'creator-world-pro'),
		'id' => 'slide7',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 7', 'creator-world-pro'),
		'id' => 'slidetitle7',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'creator-world-pro'),
		'id' => 'slidedesc7',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'creator-world-pro'),
		'id' => 'slidebutton7',
		'std' => '',
		'type' => 'text');			
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'creator-world-pro'),
		'id' => 'slideurl7',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 8', 'creator-world-pro'),
		'desc' => __('Eighth Slide', 'creator-world-pro'),
		'id' => 'slide8',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 8', 'creator-world-pro'),
		'id' => 'slidetitle8',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'creator-world-pro'),
		'id' => 'slidedesc8',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'creator-world-pro'),
		'id' => 'slidebutton8',
		'std' => '',
		'type' => 'text');		
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'creator-world-pro'),
		'id' => 'slideurl8',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 9', 'creator-world-pro'),
		'desc' => __('Ninth Slide', 'creator-world-pro'),
		'id' => 'slide9',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 9', 'creator-world-pro'),
		'id' => 'slidetitle9',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'creator-world-pro'),
		'id' => 'slidedesc9',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'creator-world-pro'),
		'id' => 'slidebutton9',
		'std' => '',
		'type' => 'text');			
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'creator-world-pro'),
		'id' => 'slideurl9',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 10', 'creator-world-pro'),
		'desc' => __('Tenth Slide', 'creator-world-pro'),
		'id' => 'slide10',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 10', 'creator-world-pro'),
		'id' => 'slidetitle10',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'creator-world-pro'),
		'id' => 'slidedesc10',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'creator-world-pro'),
		'id' => 'slidebutton10',
		'std' => '',
		'type' => 'text');			
	
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'creator-world-pro'),
		'id' => 'slideurl10',
		'std' => '',
		'type' => 'text');
	

	//Footer SETTINGS
	$options[] = array(
		'name' => __('Footer', 'creator-world-pro'),
		'type' => 'heading');
		
	$options[] = array(
		'name' => __('Footer Layout', 'creator-world-pro'),
		'desc' => __('footer Select layout. eg:Boxed, 1, 2, 3 and 4', 'creator-world-pro'),
		'id' => 'footerlayout',
		'type' => 'select',
		'std' => 'fourcolumn',
		'options' => array('onecolumn'=>'Footer 1 column', 'twocolumn'=>'Footer 2 column', 'threecolumn'=>'Footer 3 column', 'fourcolumn'=>'Footer 4 column', ) );		
				
	$options[] = array(
		'name' => __('Footer About Us', 'creator-world-pro'),
		'desc' => __('abput us text title for footer', 'creator-world-pro'),
		'id' => 'abouttitle',
		'std' => 'About Us',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('About Us Description', 'creator-world-pro'),
		'desc' => __('abput us text description for footer', 'creator-world-pro'),
		'id' => 'aboutusdescription',
		'std' => '<p>Donec ut ex ac nulla pellentesque mollis in a enim Suspendisse suscipit velit id ultricies auctor. Duis turpis arcu, aliquet sed sollicitudin seduisque velit nibh.</br > </br >Donec ut ex ac nulla sapien mauris, vitae sodales tellus suspendisse suscipit velit id ultricies auctor.</p>',
		'type' => 'textarea');
		
	$options[] = array(
		'name' => __('Footer Menu Title', 'creator-world-pro'),
		'desc' => __('footer menu title.', 'creator-world-pro'),
		'id' => 'footermenutitle',
		'std' => 'Footer Menu',
		'type' => 'text');	
	
	$options[] = array(
		'name' => __('Latest Posts Title', 'creator-world-pro'),
		'desc' => __('Footer latest posts title.', 'creator-world-pro'),
		'id' => 'letestpoststitle',
		'std' => 'Latest Posts',
		'type' => 'text');	
		
		
	$options[] = array(
		'name' => __('Footer Get in Touch', 'creator-world-pro'),
		'desc' => __('Add footer get in touch title here', 'creator-world-pro'),
		'id' => 'contacttitle',
		'std' => 'Get in touch',
		'type' => 'text');	
		
	$options[] = array(	
		'desc' => __('Add company address1 here.', 'creator-world-pro'),
		'id' => 'address',
		'std' => '1600 Amphitheatre Parkway Mountain View, CA 94043',
		'type' => 'textarea');
		
	$options[] = array(		
		'desc' => __('Add phone number here.', 'creator-world-pro'),
		'id' => 'phone',
		'std' => '+91 923456789',
		'type' => 'text');
		
	$options[] = array(		
		'desc' => __('Add fax number here.', 'creator-world-pro'),
		'id' => 'fax',
		'std' => '+91 9876543210',
		'type' => 'text');	
		
	$options[] = array(
		'desc' => __('Add email address here.', 'creator-world-pro'),
		'id' => 'email',
		'std' => 'info@demomail.com',
		'type' => 'text');
		
	
	$options[] = array(
		'name' => __('Google Map', 'creator-world-pro'),
		'desc' => __('Use iframe code url here. DO NOT APPLY IFRAME TAG', 'creator-world-pro'),
		'id' => 'googlemap',
		'std' => 'https://www.google.com/maps/embed?pb=!1m18!1m12!1m3!1d336003.6066860609!2d2.349634820486094!3d48.8576730786213!2m3!1f0!2f0!3f0!3m2!1i1024!2i768!4f13.1!3m3!1m2!1s0x47e66e1f06e2b70f%3A0x040b82c3688c9460!2sParis%2C+France!5e0!3m2!1sen!2sin!4v1433482358672',
		'type' => 'textarea');
		
		
	$options[] = array(
		'name' => __('Footer Social Icons', 'creator-world-pro'),
		'desc' => __('social icons for footer', 'creator-world-pro'),
		'id' => 'footersocialicon',
		'std' => '[social_area]
			[social icon="facebook" link="#"]
			[social icon="twitter" link="#"]
			[social icon="linkedin" link="#"]
			[social icon="google-plus" link="#"]
		[/social_area]
		',
		'type' => 'textarea');
		
	$options[] = array(
		'name' => __('Footer Copyright', 'creator-world-pro'),
		'desc' => __('Copyright Text for your site.', 'creator-world-pro'),
		'id' => 'copytext',
		'std' => '&copy; 2015 <a href="#">GRC Creation </a>. All Rights Reserved',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Footre Text Link', 'creator-world-pro'),
		'id' => 'ftlink',
		'std' => 'Design by <a href="'.esc_url('https://www.gracethemes.com/').'" target="_blank">Grace Themes</a>',
		'type' => 'textarea',);
		
	$options[] = array(
		'desc' => __('Footer Back to Top Button', 'creator-world-pro'),
		'id' => 'backtotop',
		'std' => '[back-to-top]',
		'type' => 'textarea',);

	//Short codes
	$options[] = array(
		'name' => __('Short Codes', 'creator-world-pro'),
		'type' => 'heading');
		
	$options[] = array(
		'name' => __('Our Projects', 'creator-world-pro'),
		'desc' => __('[project_lists][project title="Project Name" image="enter here image url with http" link="project link"][project title="Project Name" image="enter here image url with http" link="project link"][project title="Project Name" image="enter here image url with http" link="project link"][project title="Project Name" image="enter here image url with http" link="project link"][project title="Project Name" image="enter here image url with http" link="project link"][/project_lists]', 'creator-world-pro'),
		'type' => 'info');			
		
	
	$options[] = array(
		'name' => __('Photo Gallery', 'creator-world-pro'),
		'desc' => __('[photogallery filter="false" show="8"]', 'creator-world-pro'),
		'type' => 'info');	
		
	$options[] = array(
		'name' => __('Testimonials', 'creator-world-pro'),
		'desc' => __('[testimonials show="10"]', 'creator-world-pro'),
		'type' => 'info');
		
	$options[] = array(
		'name' => __('Contact Form', 'creator-world-pro'),
		'desc' => __('[contactform to_email="test@example.com" title="Contact Form"] 
', 'creator-world-pro'),
		'type' => 'info');

	$options[] = array(
		'name' => __('Our Team', 'creator-world-pro'),
		'desc' => __('[our-team show="4"]', 'creator-world-pro'),
		'type' => 'info');	
		
	$options[] = array(
		'name' => __('Our Skills', 'creator-world-pro'),
		'desc' => __('[counter iconname="building" value="4599" title="Our Projects"][counter iconname="group" value="9560" title="Our Clients"][counter iconname="list" value="9560" title="Worker Employed"] [counter iconname="graduation-cap" value="560" title="Winning Awards"]', 'creator-world-pro'),
		'type' => 'info');	
		
	$options[] = array(
		'name' => __('Latest News', 'creator-world-pro'),
		'desc' => __('[latest-news showposts="4" comment="show" date="show" author="hide"] and all [latest-news]', 'creator-world-pro'),
		'type' => 'info');
		
	$options[] = array(
		'name' => __('Custom Button', 'creator-world-pro'),
		'desc' => __('[button align="center" name="View Gallery" link="#" target="" arrowname="fa-chevron-right"]', 'creator-world-pro'),
		'type' => 'info');	
		
	$options[] = array(
		'name' => __('Theme Features', 'creator-world-pro'),
		'desc' => __('[features iconname="enter here font awesome icon name exa.facebook" title="enter here title name"  description="enter here description"][features iconname="enter here font awesome icon name exa.facebook" title="enter here title name"  description="enter here description"][features iconname="enter here font awesome icon name exa.facebook" title="enter here title name"  description="enter here description"][features iconname="enter here font awesome icon name exa.facebook" title="enter here title name"  description="enter here description"]', 'creator-world-pro'),
		'type' => 'info');				
			
		
	$options[] = array(
		'name' => __('Search Form', 'creator-world-pro'),
		'desc' => __('[searchform]', 'creator-world-pro'),
		'type' => 'info');
		
	$options[] = array(
		'name' => __('Social Icons ( Note: More social icons can be found at: http://fortawesome.github.io/Font-Awesome/icons/)', 'creator-world-pro'),
		'desc' => __('[social_area]<br />
			[social icon="facebook" link="#"]<br />
			[social icon="twitter" link="#"]<br />
			[social icon="linkedin" link="#"]<br />
			[social icon="google-plus" link="#"]<br />
		[/social_area]', 'creator-world-pro'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('2 Column Content', 'creator-world-pro'),
		'desc' => __('<pre>
[column_content type="one_half"]
	Column 1 Content goes here...
[/column_content]

[column_content type="one_half_last"]
	Column 2 Content goes here...
[/column_content]
</pre>', 'creator-world-pro'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('3 Column Content', 'creator-world-pro'),
		'desc' => __('<pre>
[column_content type="one_third"]
	Column 1 Content goes here...
[/column_content]

[column_content type="one_third"]
	Column 2 Content goes here...
[/column_content]

[column_content type="one_third_last"]
	Column 3 Content goes here...
[/column_content]
</pre>', 'creator-world-pro'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('4 Column Content', 'creator-world-pro'),
		'desc' => __('<pre>
[column_content type="one_fourth"]
	Column 1 Content goes here...
[/column_content]

[column_content type="one_fourth"]
	Column 2 Content goes here...
[/column_content]

[column_content type="one_fourth"]
	Column 3 Content goes here...
[/column_content]

[column_content type="one_fourth_last"]
	Column 4 Content goes here...
[/column_content]
</pre>', 'creator-world-pro'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('5 Column Content', 'creator-world-pro'),
		'desc' => __('<pre>
[column_content type="one_fifth"]
	Column 1 Content goes here...
[/column_content]

[column_content type="one_fifth"]
	Column 2 Content goes here...
[/column_content]

[column_content type="one_fifth"]
	Column 3 Content goes here...
[/column_content]

[column_content type="one_fifth"]
	Column 4 Content goes here...
[/column_content]

[column_content type="one_fifth_last"]
	Column 5 Content goes here...
[/column_content]
</pre>', 'creator-world-pro'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('Tabs', 'creator-world-pro'),
		'desc' => __('<pre>
[tabs]
	[tab title="TAB TITLE 1"]
		TAB CONTENT 1
	[/tab]
	[tab title="TAB TITLE 2"]
		TAB CONTENT 2
	[/tab]
	[tab title="TAB TITLE 3"]
		TAB CONTENT 3
	[/tab]
[/tabs]
</pre>', 'creator-world-pro'),
		'type' => 'info');


	$options[] = array(
		'name' => __('Toggle Content', 'creator-world-pro'),
		'desc' => __('<pre>
[toggle_content title="Toggle Title 1"]
	Toggle content 1...
[/toggle_content]
[toggle_content title="Toggle Title 2"]
	Toggle content 2...
[/toggle_content]
[toggle_content title="Toggle Title 3"]
	Toggle content 3...
[/toggle_content]
</pre>', 'creator-world-pro'),
		'type' => 'info');


	$options[] = array(
		'name' => __('Accordion Content', 'creator-world-pro'),
		'desc' => __('<pre>
[accordion]
	[accordion_content title="ACCORDION TITLE 1"]
		ACCORDION CONTENT 1
	[/accordion_content]
	[accordion_content title="ACCORDION TITLE 2"]
		ACCORDION CONTENT 2
	[/accordion_content]
	[accordion_content title="ACCORDION TITLE 3"]
		ACCORDION CONTENT 3
	[/accordion_content]
[/accordion]
</pre>', 'creator-world-pro'),
		'type' => 'info');
		
	$options[] = array(
		'name' => __('Clear', 'creator-world-pro'),
		'desc' => __('<pre>
[clear]
</pre>', 'creator-world-pro'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('HR / Horizontal separation line', 'creator-world-pro'),
		'desc' => __('<pre>
[hr] or &lt;hr&gt;
</pre>', 'creator-world-pro'),
		'type' => 'info');
	
	$options[] = array(
		'name' => __('Scroll to Top', 'creator-world-pro'),
		'desc' => __('[back-to-top] 
', 'creator-world-pro'),
		'type' => 'info');

	// Support					
	$options[] = array(
		'name' => __('Our Themes', 'creator-world-pro'),
		'type' => 'heading');

	$options[] = array(
		'desc' => __(' Creator World Pro WordPress theme has been Designed and Created by <a href="'.esc_url('https://gracethemes.com/').'" target="_blank">Grace Themes</a>', 'creator-world-pro'),
		'type' => 'info');	

	 $options[] = array(
		'desc' => __('<a href="'.esc_url('https://gracethemes.com/').'" target="_blank"><img src="'.get_template_directory_uri().'/images/themesbunch.jpg"></a>', 'creator-world-pro'),
		'type' => 'info');	

	return $options;
}