<?php 
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 */ 

function optionsframework_option_name() {
	// Change this to use your theme slug
	$themename = wp_get_theme();
	$themename = preg_replace("/\W/", "_", strtolower($themename) );
	return $themename;
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 *
 * If you are making your theme translatable, you should replace 'eaterstop-pro'
 * with the actual text domain for your theme.  Read more:
 * http://codex.wordpress.org/Function_Reference/load_theme_textdomain
*/

function optionsframework_options() {
	//array of all custom font types.
	$font_types = array( '' => '',
    'ABeeZee' => 'ABeeZee',
    'Abel' => 'Abel',
    'Abril Fatface' => 'Abril Fatface',
    'Aclonica' => 'Aclonica',
    'Acme' => 'Acme',
    'Actor' => 'Actor',
    'Adamina' => 'Adamina',
    'Advent Pro' => 'Advent Pro',
    'Aguafina Script' => 'Aguafina Script',
    'Akronim' => 'Akronim',
    'Aladin' => 'Aladin',
    'Aldrich' => 'Aldrich',
    'Alegreya' => 'Alegreya',
    'Alegreya Sans SC' => 'Alegreya Sans SC',
    'Alegreya SC' => 'Alegreya SC',
    'Alex Brush' => 'Alex Brush',
    'Alef' => 'Alef',
    'Alfa Slab One' => 'Alfa Slab One',
    'Alice' => 'Alice',
    'Alike' => 'Alike',
    'Alike Angular' => 'Alike Angular',
    'Allan' => 'Allan',
    'Allerta' => 'Allerta',
    'Allerta Stencil' => 'Allerta Stencil',
    'Allura' => 'Allura',
    'Almendra' => 'Almendra',
    'Almendra Display' => 'Almendra Display',
    'Almendra SC' => 'Almendra SC',
    'Amiri' => 'Amiri',
    'Amarante' => 'Amarante',
    'Amaranth' => 'Amaranth',
    'Amatic SC' => 'Amatic SC',
    'Amethysta' => 'Amethysta',
    'Amita' => 'Amita',
    'Anaheim' => 'Anaheim',
    'Andada' => 'Andada',
    'Andika' => 'Andika',
    'Annie Use Your Telescope' => 'Annie Use Your Telescope',
    'Anonymous Pro' => 'Anonymous Pro',
    'Antic' => 'Antic',
    'Antic Didone' => 'Antic Didone',
    'Antic Slab' => 'Antic Slab',
    'Anton' => 'Anton',
    'Angkor' => 'Angkor',
    'Arapey' => 'Arapey',
    'Arbutus' => 'Arbutus',
    'Arbutus Slab' => 'Arbutus Slab',
    'Architects Daughter' => 'Architects Daughter',
    'Archivo White' => 'Archivo White',
    'Archivo Narrow' => 'Archivo Narrow',
    'Arial' => 'Arial',
    'Arimo' => 'Arimo',
    'Arya' => 'Arya',
    'Arizonia' => 'Arizonia',
    'Armata' => 'Armata',
    'Artifika' => 'Artifika',
    'Arvo' => 'Arvo',
    'Asar' => 'Asar',
    'Asap' => 'Asap',
    'Asset' => 'Asset',
    'Astloch' => 'Astloch',
    'Asul' => 'Asul',
    'Atomic Age' => 'Atomic Age',
    'Aubrey' => 'Aubrey',
    'Audiowide' => 'Audiowide',
    'Autour One' => 'Autour One',
    'Average' => 'Average',
    'Average Sans' => 'Average Sans',
    'Averia Gruesa Libre' => 'Averia Gruesa Libre',
    'Averia Libre' => 'Averia Libre',
    'Averia Sans Libre' => 'Averia Sans Libre',
    'Averia Serif Libre' => 'Averia Serif Libre',
    'Battambang' => 'Battambang',
    'Bad Script' => 'Bad Script',
    'Bayon' => 'Bayon',
    'Balthazar' => 'Balthazar',
    'Bangers' => 'Bangers',
    'Basic' => 'Basic',
    'Baumans' => 'Baumans',
    'Belgrano' => 'Belgrano',
    'Belleza' => 'Belleza',
    'BenchNine' => 'BenchNine',
    'Bentham' => 'Bentham',
    'Berkshire Swash' => 'Berkshire Swash',
    'Bevan' => 'Bevan',
    'Bigelow Rules' => 'Bigelow Rules',
    'Bigshot One' => 'Bigshot One',
    'Bilbo' => 'Bilbo',
    'Bilbo Swash Caps' => 'Bilbo Swash Caps',
    'Biryani' => 'Biryani',
    'Bitter' => 'Bitter',
    'White Ops One' => 'White Ops One',
    'Bokor' => 'Bokor',
    'Bonbon' => 'Bonbon',
    'Boogaloo' => 'Boogaloo',
    'Bowlby One' => 'Bowlby One',
    'Bowlby One SC' => 'Bowlby One SC',
    'Brawler' => 'Brawler',
    'Bree Serif' => 'Bree Serif',
    'Bubblegum Sans' => 'Bubblegum Sans',
    'Bubbler One' => 'Bubbler One',
    'Buda' => 'Buda',
    'Buenard' => 'Buenard',
    'Butcherman' => 'Butcherman',
    'Butcherman Caps' => 'Butcherman Caps',
    'Butterfly Kids' => 'Butterfly Kids',
    'Cabin' => 'Cabin',
    'Cabin Condensed' => 'Cabin Condensed',
    'Cabin Sketch' => 'Cabin Sketch',
    'Cabin' => 'Cabin',
    'Caesar Dressing' => 'Caesar Dressing',
    'Cagliostro' => 'Cagliostro',
    'Calligraffitti' => 'Calligraffitti',
    'Cambay' => 'Cambay',
    'Cambo' => 'Cambo',
    'Candal' => 'Candal',
    'Cantarell' => 'Cantarell',
    'Cantata One' => 'Cantata One',
    'Cantora One' => 'Cantora One',
    'Capriola' => 'Capriola',
    'Cardo' => 'Cardo',
    'Carme' => 'Carme',
    'Carrois Gothic' => 'Carrois Gothic',
    'Carrois Gothic SC' => 'Carrois Gothic SC',
    'Carter One' => 'Carter One',
    'Caveat' => 'Caveat',
    'Caveat Brush' => 'Caveat Brush',
    'Catamaran' => 'Catamaran',
    'Caudex' => 'Caudex',
    'Cedarville Cursive' => 'Cedarville Cursive',
    'Ceviche One' => 'Ceviche One',
    'Changa One' => 'Changa One',
    'Chango' => 'Chango',
    'Chau Philomene One' => 'Chau Philomene One',
    'Chenla' => 'Chenla',
    'Chela One' => 'Chela One',
    'Chelsea Market' => 'Chelsea Market',
    'Cherry Cream Soda' => 'Cherry Cream Soda',
    'Cherry Swash' => 'Cherry Swash',
    'Chewy' => 'Chewy',
    'Chicle' => 'Chicle',
    'Chivo' => 'Chivo',
    'Chonburi' => 'Chonburi',
    'Cinzel' => 'Cinzel',
    'Cinzel Decorative' => 'Cinzel Decorative',
    'Clicker Script' => 'Clicker Script',
    'Coda' => 'Coda',
    'Codystar' => 'Codystar',
    'Combo' => 'Combo',
    'Comfortaa' => 'Comfortaa',
    'Coming Soon' => 'Coming Soon',
    'Condiment' => 'Condiment',
    'Content' => 'Content',
    'Contrail One' => 'Contrail One',
    'Convergence' => 'Convergence',
    'Cookie' => 'Cookie',
    'Comic Sans MS' => 'Comic Sans MS',
    'Copse' => 'Copse',
    'Corben' => 'Corben',
    'Courgette' => 'Courgette',
    'Cousine' => 'Cousine',
    'Coustard' => 'Coustard',
    'Covered By Your Grace' => 'Covered By Your Grace',
    'Crafty Girls' => 'Crafty Girls',
    'Creepster' => 'Creepster',
    'Creepster Caps' => 'Creepster Caps',
    'Crete Round' => 'Crete Round',
    'Crimson' => 'Crimson',
    'Croissant One' => 'Croissant One',
    'Crushed' => 'Crushed',
    'Cuprum' => 'Cuprum',
    'Cutive' => 'Cutive',
    'Cutive Mono' => 'Cutive Mono',
    'Damion' => 'Damion',
    'Dangrek' => 'Dangrek',
    'Dancing Script' => 'Dancing Script',
    'Dawning of a New Day' => 'Dawning of a New Day',
    'Days One' => 'Days One',
    'Dekko' => 'Dekko',
    'Delius' => 'Delius',
    'Delius Swash Caps' => 'Delius Swash Caps',
    'Delius Unicase' => 'Delius Unicase',
    'Della Respira' => 'Della Respira',
    'Denk One' => 'Denk One',
    'Devonshire' => 'Devonshire',
    'Dhurjati' => 'Dhurjati',
    'Didact Gothic' => 'Didact Gothic',
    'Diplomata' => 'Diplomata',
    'Diplomata SC' => 'Diplomata SC',
    'Domine' => 'Domine',
    'Donegal One' => 'Donegal One',
    'Doppio One' => 'Doppio One',
    'Dorsa' => 'Dorsa',
    'Dosis' => 'Dosis',
    'Dr Sugiyama' => 'Dr Sugiyama',
    'Droid Sans' => 'Droid Sans',
    'Droid Sans Mono' => 'Droid Sans Mono',
    'Droid Serif' => 'Droid Serif',
    'Duru Sans' => 'Duru Sans',
    'Dynalight' => 'Dynalight',
    'EB Garamond' => 'EB Garamond',
    'Eczar' => 'Eczar',
    'Eagle Lake' => 'Eagle Lake',
    'Eater' => 'Eater',
    'Eater Caps' => 'Eater Caps',
    'Economica' => 'Economica',
    'Ek Mukta' => 'Ek Mukta',
    'Electrolize' => 'Electrolize',
    'Elsie' => 'Elsie',
    'Elsie Swash Caps' => 'Elsie Swash Caps',
    'Emblema One' => 'Emblema One',
    'Emilys Candy' => 'Emilys Candy',
    'Engagement' => 'Engagement',
    'Englebert' => 'Englebert',
    'Enriqueta' => 'Enriqueta',
    'Erica One' => 'Erica One',
    'Esteban' => 'Esteban',
    'Euphoria Script' => 'Euphoria Script',
    'Ewert' => 'Ewert',
    'Exo' => 'Exo',
    'Exo 2' => 'Exo 2',
    'Expletus Sans' => 'Expletus Sans',
    'Fanwood Text' => 'Fanwood Text',
    'Fascinate' => 'Fascinate',
    'Fascinate Inline' => 'Fascinate Inline',
    'Fasthand' => 'Fasthand',
    'Faster One' => 'Faster One',
    'Federant' => 'Federant',
    'Federo' => 'Federo',
    'Felipa' => 'Felipa',
    'Fenix' => 'Fenix',
    'Finger Paint' => 'Finger Paint',
    'Fira Mono' => 'Fira Mono',
    'Fira Sans' => 'Fira Sans',
    'Fjalla One' => 'Fjalla One',
    'Fjord One' => 'Fjord One',
    'Flamenco' => 'Flamenco',
    'Flavors' => 'Flavors',
    'Fondamento' => 'Fondamento',
    'Fontdiner Swanky' => 'Fontdiner Swanky',
    'Forum' => 'Forum',
    'Francois One' => 'Francois One',
    'FreeSans' => 'FreeSans',

    'Freckle Face' => 'Freckle Face',
    'Fredericka the Great' => 'Fredericka the Great',
    'Fredoka One' => 'Fredoka One',
    'Fresca' => 'Fresca',
    'Freehand' => 'Freehand',
    'Frijole' => 'Frijole',
    'Fruktur' => 'Fruktur',
    'Fugaz One' => 'Fugaz One',
    'Gafata' => 'Gafata',
    'Galdeano' => 'Galdeano',
    'Galindo' => 'Galindo',
    'Gentium Basic' => 'Gentium Basic',
    'Gentium Book Basic' => 'Gentium Book Basic',
    'Geo' => 'Geo',
    'Georgia' => 'Georgia',
    'Geostar' => 'Geostar',
    'Geostar Fill' => 'Geostar Fill',
    'Germania One' => 'Germania One',
    'Gilda Display' => 'Gilda Display',
    'Give You Glory' => 'Give You Glory',
    'Glass Antiqua' => 'Glass Antiqua',
    'Glegoo' => 'Glegoo',
    'Gloria Hallelujah' => 'Gloria Hallelujah',
    'Goblin One' => 'Goblin One',
    'Gochi Hand' => 'Gochi Hand',
    'Gorditas' => 'Gorditas',
    'Gurajada' => 'Gurajada',
    'Goudy Bookletter 1911' => 'Goudy Bookletter 1911',
    'Graduate' => 'Graduate',
    'Grand Hotel' => 'Grand Hotel',
    'Gravitas One' => 'Gravitas One',
    'Great Vibes' => 'Great Vibes',
    'Griffy' => 'Griffy',
    'Gruppo' => 'Gruppo',
    'Gudea' => 'Gudea',
    'Gidugu' => 'Gidugu',
    'GFS Didot' => 'GFS Didot',
    'GFS Neohellenic' => 'GFS Neohellenic',
    'Habibi' => 'Habibi',
    'Hammersmith One' => 'Hammersmith One',
    'Halant' => 'Halant',
    'Hanalei' => 'Hanalei',
    'Hanalei Fill' => 'Hanalei Fill',
    'Handlee' => 'Handlee',
    'Hanuman' => 'Hanuman',
    'Happy Monkey' => 'Happy Monkey',
    'Headland One' => 'Headland One',
    'Henny Penny' => 'Henny Penny',
    'Herr Von Muellerhoff' => 'Herr Von Muellerhoff',
    'Hind' => 'Hind',
    'Hind Siliguri' => 'Hind Siliguri',
    'Hind Vadodara' => 'Hind Vadodara',
    'Holtwood One SC' => 'Holtwood One SC',
    'Homemade Apple' => 'Homemade Apple',
    'Homenaje' => 'Homenaje',
    'IM Fell' => 'IM Fell',
    'Itim' => 'Itim',
    'Iceberg' => 'Iceberg',
    'Iceland' => 'Iceland',
    'Imprima' => 'Imprima',
    'Inconsolata' => 'Inconsolata',
    'Inder' => 'Inder',
    'Indie Flower' => 'Indie Flower',
    'Inknut Antiqua' => 'Inknut Antiqua',
    'Inika' => 'Inika',
    'Irish Growler' => 'Irish Growler',
    'Istok Web' => 'Istok Web',
    'Italiana' => 'Italiana',
    'Italianno' => 'Italianno',
    'Jacques Francois' => 'Jacques Francois',
    'Jacques Francois Shadow' => 'Jacques Francois Shadow',
    'Jim Nightshade' => 'Jim Nightshade',
    'Jockey One' => 'Jockey One',
    'Jaldi' => 'Jaldi',
    'Jolly Lodger' => 'Jolly Lodger',
    'Josefin Sans' => 'Josefin Sans',
    'Josefin Sans' => 'Josefin Sans',
    'Josefin Slab' => 'Josefin Slab',
    'Joti One' => 'Joti One',
    'Judson' => 'Judson',
    'Julee' => 'Julee',
    'Julius Sans One' => 'Julius Sans One',
    'Junge' => 'Junge',
    'Jura' => 'Jura',
    'Just Another Hand' => 'Just Another Hand',
    'Just Me Again Down Here' => 'Just Me Again Down Here',
    'Kadwa' => 'Kadwa',
    'Kdam Thmor' => 'Kdam Thmor',
    'Kalam' => 'Kalam', 
    'Kameron' => 'Kameron',
    'Kantumruy' => 'Kantumruy',
    'Karma' => 'Karma',
    'Karla' => 'Karla',
    'Kaushan Script' => 'Kaushan Script',
    'Kavoon' => 'Kavoon',
    'Keania One' => 'Keania One',
    'Kelly Slab' => 'Kelly Slab',
    'Kenia' => 'Kenia',
    'Khand' => 'Khand',
    'Khmer' => 'Khmer',
    'Khula' => 'Khula',
    'Kite One' => 'Kite One',
    'Knewave' => 'Knewave',
    'Kotta One' => 'Kotta One',
    'Kranky' => 'Kranky',
    'Kreon' => 'Kreon',
    'Kristi' => 'Kristi',
    'Koulen' => 'Koulen',
    'Krona One' => 'Krona One',
    'Kurale' => 'Kurale',
    'Lakki Reddy' => 'Lakki Reddy',
    'La Belle Aurore' => 'La Belle Aurore',
    'Lancelot' => 'Lancelot',
    'Laila' => 'Laila',
    'Lato' => 'Lato',
    'Lateef' => 'Lateef',
    'League Script' => 'League Script',
    'Leckerli One' => 'Leckerli One',
    'Ledger' => 'Ledger',
    'Lekton' => 'Lekton',
    'Lemon' => 'Lemon',

    'Libre Baskerville' => 'Libre Baskerville',
    'Life Savers' => 'Life Savers',
    'Lilita One' => 'Lilita One',
    'Limelight' => 'Limelight',
    'Linden Hill' => 'Linden Hill',
    'Lobster' => 'Lobster',
    'Lobster Two' => 'Lobster Two',
    'Londrina Outline' => 'Londrina Outline',
    'Londrina Shadow' => 'Londrina Shadow',
    'Londrina Sketch' => 'Londrina Sketch',
    'Londrina Solid' => 'Londrina Solid',
    'Lora' => 'Lora',
    'Love Ya Like A Sister' => 'Love Ya Like A Sister',
    'Loved by the King' => 'Loved by the King',
    'Lovers Quarrel' => 'Lovers Quarrel',
    'Lucida Sans Unicode' => 'Lucida Sans Unicode',
    'Luckiest Guy' => 'Luckiest Guy',
    'Lusitana' => 'Lusitana',
    'Lustria' => 'Lustria',
    'Macondo' => 'Macondo',
    'Macondo Swash Caps' => 'Macondo Swash Caps',
    'Magra' => 'Magra',
    'Maiden Orange' => 'Maiden Orange',
    'Mallanna' => 'Mallanna',
    'Mandali' => 'Mandali',
    'Mako' => 'Mako',
    'Marcellus' => 'Marcellus',
    'Marcellus SC' => 'Marcellus SC',
    'Marck Script' => 'Marck Script',
    'Margarine' => 'Margarine',
    'Marko One' => 'Marko One',
    'Marmelad' => 'Marmelad',
    'Marvel' => 'Marvel',
    'Martel' => 'Martel',
    'Martel Sans' => 'Martel Sans',
    'Mate' => 'Mate',
    'Mate SC' => 'Mate SC',
    'Maven Pro' => 'Maven Pro',
    'McLaren' => 'McLaren',
    'Meddon' => 'Meddon',
    'MedievalSharp' => 'MedievalSharp',
    'Medula One' => 'Medula One',
    'Megrim' => 'Megrim',
    'Meie Script' => 'Meie Script',
    'Merienda' => 'Merienda',
    'Merienda One' => 'Merienda One',
    'Merriweather' => 'Merriweather',
    'Metal' => 'Metal',
    'Metal Mania' => 'Metal Mania',
    'Metamorphous' => 'Metamorphous',
    'Metrophobic' => 'Metrophobic',
    'Michroma' => 'Michroma',
    'Milonga' => 'Milonga',
    'Miltonian' => 'Miltonian',
    'Miltonian Tattoo' => 'Miltonian Tattoo',
    'Miniver' => 'Miniver',
    'Miss Fajardose' => 'Miss Fajardose',
    'Miss Saint Delafield' => 'Miss Saint Delafield',
    'Modak' => 'Modak',
    'Modern Antiqua' => 'Modern Antiqua',
    'Molengo' => 'Molengo',
    'Molle' => 'Molle',
    'Moulpali' => 'Moulpali',
    'Monda' => 'Monda',
    'Monofett' => 'Monofett',
    'Monoton' => 'Monoton',
    'Monsieur La Doulaise' => 'Monsieur La Doulaise',
    'Montaga' => 'Montaga',
    'Montez' => 'Montez',
    'Montserrat' => 'Montserrat',
    'Montserrat Alternates' => 'Montserrat Alternates',
    'Montserrat Subrayada' => 'Montserrat Subrayada',
    'Mountains of Christmas' => 'Mountains of Christmas',
    'Mouse Memoirs' => 'Mouse Memoirs',
    'Moul' => 'Moul',
    'Mr Bedford' => 'Mr Bedford',
    'Mr Bedfort' => 'Mr Bedfort',
    'Mr Dafoe' => 'Mr Dafoe',
    'Mr De Haviland' => 'Mr De Haviland',
    'Mrs Saint Delafield' => 'Mrs Saint Delafield',
    'Mrs Sheppards' => 'Mrs Sheppards',
    'Muli' => 'Muli',
    'Mystery Quest' => 'Mystery Quest',
    'Neucha' => 'Neucha',
    'Neuton' => 'Neuton',
    'New Rocker' => 'New Rocker',
    'News Cycle' => 'News Cycle',
    'Niconne' => 'Niconne',
    'Nixie One' => 'Nixie One',
    'Nobile' => 'Nobile',
    'Nokora' => 'Nokora',
    'Norican' => 'Norican',
    'Nosifer' => 'Nosifer',
    'Nosifer Caps' => 'Nosifer Caps',
    'Nova Mono' => 'Nova Mono',
    'Noticia Text' => 'Noticia Text',
    'Noto Sans' => 'Noto Sans',
    'Noto Serif' => 'Noto Serif',
    'Nova Round' => 'Nova Round',
    'Numans' => 'Numans',
    'Nunito' => 'Nunito',
    'NTR' => 'NTR',
    'Offside' => 'Offside',
    'Oldenburg' => 'Oldenburg',
    'Oleo Script' => 'Oleo Script',
    'Oleo Script Swash Caps' => 'Oleo Script Swash Caps',
    'Open Sans' => 'Open Sans',
    'Open Sans Condensed' => 'Open Sans Condensed',
    'Oranienbaum' => 'Oranienbaum',
    'Orbitron' => 'Orbitron',
    'Odor Mean Chey' => 'Odor Mean Chey',
    'Oregano' => 'Oregano',
    'Orienta' => 'Orienta',
    'Original Surfer' => 'Original Surfer',
    'Oswald' => 'Oswald',
    'Over the Rainbow' => 'Over the Rainbow',
    'Overlock' => 'Overlock',
    'Overlock SC' => 'Overlock SC',
    'Ovo' => 'Ovo',
    'Oxygen' => 'Oxygen',
    'Oxygen Mono' => 'Oxygen Mono',
    'Palanquin Dark' => 'Palanquin Dark',
    'Peddana' => 'Peddana',
    'Poppins' => 'Poppins',
    'PT Mono' => 'PT Mono',
    'PT Sans' => 'PT Sans',
    'PT Sans Caption' => 'PT Sans Caption',
    'PT Sans Narrow' => 'PT Sans Narrow',
    'PT Serif' => 'PT Serif',
    'PT Serif Caption' => 'PT Serif Caption',
    'Pacifico' => 'Pacifico',
    'Paprika' => 'Paprika',
    'Parisienne' => 'Parisienne',
    'Passero One' => 'Passero One',
    'Passion One' => 'Passion One',
    'Patrick Hand' => 'Patrick Hand',
    'Patrick Hand SC' => 'Patrick Hand SC',
    'Patua One' => 'Patua One',
    'Paytone One' => 'Paytone One',
    'Peralta' => 'Peralta',
    'Permanent Marker' => 'Permanent Marker',
    'Petit Formal Script' => 'Petit Formal Script',
    'Petrona' => 'Petrona',
    'Philosopher' => 'Philosopher',
    'Piedra' => 'Piedra',
    'Pinyon Script' => 'Pinyon Script',
    'Pirata One' => 'Pirata One',
    'Plaster' => 'Plaster',
    'Palatino Linotype' => 'Palatino Linotype',
    'Play' => 'Play',
    'Playball' => 'Playball',
    'Playfair Display' => 'Playfair Display',
    'Playfair Display SC' => 'Playfair Display SC',
    'Podkova' => 'Podkova',
    'Poiret One' => 'Poiret One',
    'Poller One' => 'Poller One',
    'Poly' => 'Poly',
    'Pompiere' => 'Pompiere',
    'Pontano Sans' => 'Pontano Sans',
    'Port Lligat Sans' => 'Port Lligat Sans',
    'Port Lligat Slab' => 'Port Lligat Slab',
    'Prata' => 'Prata',
    'Pragati Narrow' => 'Pragati Narrow',
    'Preahvihear' => 'Preahvihear',
    'Press Start 2P' => 'Press Start 2P',
    'Princess Sofia' => 'Princess Sofia',
    'Prociono' => 'Prociono',
    'Prosto One' => 'Prosto One',
    'Puritan' => 'Puritan',
    'Purple Purse' => 'Purple Purse',
    'Quando' => 'Quando',
    'Quantico' => 'Quantico',
    'Quattrocento' => 'Quattrocento',
    'Quattrocento Sans' => 'Quattrocento Sans',
    'Questrial' => 'Questrial',
    'Quicksand' => 'Quicksand',
    'Quintessential' => 'Quintessential',
    'Qwigley' => 'Qwigley',
    'Racing Sans One' => 'Racing Sans One',
    'Radley' => 'Radley',
    'Rajdhani' => 'Rajdhani',
    'Raleway Dots' => 'Raleway Dots',
    'Raleway' => 'Raleway',
    'Rambla' => 'Rambla',
    'Ramabhadra' => 'Ramabhadra',
    'Ramaraja' => 'Ramaraja',
    'Rammetto One' => 'Rammetto One',
    'Ranchers' => 'Ranchers',
    'Rancho' => 'Rancho',
    'Ranga' => 'Ranga',
    'Ravi Prakash' => 'Ravi Prakash',
    'Rationale' => 'Rationale',
    'Redressed' => 'Redressed',
    'Reenie Beanie' => 'Reenie Beanie',
    'Revalia' => 'Revalia',
    'Rhodium Libre' => 'Rhodium Libre',
    'Ribeye' => 'Ribeye',
    'Ribeye Marrow' => 'Ribeye Marrow',
    'Righteous' => 'Righteous',
    'Risque' => 'Risque',
    'Roboto' => 'Roboto',
    'Roboto Condensed' => 'Roboto Condensed',
    'Roboto Mono' => 'Roboto Mono',
    'Roboto Slab' => 'Roboto Slab',
    'Rochester' => 'Rochester',
    'Rock Salt' => 'Rock Salt',
    'Rokkitt' => 'Rokkitt',
    'Romanesco' => 'Romanesco',
    'Ropa Sans' => 'Ropa Sans',
    'Rosario' => 'Rosario',
    'Rosarivo' => 'Rosarivo',
    'Rouge Script' => 'Rouge Script',
    'Rozha One' => 'Rozha One',
    'Rubik' => 'Rubik',
    'Rubik One' => 'Rubik One',
    'Rubik Mono One' => 'Rubik Mono One',
    'Ruda' => 'Ruda',
    'Rufina' => 'Rufina',
    'Ruge Boogie' => 'Ruge Boogie',
    'Ruluko' => 'Ruluko',
    'Rum Raisin' => 'Rum Raisin',
    'Ruslan Display' => 'Ruslan Display',
    'Russo One' => 'Russo One',
    'Ruthie' => 'Ruthie',
    'Rye' => 'Rye',
    'Sacramento' => 'Sacramento',
    'Sail' => 'Sail',
    'Salsa' => 'Salsa',
    'Sanchez' => 'Sanchez',
    'Sancreek' => 'Sancreek',
    'Sahitya' => 'Sahitya',
    'Sansita One' => 'Sansita One',
    'Sarpanch' => 'Sarpanch',
    'Sarina' => 'Sarina',
    'Satisfy' => 'Satisfy',
    'Scada' => 'Scada',
    'Scheherazade' => 'Scheherazade',
    'Schoolbell' => 'Schoolbell',
    'Seaweed Script' => 'Seaweed Script',
    'Sarala' => 'Sarala',
    'Sevillana' => 'Sevillana',
    'Seymour One' => 'Seymour One',
    'Shadows Into Light' => 'Shadows Into Light',
    'Shadows Into Light Two' => 'Shadows Into Light Two',
    'Shanti' => 'Shanti',
    'Share' => 'Share',
    'Share Tech' => 'Share Tech',
    'Share Tech Mono' => 'Share Tech Mono',
    'Shojumaru' => 'Shojumaru',
    'Short Stack' => 'Short Stack',
    'Sigmar One' => 'Sigmar One',
    'Suranna' => 'Suranna',
    'Suravaram' => 'Suravaram',
    'Suwannaphum' => 'Suwannaphum',
    'Signika' => 'Signika',
    'Signika Negative' => 'Signika Negative',
    'Simonetta' => 'Simonetta',
    'Siemreap' => 'Siemreap',
    'Sirin Stencil' => 'Sirin Stencil',
    'Six Caps' => 'Six Caps',
    'Skranji' => 'Skranji',
    'Slackey' => 'Slackey',
    'Smokum' => 'Smokum',
    'Smythe' => 'Smythe',
    'Sniglet' => 'Sniglet',
    'Snippet' => 'Snippet',
    'Snowburst One' => 'Snowburst One',
    'Sofadi One' => 'Sofadi One',
    'Sofia' => 'Sofia',
    'Sonsie One' => 'Sonsie One',
    'Sorts Mill Goudy' => 'Sorts Mill Goudy',
    'Sorts Mill Goudy' => 'Sorts Mill Goudy',
    'Source Code Pro' => 'Source Code Pro',
    'Source Sans Pro' => 'Source Sans Pro',
    'Special I am one' => 'Special I am one',
    'Spicy Rice' => 'Spicy Rice',
    'Spinnaker' => 'Spinnaker',
    'Spirax' => 'Spirax',
    'Squada One' => 'Squada One',
    'Sree Krushnadevaraya' => 'Sree Krushnadevaraya',
    'Stalemate' => 'Stalemate',
    'Stalinist One' => 'Stalinist One',
    'Stardos Stencil' => 'Stardos Stencil',
    'Stint Ultra Condensed' => 'Stint Ultra Condensed',
    'Stint Ultra Expanded' => 'Stint Ultra Expanded',
    'Stoke' => 'Stoke',
    'Stoke' => 'Stoke',
    'Strait' => 'Strait',
    'Sura' => 'Sura',
    'Sumana' => 'Sumana',
    'Sue Ellen Francisco' => 'Sue Ellen Francisco',
    'Sunshiney' => 'Sunshiney',
    'Supermercado One' => 'Supermercado One',
    'Swanky and Moo Moo' => 'Swanky and Moo Moo',
    'Syncopate' => 'Syncopate',
    'Symbol' => 'Symbol',
    'Timmana' => 'Timmana',
    'Taprom' => 'Taprom',
    'Tangerine' => 'Tangerine',
    'Tahoma' => 'Tahoma',
    'Teko' => 'Teko',
    'Telex' => 'Telex',
    'Tenali Ramakrishna' => 'Tenali Ramakrishna',
    'Tenor Sans' => 'Tenor Sans',
    'Terminal Dosis' => 'Terminal Dosis',
    'Terminal Dosis Light' => 'Terminal Dosis Light',
    'Text Me One' => 'Text Me One',
    'The Girl Next Door' => 'The Girl Next Door',
    'Tienne' => 'Tienne',
    'Tillana' => 'Tillana',
    'Tinos' => 'Tinos',
    'Titan One' => 'Titan One',
    'Titillium Web' => 'Titillium Web',
    'Trade Winds' => 'Trade Winds',
    'Trebuchet MS' => 'Trebuchet MS',
    'Trocchi' => 'Trocchi',
    'Trochut' => 'Trochut',
    'Trykker' => 'Trykker',
    'Tulpen One' => 'Tulpen One',
    'Ubuntu' => 'Ubuntu',
    'Ubuntu Condensed' => 'Ubuntu Condensed',
    'Ubuntu Mono' => 'Ubuntu Mono',
    'Ultra' => 'Ultra',
    'Uncial Antiqua' => 'Uncial Antiqua',
    'Underdog' => 'Underdog',
    'Unica One' => 'Unica One',
    'UnifrakturCook' => 'UnifrakturCook',
    'UnifrakturMaguntia' => 'UnifrakturMaguntia',
    'Unkempt' => 'Unkempt',
    'Unlock' => 'Unlock',
    'Unna' => 'Unna',
    'VT323' => 'VT323',
    'Vampiro One' => 'Vampiro One',
    'Varela' => 'Varela',
    'Varela Round' => 'Varela Round',
    'Vast Shadow' => 'Vast Shadow',
    'Vesper Libre' => 'Vesper Libre',
    'Verdana' => 'Verdana',
    'Vibur' => 'Vibur',
    'Vidaloka' => 'Vidaloka',
    'Viga' => 'Viga',
    'Voces' => 'Voces',
    'Volkhov' => 'Volkhov',
    'Vollkorn' => 'Vollkorn',
    'Voltaire' => 'Voltaire',
    'Waiting for the Sunrise' => 'Waiting for the Sunrise',
    'Wallpoet' => 'Wallpoet',
    'Walter Turncoat' => 'Walter Turncoat',
    'Warnes' => 'Warnes',
    'Wellfleet' => 'Wellfleet',
    'Wendy One' => 'Wendy One',
    'Wire One' => 'Wire One',
    'Yanone Kaffeesatz' => 'Yanone Kaffeesatz',
    'Yantramanav' => 'Yantramanav',
    'Yellowtail' => 'Yellowtail',
    'Yeseva One' => 'Yeseva One',
    'Yesteryear' => 'Yesteryear',
    'Zeyada' => 'Zeyada'
  );

	//array of all font sizes.
	$font_sizes = array( 
		'10px' => '10px',
		'11px' => '11px',
	);
	
	$options = array();
	$imagepath =  get_template_directory_uri() . '/images/';

	
	for($n=12;$n<=200;$n+=1){
		$font_sizes[$n.'px'] = $n.'px';
	}
	
	// Pull all the pages into an array
	 $options_pages = array();
	 $options_pages_obj = get_pages('sort_column=post_parent,menu_order');
	 $options_pages[''] = 'Select a page:';
	 foreach ($options_pages_obj as $page) {
	  $options_pages[$page->ID] = $page->post_title;
	 }

	// array of section content.
	$section_text = array(
	
		 1 => array(
			'section_title'	=> 'Our Menus',
			'menutitle'		=> 'menusection',
			'bgcolor' 		=> '#ffffff',
			'bgimage'		=> get_template_directory_uri().'/images/menubg.jpg',
			'class'			=> 'ourmenuwrap',
			'content'		=> '[ourmenu show="6" filter="true"] ',
		 ),	
		 
		 2 => array(
			'section_title'	=> '',
			'menutitle'		=> 'aboutsection',
			'bgcolor' 		=> '#FCFCFC',
			'bgimage'		=> '',
			'class'			=> 'about-wrap',
			'content'		=> '[column_content type="one_half"]<img src="'.get_template_directory_uri().'/images/chefphoto.jpg" alt="" />[/column_content]

[column_content type="one_half_last"]<h2 class="section_title">Welcome to Eaterstop</h2> Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean commodo ligula eget dolor. Aenean massa fringilla vel, aliquet nec, vulputate eget, arcu.In enim justo, vulputate eget, arcu.In enim justo, rhoncus consectetuer adipiscing  rhoncus consectetuer adipiscing elit.

<p>Nulla consequat massa quis enim.Donec pede justo, fringilla vel, aliquet nec, vulputate eget, arcu.In enim justo, rhoncus ut, imperdiet a, venenatis vitae, justo. Nullam dictum felis eu pede mollis pretium.Integer tincidunt. Cras dapibus. Nulla consequat massa quis enim.Donec pede justo, fringilla vel, aliquet nec, vulputate eget, arcu.In enim justo, rhoncus ut, imperdiet a, venenatis vitae, justo. Nullam dictum felis eu pede mollis pretium.Integer tincidunt. Cras dapibus. Vivamus elementum semper nisi.Aenean vulputate eleifend tellus consectetuer adipiscing Cras dapibus. Vivamus elementum semper nisi.</p>
<p> Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean commodo ligula eget dolor. Aenean massa fringilla vel, aliquet nec, vulputate eget, arcu.In enim justo, rhoncus consectetuer vulputate eget, arcu.In enim justo, rhoncus consectetuer adipiscing  adipiscing elit.</p><a class="rdmore" href="#">Read More &raquo;</a>[/column_content]'
		),
		 
		 3 => array(
			'section_title'	=> 'Our Experts',
			'menutitle'		=> 'teamsection',
			'bgcolor' 		=> '',
			'bgimage'		=> get_template_directory_uri().'/images/counterbg.jpg',
			'class'			=> 'serviceswrap',
			'content'		=> '[our-staff show="4"] ',
		),	
		
		4 => array(
			'section_title'	=> 'Fresh And Fast Food Chain',
			'menutitle'		=> 'themefeaturd',
			'bgcolor' 		=> '#FCFCFC',
			'bgimage'		=> '',
			'class'			=> 'feature-wrap',
			'content'		=> '[column_content type="frdbox"]<div class="foodthumb"><img src="'.get_template_directory_uri().'/images/menu1.jpg" alt="" /></div><h4>Pepper Steak</h4>A delicious meal, served with boiled white rice. arcu.In enim justo, rhoncus consectetuer adipiscing elit.[/column_content][column_content type="frdbox"]<div class="foodthumb"><img src="'.get_template_directory_uri().'/images/menu2.jpg" alt="" /></div><h4>Cream Soup</h4>This cheesy vegetable soup is a meal in its self. arcu.In enim consectetuer adipiscing justo, rhoncus consectetuer adipiscing elit.[/column_content][column_content type="frdbox last"]<div class="foodthumb"><img src="'.get_template_directory_uri().'/images/menu3.jpg" alt="" /></div><h4>Chili Sauce</h4>This sauce is a great substitute for bottled chili sauce.In enim consectetuer inui justo, rhoncus consectetuer adipiscing elit.[/column_content][column_content type="frdbox"]<div class="foodthumb"><img src="'.get_template_directory_uri().'/images/menu4.jpg" alt="" /></div><h4>Garlic sauce</h4>This sauce is great on steak and chips. Lorem ipsum dolor sitiniumdero lucudia enim justo, rhoncus consectetuer adipiscing elit.[/column_content][column_content type="frdbox"]<div class="foodthumb"><img src="'.get_template_directory_uri().'/images/menu5.jpg" alt="" /></div><h4>Calabreza</h4>Calabresa is one of the most common types of sausage in Brazil. Lorem ipsum dolor sit justo, rhoncus consectetuer adipiscing elit.[/column_content][column_content type="frdbox last"]<div class="foodthumb"><img src="'.get_template_directory_uri().'/images/menu6.jpg" alt="" /></div><h4>Filet Mignon</h4>This cheesy vegetable soup is a meal in its self. Lorem ipsum dolor sit enim justo, rhoncus consectetuer adipiscing elit.[/column_content]'
		),	
		
		
		5 => array(
			'section_title'	=> '',
			'menutitle'		=> 'ourskills',
			'bgcolor' 		=> '',
			'bgimage'		=> get_template_directory_uri().'/images/counterbg.jpg',
			'class'			=> 'skillwraps',
			'content'		=> '[counter iconname="group" value="9560" title="Our Staff"][counter iconname="gift" value="9560" title="Lucky Visitor"][counter iconname="list" value="9560" title="Our Clients List"] [counter iconname="graduation-cap" value="560" title="Our Awards"]'
		),
		
		
		6 => array(
			'section_title'	=> 'Latest News',
			'menutitle'		=> 'newswraper',
			'bgcolor' 		=> '',
			'bgimage'		=> '',
			'class'			=> 'newspostwrap',
			'content'		=> '[latest-news showposts="4" comment="show" date="show" author="show"]',
		),		

		
		7 => array(
			'section_title'	=> 'Clients Testimonials',
			'menutitle'		=> 'testimonialswrap',
			'bgcolor' 		=> '',
			'bgimage'		=> get_template_directory_uri().'/images/testimonialsbg.jpg',
			'class'			=> 'tmnlwrapper',
			'content'		=> '[testimonials]'
		),
		
		8 => array(
			'section_title'	=> 'Our Gallery',
			'menutitle'		=> 'home-gallery',
			'bgcolor' 		=> '#f5f4f4',
			'bgimage'		=> '',
			'class'			=> 'gallerywrap',
			'content'		=> '[photogallery filter="true"]',
		),
		
		9 => array(
			'section_title'	=> 'View Recipe',
			'menutitle'		=> 'ourclients',
			'bgcolor' 		=> '',
			'bgimage'		=> '',			
			'class'			=> 'client-wrap',
			'content'		=> '[racipe_lists][racipe title="Company Name" image="'.get_template_directory_uri().'/images/menu6.jpg" link="#" target="_blank"][racipe title="Company Name" image="'.get_template_directory_uri().'/images/menu7.jpg" link="#" target="_blank"][racipe title="Company Name" image="'.get_template_directory_uri().'/images/menu8.jpg" link="#" target="_blank"][racipe title="Company Name" image="'.get_template_directory_uri().'/images/menu9.jpg" link="#" target="_blank"][racipe title="Company Name" image="'.get_template_directory_uri().'/images/menu10.jpg" link="#" target="_blank"][racipe title="Company Name" image="'.get_template_directory_uri().'/images/menu11.jpg" link="#" target="_blank"][racipe title="Company Name" image="'.get_template_directory_uri().'/images/menu12.jpg" link="#" target="_blank"][racipe title="Company Name" image="'.get_template_directory_uri().'/images/menu1.jpg" link="#" target="_blank"][/racipe_lists]',
		),			

	);

	$options = array();

	//Basic Settings
	$options[] = array(
		'name' => __('Basic Settings', 'eaterstop-pro'),
		'type' => 'heading');

	$options[] = array(
		'name' => __('Logo', 'eaterstop-pro'),
		'desc' => __('Upload your main logo here', 'eaterstop-pro'),
		'id' => 'logo',
		'class' => '',
		'std'	=> '',
		'type' => 'upload');
	
	$options[] = array(		
		'desc' => __('manage your logo height', 'eaterstop-pro'),
		'id' => 'logoheight',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(	
		'name' => __('Site title & Description', 'eaterstop-pro'),		
		'desc'	=> __('Check To hide site title and description', 'eaterstop-pro'),
		'id'	=> 'hide_titledesc',
		'type'	=> 'checkbox',
		'std'	=> '');		
		
	$options[] = array(	
		'name' => __('Layout Option', 'eaterstop-pro'),		
		'desc'	=> __('Check To View Box Layout ', 'eaterstop-pro'),
		'id'	=> 'boxlayout',
		'type'	=> 'checkbox',
		'std'	=> '');		
		
	$options[] = array(
		'name' => __('Sticky Header', 'eaterstop-pro'),
		'desc' => __('Check this to disable sticky header on scroll', 'eaterstop-pro'),
		'id' => 'headstick',
		'std' => '',
		'type' => 'checkbox');	
		
	$options[] = array(
		'name' => __('Disable Animation', 'eaterstop-pro'),
		'desc' => __('Check this to disable animation on scroll', 'eaterstop-pro'),
		'id' => 'scrollanimation',
		'std' => '',
		'type' => 'checkbox');			

	$options[] = array(
		'name' => __('Custom CSS', 'eaterstop-pro'),
		'desc' => __('Some Custom Styling for your site. Place any css codes here instead of the style.css file.', 'eaterstop-pro'),
		'id' => 'style2',
		'std' => '',
		'type' => 'textarea');
		
	// font family start 
		
	$options[] = array(
		'name' => __('Font Faces', 'eaterstop-pro'),
		'desc' => __('Select font for the body text', 'eaterstop-pro'),
		'id' => 'bodyfontface',
		'type' => 'select',
		'std' => 'Open Sans',
		'options' => $font_types );
		
	$options[] = array(
		'desc' => __('Select font for the textual logo', 'eaterstop-pro'),
		'id' => 'logofontface',
		'type' => 'select',
		'std' => 'Roboto Condensed',
		'options' => $font_types );
		
	$options[] = array(
		'desc' => __('Select font for the navigation text', 'eaterstop-pro'),
		'id' => 'navfontface',
		'type' => 'select',
		'std' => 'Roboto',
		'options' => $font_types );
		
	$options[] = array(
		'desc' => __('Select font family for all heading tag.', 'eaterstop-pro'),
		'id' => 'headfontface',
		'type' => 'select',
		'std' => 'Roboto',
		'options' => $font_types );
			
	$options[] = array(
		'desc' => __('Select font for Slide title', 'eaterstop-pro'),
		'id' => 'slidetitlefontface',
		'type' => 'select',
		'std' => 'Roboto Condensed',
		'options' => $font_types );	
		
	$options[] = array(
		'desc' => __('Select font for Slide Description', 'eaterstop-pro'),
		'id' => 'slidedesfontface',
		'type' => 'select',
		'std' => 'Roboto Condensed',
		'options' => $font_types );	

		
	// font sizes start	
	$options[] = array(
		'name' => __('Font Sizes', 'eaterstop-pro'),
		'desc' => __('Select font size for body text', 'eaterstop-pro'),
		'id' => 'bodyfontsize',
		'type' => 'select',
		'std' => '13px',
		'options' => $font_sizes );
		
	$options[] = array(
		'desc' => __('Select font size for textual logo', 'eaterstop-pro'),
		'id' => 'logofontsize',
		'type' => 'select',
		'std' => '40px',
		'options' => $font_sizes );
		
	$options[] = array(
		'desc' => __('Select font size for navigation', 'eaterstop-pro'),
		'id' => 'navfontsize',
		'type' => 'select',
		'std' => '14px',
		'options' => $font_sizes );	
		
	$options[] = array(
		'desc' => __('Select font size for section title', 'eaterstop-pro'),
		'id' => 'sectitlesize',
		'type' => 'select',
		'std' => '34px',
		'options' => $font_sizes );
		
	$options[] = array(
		'desc' => __('Select font size for footer title', 'eaterstop-pro'),
		'id' => 'ftfontsize',
		'type' => 'select',
		'std' => '20px',
		'options' => $font_sizes );	

	$options[] = array(
		'desc' => __('Select h1 font size', 'eaterstop-pro'),
		'id' => 'h1fontsize',
		'std' => '32px',
		'type' => 'select',
		'options' => $font_sizes);

	$options[] = array(
		'desc' => __('Select h2 font size', 'eaterstop-pro'),
		'id' => 'h2fontsize',
		'std' => '28px',
		'type' => 'select',
		'options' => $font_sizes);

	$options[] = array(
		'desc' => __('Select h3 font size', 'eaterstop-pro'),
		'id' => 'h3fontsize',
		'std' => '18px',
		'type' => 'select',
		'options' => $font_sizes);

	$options[] = array(
		'desc' => __('Select h4 font size', 'eaterstop-pro'),
		'id' => 'h4fontsize',
		'std' => '22px',
		'type' => 'select',
		'options' => $font_sizes);

	$options[] = array(
		'desc' => __('Select h5 font size', 'eaterstop-pro'),
		'id' => 'h5fontsize',
		'std' => '20px',
		'type' => 'select',
		'options' => $font_sizes);

	$options[] = array(
		'desc' => __('Select h6 font size', 'eaterstop-pro'),
		'id' => 'h6fontsize',
		'std' => '14px',
		'type' => 'select',
		'options' => $font_sizes);


	// font colors start

	$options[] = array(
		'name' => __('Font Colors', 'eaterstop-pro'),
		'desc' => __('Select font color for the body text', 'eaterstop-pro'),
		'id' => 'bodyfontcolor',
		'std' => '#555555',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for textual logo', 'eaterstop-pro'),
		'id' => 'logofontcolor',
		'std' => '#d66200',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for logo tagline', 'eaterstop-pro'),
		'id' => 'logotaglinecolor',
		'std' => '#828181',
		'type' => 'color');
		
	

	$options[] = array(
		'desc' => __('Select font color for social icons', 'eaterstop-pro'),
		'id' => 'socialfontcolor',
		'std' => '#a5a5a5',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font hover color for social icons', 'eaterstop-pro'),
		'id' => 'socialfonthvcolor',
		'std' => '#d66200',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for section title', 'eaterstop-pro'),
		'id' => 'sectitlecolor',
		'std' => '#515151',
		'type' => 'color');	
		
	
	$options[] = array(
		'desc' => __('Select font color for navigation', 'eaterstop-pro'),
		'id' => 'navfontcolor',
		'std' => '#515151',
		'type' => 'color');

	$options[] = array(
		'desc' => __('Select font color for navigation hover', 'eaterstop-pro'),
		'id' => 'navhovercolor',
		'std' => '#d66200',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for widget title', 'eaterstop-pro'),
		'id' => 'wdgttitleccolor',
		'std' => '#515151',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for footer title', 'eaterstop-pro'),
		'id' => 'foottitlecolor',
		'std' => '#ffffff',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for footer', 'eaterstop-pro'),
		'id' => 'footdesccolor',
		'std' => '#595959',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for footer menu ', 'eaterstop-pro'),
		'id' => 'footermenucolor',
		'std' => '#d66200',
		'type' => 'color');		
		
	$options[] = array(
		'desc' => __('Select font hover color for footer menu ', 'eaterstop-pro'),
		'id' => 'footermenucurrent',
		'std' => '#8e8d8d',
		'type' => 'color');			
		
	$options[] = array(
		'desc' => __('Select font color for footer left text (copyright)', 'eaterstop-pro'),
		'id' => 'copycolor',
		'std' => '#ffffff',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for footer right text (design by)', 'eaterstop-pro'),
		'id' => 'designcolor',
		'std' => '#ffffff',
		'type' => 'color');

	$options[] = array(
		'desc' => __('Select font color for links / anchor tags', 'eaterstop-pro'),
		'id' => 'linkcolor',
		'std' => '#d66200',
		'type' => 'color');

	$options[] = array(
		'desc' => __('Select font hover color for links / anchor tags', 'eaterstop-pro'),
		'id' => 'linkhovercolor',
		'std' => '#272727',
		'type' => 'color');			
		
	$options[] = array(
		'desc' => __('Select font color for sidebar li a', 'eaterstop-pro'),
		'id' => 'sidebarfontcolor',
		'std' => '#78797c',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font hover color for sidebar li a', 'eaterstop-pro'),
		'id' => 'sidebarfonthvcolor',
		'std' => '#d66200',
		'type' => 'color');			
			
	
	$options[] = array(
		'desc' => __('Select font color for footer links', 'eaterstop-pro'),
		'id' => 'copylinks',
		'std' => '#d66200',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font hover color for footer links', 'eaterstop-pro'),
		'id' => 'copylinkshover',
		'std' => '#ffffff',
		'type' => 'color');	

	$options[] = array(
		'desc' => __('Select h1 font color', 'eaterstop-pro'),
		'id' => 'h1fontcolor',
		'std' => '#515151',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select h2 font color', 'eaterstop-pro'),
		'id' => 'h2fontcolor',
		'std' => '#515151',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select h3 font color', 'eaterstop-pro'),
		'id' => 'h3fontcolor',
		'std' => '#515151',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select h4 font color', 'eaterstop-pro'),
		'id' => 'h4fontcolor',
		'std' => '#515151',
		'type' => 'color');	

	$options[] = array(
		'desc' => __('Select h5 font color', 'eaterstop-pro'),
		'id' => 'h5fontcolor',
		'std' => '#515151',
		'type' => 'color');	

	$options[] = array(
		'desc' => __('Select h6 font color', 'eaterstop-pro'),
		'id' => 'h6fontcolor',
		'std' => '#515151',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for last word colorful for title', 'eaterstop-pro'),
		'id' => 'lastwordcolor',
		'std' => '#d66200',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for counter circle box', 'eaterstop-pro'),
		'id' => 'countercirclecolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for counter circle number', 'eaterstop-pro'),
		'id' => 'countercirclenumber',
		'std' => '#d66200',
		'type' => 'color');	

		
	$options[] = array(
		'desc' => __('Select font color for testimonials title', 'eaterstop-pro'),
		'id' => 'testimonialtitle',
		'std' => '#ffffff',
		'type' => 'color');		
		
	$options[] = array(
		'desc' => __('Select font color for testimonials decription', 'eaterstop-pro'),
		'id' => 'testimonialdesc',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for footer social icons', 'eaterstop-pro'),
		'id' => 'footsocialcolor',
		'std' => '#595959',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font hover color for footer social icons', 'eaterstop-pro'),
		'id' => 'footsocialhvcolor',
		'std' => '#d66200',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for our special menu filter', 'eaterstop-pro'),
		'id' => 'smfilterfontcolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font active color for our special menu filter', 'eaterstop-pro'),
		'id' => 'smfilterfontcolorhv',
		'std' => '#FFA200',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for our special menu title', 'eaterstop-pro'),
		'id' => 'menutitlecolor',
		'std' => '#969696',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for our special menu price', 'eaterstop-pro'),
		'id' => 'menupricecolor',
		'std' => '#B57137',
		'type' => 'color');						
			

	// Background start		
	$options[] = array(	
		'name' => __('Background Colors', 'eaterstop-pro'),	
		'desc' => __('Select background color for header', 'eaterstop-pro'),
		'id' => 'headerbgcolor',
		'std' => '#ffffff',
		'type' => 'color');	
	
	$options[] = array(
		'desc' => __('Select background color for header nav dropdown', 'eaterstop-pro'),
		'id' => 'navdpbgcolor',
		'std' => '#ffffff',
		'type' => 'color');
	

	$options[] = array(
		'desc' => __('Select background color for footer', 'eaterstop-pro'),
		'id' => 'footerbgcolor',
		'std' => '#242323',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select background color for copyright section', 'eaterstop-pro'),
		'id' => 'copybgcolor',
		'std' => '#1a191a',
		'type' => 'color');	

	$options[] = array(
		'desc' => __('Select background color for toggle menu', 'eaterstop-pro'),
		'id' => 'togglemenu',
		'std' => '#d66200',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background color for our team expert boxes', 'eaterstop-pro'),
		'id' => 'teambgcolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background color for counter circle box', 'eaterstop-pro'),
		'id' => 'countercirclebgcolor',
		'std' => '#000000',
		'type' => 'color');	
	$options[] = array(
		'desc' => __('Select background hover color for view recipe arrows', 'eaterstop-pro'),
		'id' => 'racipearrowbgcolor',
		'std' => '#d66200',
		'type' => 'color');							

	// Border colors
	$options[] = array(
		'name' => __('Border Colors', 'eaterstop-pro'),	
		'desc' => __('Select border color for All', 'eaterstop-pro'),
		'id' => 'allbdcolor',
		'std' => '#d66200',
		'type' => 'color');
			
	$options[] = array(	
		'desc' => __('Select border color for footer posts', 'eaterstop-pro'),
		'id' => 'footerpostborder',
		'std' => '#5e6162',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for sidebar li a', 'eaterstop-pro'),
		'id' => 'sidebarliaborder',
		'std' => '#d0cfcf',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for our staff degignation', 'eaterstop-pro'),
		'id' => 'teamborder',
		'std' => '#EAEAEA',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for sidebar widget title', 'eaterstop-pro'),
		'id' => 'widgettitleborder',
		'std' => '#E8E8E8',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for sidebar widget box', 'eaterstop-pro'),
		'id' => 'widgetboxborder',
		'std' => '#E8E8E8',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for footer all underline', 'eaterstop-pro'),
		'id' => 'footerallborder',
		'std' => '#303030',
		'type' => 'color');				
		
		

	// Default Buttons		
	$options[] = array(
		'name' => __('Button Colors', 'eaterstop-pro'),		
		'desc' => __('Select background color for default button', 'eaterstop-pro'),
		'id' => 'btnbgcolor',
		'std' => '#d66200',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select background hover color for default button', 'eaterstop-pro'),
		'id' => 'btnbghvcolor',
		'std' => '#424242',
		'type' => 'color');		

	$options[] = array(
		'desc' => __('Select font color default button', 'eaterstop-pro'),
		'id' => 'btntxtcolor',
		'std' => '#ffffff',
		'type' => 'color');

	$options[] = array(
		'desc' => __('Select font hover color for default button', 'eaterstop-pro'),
		'id' => 'btntxthvcolor',
		'std' => '#ffffff',
		'type' => 'color');

	// Slider Caption colors	
	$options[] = array(	
		'name' => __('Slider Caption Colors', 'eaterstop-pro'),			
		'desc' => __('Select font color for slider title', 'eaterstop-pro'),
		'id' => 'slidetitlecolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(		
		'desc' => __('Select font color for slider description', 'eaterstop-pro'),
		'id' => 'slidedesccolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font size for slider title', 'eaterstop-pro'),
		'id' => 'slidetitlefontsize',
		'type' => 'select',
		'std' => '42px',
		'options' => $font_sizes );
		
	$options[] = array(
		'desc' => __('Select font size for slider description', 'eaterstop-pro'),
		'id' => 'slidedescfontsize',
		'type' => 'select',
		'std' => '20px',
		'options' => $font_sizes );
		
	// Slider controls colors		
	$options[] = array(
		'name' => __('Slider controls Colors', 'eaterstop-pro'),
		'desc' => __('Select background color for slider pager', 'eaterstop-pro'),
		'id' => 'sldpagebg',
		'std' => '#ffffff',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select background active color for slider pager', 'eaterstop-pro'),
		'id' => 'sldpagehvbg',
		'std' => '#d66200',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select Border color for slider pager', 'eaterstop-pro'),
		'id' => 'sldpagehvbd',
		'std' => '#ffffff',
		'type' => 'color');	

	$options[] = array(
		'name' => __('Blog Single Layout', 'eaterstop-pro'),
		'desc' => __('Select layout. eg:Boxed, Wide', 'eaterstop-pro'),
		'id' => 'singlelayout',
		'type' => 'select',
		'std' => 'singleright',
		'options' => array('singleright'=>'Blog Single Right Sidebar', 'singleleft'=>'Blog Single Left Sidebar', 'sitefull'=>'Blog Single Full Width', 'nosidebar'=>'Blog Single No Sidebar') );
		
		
	$options[] = array(
		'name' => __('Woocommerce Page Layout', 'eaterstop-pro'),
		'desc' => __('Select layout. eg:right-sidebar, left-sidebar, full-width', 'eaterstop-pro'),
		'id' => 'woocommercelayout',
		'type' => 'select',
		'std' => 'woocommercesitefull',
		'options' => array('woocommerceright'=>'Woocommerce Right Sidebar', 'woocommerceleft'=>'Woocommerce Left Sidebar', 'woocommercesitefull'=>'Woocommerce Full Width') );	
		
	$options[] = array(	
		'name' => __('Testimonials Rotating Speed', 'eaterstop-pro'),	
		'desc' => __('manage testimonials rotating speed.', 'eaterstop-pro'),
		'id' => 'testimonialsrotatingspeed',
		'std' => '8000',
		'type' => 'text');	
		
	$options[] = array(		
		'desc' => __('True/False Auto play Testimonials.','eaterstop-pro'),
		'id' => 'testimonialsautoplay',
		'std' => 'true',
		'type' => 'select',
		'options' => array('true'=>'True', 'false'=>'False'));			
			
		
	$options[] = array(
		'name' => __('Responsive View Menu text Changeable', 'eaterstop-pro'),
		'desc' => __('Change menu test on responsive view', 'eaterstop-pro'),
		'id' => 'menuwordchange',
		'std' => 'Menu',
		'type' => 'text');	
		
	$options[] = array(
		'name' => __('Excerpt Length', 'eaterstop-pro'),	
		'desc' => __('Select excerpt length for our menu section', 'eaterstop-pro'),
		'id' => 'ourmenulength',
		'std' => '10',
		'type' => 'text');	
		
	$options[] = array(		
		'desc' => __('Select excerpt length for our experts', 'eaterstop-pro'),
		'id' => 'ourexpertslength',
		'std' => '20',
		'type' => 'text');	
		
	$options[] = array(		
		'desc' => __('Select excerpt length for latest news section', 'eaterstop-pro'),
		'id' => 'latestnewslength',
		'std' => '15',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Read More Button Text', 'eaterstop-pro'),	
		'desc' => __('change read more button text for latest news sction', 'eaterstop-pro'),
		'id' => 'latestnewsreadmore',
		'std' => 'Read More &raquo;',
		'type' => 'text');
		
	$options[] = array(		
		'desc' => __('Change Show All Button text for photo gallery section', 'eaterstop-pro'),
		'id' => 'galleryshowallbtn',
		'std' => 'Show All',
		'type' => 'text');						
		

	//Layout Settings
	$options[] = array(
		'name' => __('Sections', 'eaterstop-pro'),
		'type' => 'heading');
		
	$options[] = array(
		'name' => __('Todays Special Menu','eaterstop-pro'),
		'desc'	=> __('Select todays special menu for frontpage section','eaterstop-pro'),
		'id' 	=> 'welcomepagecontent',
		'type'	=> 'select',
		'options' => $options_pages,
	);	
	
	$options[] = array(			
			'desc'	=> __('Check to hide this section', 'eaterstop-pro'),
			'id'	=> 'hidewelcomesection',
			'type'	=> 'checkbox',
			'std'	=> '');	
	
	$options[] = array(	
		'name' => __('Four Boxes','eaterstop-pro'),
		'desc'	=> __('First Services box for frontpage section first','eaterstop-pro'),
		'id' 	=> 'box1',
		'type'	=> 'select',
		'options' => $options_pages,
	);
	
	$options[] = array(		
		'desc' => __('upload image for first box.', 'eaterstop-pro'),
		'id' => 'boximg1',
		'class' => '',
		'std'	=> '',
		'type' => 'upload');
	
	$options[] = array(	
		'desc'	=> __('Second Services box for frontpage section first','eaterstop-pro'),
		'id' 	=> 'box2',
		'type'	=> 'select',
		'options' => $options_pages,
	);
	
	$options[] = array(		
		'desc' => __('upload image for second box.', 'eaterstop-pro'),
		'id' => 'boximg2',
		'class' => '',
		'std'	=> '',
		'type' => 'upload');
	
	$options[] = array(	
		'desc'	=> __('Third Services box for frontpage section first','eaterstop-pro'),
		'id' 	=> 'box3',
		'type'	=> 'select',
		'options' => $options_pages,
	);	
	
	$options[] = array(		
		'desc' => __('upload image for third box.', 'eaterstop-pro'),
		'id' => 'boximg3',
		'class' => '',
		'std'	=> '',
		'type' => 'upload');
	
	$options[] = array(	
		'desc'	=> __('Third Services box for frontpage section first','eaterstop-pro'),
		'id' 	=> 'box4',
		'type'	=> 'select',
		'options' => $options_pages,
	);
	
	$options[] = array(		
		'desc' => __('upload image for fourth box.', 'eaterstop-pro'),
		'id' => 'boximg4',
		'class' => '',
		'std'	=> '',
		'type' => 'upload');
		
	$options[] = array(		
		'desc' => __('Change excerpt length for page four boxes', 'eaterstop-pro'),
		'id' => 'pageboxescontent',
		'std' => '20',
		'type' => 'text');		
		
	$options[] = array(			
			'desc'	=> __('Check to hide this section', 'eaterstop-pro'),
			'id'	=> 'hidefourbxsec',
			'type'	=> 'checkbox',
			'std'	=> '');		
	
	$options[] = array(
		'name' => __('Number of Sections', 'eaterstop-pro'),
		'desc' => __('Select number of sections', 'eaterstop-pro'),
		'id' => 'numsection',
		'type' => 'select',
		'std' => '9',
		'options' => array_combine(range(1,30), range(1,30)) );

	$numsecs = of_get_option( 'numsection', 9 );

	for( $n=1; $n<=$numsecs; $n++){
		$options[] = array(
			'desc' => __("<h3>Section ".$n."</h3>", 'eaterstop-pro'),
			'class' => 'toggle_title',
			'type' => 'info');	
	
		$options[] = array(
			'name' => __('Section Title', 'eaterstop-pro'),
			'id' => 'sectiontitle'.$n,
			'std' => ( ( isset($section_text[$n]['section_title']) ) ? $section_text[$n]['section_title'] : '' ),
			'type' => 'text');

		$options[] = array(
			'name' => __('Section ID', 'eaterstop-pro'),
			'desc'	=> __('Enter your section ID here. SECTION ID MUST BE IN SMALL LETTERS ONLY AND DO NOT ADD SPACE OR SYMBOL.', 'eaterstop-pro'),
			'id' => 'menutitle'.$n,
			'std' => ( ( isset($section_text[$n]['menutitle']) ) ? $section_text[$n]['menutitle'] : '' ),
			'type' => 'text');

		$options[] = array(
			'name' => __('Section Background Color', 'eaterstop-pro'),
			'desc' => __('Select background color for section', 'eaterstop-pro'),
			'id' => 'sectionbgcolor'.$n,
			'std' => ( ( isset($section_text[$n]['bgcolor']) ) ? $section_text[$n]['bgcolor'] : '' ),
			'type' => 'color');
			
		$options[] = array(
			'name' => __('Background Image', 'eaterstop-pro'),
			'id' => 'sectionbgimage'.$n,
			'class' => '',
			'std' => ( ( isset($section_text[$n]['bgimage']) ) ? $section_text[$n]['bgimage'] : '' ),
			'type' => 'upload');

		$options[] = array(
			'name' => __('Section CSS Class', 'eaterstop-pro'),
			'desc' => __('Set class for this section.', 'eaterstop-pro'),
			'id' => 'sectionclass'.$n,
			'std' => ( ( isset($section_text[$n]['class']) ) ? $section_text[$n]['class'] : '' ),
			'type' => 'text');
			
		$options[] = array(
			'name'	=> __('Hide Section', 'eaterstop-pro'),
			'desc'	=> __('Check to hide this section', 'eaterstop-pro'),
			'id'	=> 'hidesec'.$n,
			'type'	=> 'checkbox',
			'std'	=> '');

		$options[] = array(
			'name' => __('Section Content', 'eaterstop-pro'),
			'id' => 'sectioncontent'.$n,
			'std' => ( ( isset($section_text[$n]['content']) ) ? $section_text[$n]['content'] : '' ),
			'type' => 'editor');
	}


	//SLIDER SETTINGS
	$options[] = array(
		'name' => __('Homepage Slider', 'eaterstop-pro'),
		'type' => 'heading');
		
	$options[] = array(
		'name' => __('Inner Page Banner', 'eaterstop-pro'),
		'desc' => __('Upload inner page banner for site', 'eaterstop-pro'),
		'id' => 'innerpagebanner',
		'class' => '',
		'std'	=> get_template_directory_uri()."/images/default-banner.jpg",
		'type' => 'upload');
		
		
	$options[] = array(
		'name' => __('Custom Slider Shortcode Area For Home Page', 'eaterstop-pro'),
		'desc' => __('Enter here your slider shortcode without php tag', 'eaterstop-pro'),
		'id' => 'customslider',
		'std' => '',
		'type' => 'textarea');		
		
	$options[] = array(
		'name' => __('Slider Effects and Timing', 'eaterstop-pro'),
		'desc' => __('Select slider effect.','eaterstop-pro'),
		'id' => 'slideefect',
		'std' => 'random',
		'type' => 'select',
		'options' => array('random'=>'Random', 'fade'=>'Fade', 'fold'=>'Fold', 'sliceDown'=>'Slide Down', 'sliceDownLeft'=>'Slide Down Left', 'sliceUp'=>'Slice Up', 'sliceUpLeft'=>'Slice Up Left', 'sliceUpDown'=>'Slice Up Down', 'sliceUpDownLeft'=>'Slice Up Down Left', 'slideInRight'=>'SlideIn Right', 'slideInLeft'=>'SlideIn Left', 'boxRandom'=>'Box Random', 'boxRain'=>'Box Rain', 'boxRainReverse'=>'Box Rain Reverse', 'boxRainGrow'=>'Box Rain Grow', 'boxRainGrowReverse'=>'Box Rain Grow Reverse' ));
		
	$options[] = array(
		'desc' => __('Animation speed should be multiple of 100.', 'eaterstop-pro'),
		'id' => 'slideanim',
		'std' => 500,
		'type' => 'text');
		
	$options[] = array(
		'desc' => __('Add slide pause time.', 'eaterstop-pro'),
		'id' => 'slidepause',
		'std' => 4000,
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slide Controllers', 'eaterstop-pro'),
		'desc' => __('Hide/Show Direction Naviagtion of slider.','eaterstop-pro'),
		'id' => 'slidenav',
		'std' => 'true',
		'type' => 'select',
		'options' => array('true'=>'Show', 'false'=>'Hide'));
		
	$options[] = array(
		'desc' => __('Hide/Show pager of slider.','eaterstop-pro'),
		'id' => 'slidepage',
		'std' => 'true',
		'type' => 'select',
		'options' => array('true'=>'Show', 'false'=>'Hide'));
		
	$options[] = array(
		'desc' => __('Pause Slide on Hover.','eaterstop-pro'),
		'id' => 'slidepausehover',
		'std' => 'false',
		'type' => 'select',
		'options' => array('true'=>'Yes', 'false'=>'No'));	
		
	$options[] = array(
		'name' => __('Slider Image 1', 'eaterstop-pro'),
		'desc' => __('First Slide', 'eaterstop-pro'),
		'id' => 'slide1',
		'class' => '',
		'std' => get_template_directory_uri()."/images/slides/slider1.jpg",
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 1', 'eaterstop-pro'),
		'id' => 'slidetitle1',
		'std' => 'Top Restaurant WordPress Theme',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'eaterstop-pro'),
		'id' => 'slidedesc1',
		'std' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. ',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'eaterstop-pro'),
		'id' => 'slidebutton1',
		'std' => '',
		'type' => 'text');	

	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'eaterstop-pro'),
		'id' => 'slideurl1',
		'std' => '',
		'type' => 'text');		
		
	
	$options[] = array(
		'name' => __('Slider Image 2', 'eaterstop-pro'),
		'desc' => __('Second Slide', 'eaterstop-pro'),
		'class' => '',
		'id' => 'slide2',
		'std' => get_template_directory_uri()."/images/slides/slider2.jpg",
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 2', 'eaterstop-pro'),
		'id' => 'slidetitle2',
		'std' => 'Top Restaurant WordPress Theme',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'eaterstop-pro'),
		'id' => 'slidedesc2',
		'std' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. ',
		'type' => 'textarea');	
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'eaterstop-pro'),
		'id' => 'slidebutton2',
		'std' => '',
		'type' => 'text');			
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'eaterstop-pro'),
		'id' => 'slideurl2',
		'std' => '',
		'type' => 'text');	
	
	$options[] = array(
		'name' => __('Slider Image 3', 'eaterstop-pro'),
		'desc' => __('Third Slide', 'eaterstop-pro'),
		'id' => 'slide3',
		'class' => '',
		'std' => get_template_directory_uri()."/images/slides/slider3.jpg",
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 3', 'eaterstop-pro'),
		'id' => 'slidetitle3',
		'std' => 'Top Restaurant WordPress Theme',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'eaterstop-pro'),
		'id' => 'slidedesc3',
		'std' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. ',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'eaterstop-pro'),
		'id' => 'slidebutton3',
		'std' => '',
		'type' => 'text');			
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'eaterstop-pro'),
		'id' => 'slideurl3',
		'std' => '',
		'type' => 'text');	
	
	$options[] = array(
		'name' => __('Slider Image 4', 'eaterstop-pro'),
		'desc' => __('Third Slide', 'eaterstop-pro'),
		'id' => 'slide4',
		'class' => '',
		'std' => get_template_directory_uri()."/images/slides/slider4.jpg",
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 4', 'eaterstop-pro'),
		'id' => 'slidetitle4',
		'std' => 'Responsive Restaurant Theme',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'eaterstop-pro'),
		'id' => 'slidedesc4',
		'std' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. ',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'eaterstop-pro'),
		'id' => 'slidebutton4',
		'std' => '',
		'type' => 'text');			
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'eaterstop-pro'),
		'id' => 'slideurl4',
		'std' => '',
		'type' => 'text');				
	
	$options[] = array(
		'name' => __('Slider Image 5', 'eaterstop-pro'),
		'desc' => __('Fifth Slide', 'eaterstop-pro'),
		'id' => 'slide5',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 5', 'eaterstop-pro'),
		'id' => 'slidetitle5',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'eaterstop-pro'),
		'id' => 'slidedesc5',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'eaterstop-pro'),
		'id' => 'slidebutton5',
		'std' => '',
		'type' => 'text');			
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'eaterstop-pro'),
		'id' => 'slideurl5',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 6', 'eaterstop-pro'),
		'desc' => __('Sixth Slide', 'eaterstop-pro'),
		'id' => 'slide6',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 6', 'eaterstop-pro'),
		'id' => 'slidetitle6',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'eaterstop-pro'),
		'id' => 'slidedesc6',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'eaterstop-pro'),
		'id' => 'slidebutton6',
		'std' => '',
		'type' => 'text');		
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'eaterstop-pro'),
		'id' => 'slideurl6',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 7', 'eaterstop-pro'),
		'desc' => __('Seventh Slide', 'eaterstop-pro'),
		'id' => 'slide7',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 7', 'eaterstop-pro'),
		'id' => 'slidetitle7',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'eaterstop-pro'),
		'id' => 'slidedesc7',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'eaterstop-pro'),
		'id' => 'slidebutton7',
		'std' => '',
		'type' => 'text');			
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'eaterstop-pro'),
		'id' => 'slideurl7',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 8', 'eaterstop-pro'),
		'desc' => __('Eighth Slide', 'eaterstop-pro'),
		'id' => 'slide8',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 8', 'eaterstop-pro'),
		'id' => 'slidetitle8',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'eaterstop-pro'),
		'id' => 'slidedesc8',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'eaterstop-pro'),
		'id' => 'slidebutton8',
		'std' => '',
		'type' => 'text');		
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'eaterstop-pro'),
		'id' => 'slideurl8',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 9', 'eaterstop-pro'),
		'desc' => __('Ninth Slide', 'eaterstop-pro'),
		'id' => 'slide9',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 9', 'eaterstop-pro'),
		'id' => 'slidetitle9',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'eaterstop-pro'),
		'id' => 'slidedesc9',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'eaterstop-pro'),
		'id' => 'slidebutton9',
		'std' => '',
		'type' => 'text');			
		
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'eaterstop-pro'),
		'id' => 'slideurl9',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 10', 'eaterstop-pro'),
		'desc' => __('Tenth Slide', 'eaterstop-pro'),
		'id' => 'slide10',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 10', 'eaterstop-pro'),
		'id' => 'slidetitle10',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'eaterstop-pro'),
		'id' => 'slidedesc10',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'eaterstop-pro'),
		'id' => 'slidebutton10',
		'std' => '',
		'type' => 'text');			
	
	$options[] = array(
		'desc' => __('Slide Url for Read More Button', 'eaterstop-pro'),
		'id' => 'slideurl10',
		'std' => '',
		'type' => 'text');
	

	//Footer SETTINGS
	$options[] = array(
		'name' => __('Footer', 'eaterstop-pro'),
		'type' => 'heading');
		
	$options[] = array(
		'name' => __('Footer Layout', 'eaterstop-pro'),
		'desc' => __('footer Select layout. eg:Boxed, 1, 2, 3 and 4', 'eaterstop-pro'),
		'id' => 'footerlayout',
		'type' => 'select',
		'std' => 'fourcolumn',
		'options' => array('onecolumn'=>'Footer 1 column', 'twocolumn'=>'Footer 2 column', 'threecolumn'=>'Footer 3 column', 'fourcolumn'=>'Footer 4 column', ) );			
				
	$options[] = array(
		'name' => __('Footer About Us', 'eaterstop-pro'),
		'desc' => __('abput us text title for footer', 'eaterstop-pro'),
		'id' => 'abouttitle',
		'std' => 'About Us',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('About Us Description', 'eaterstop-pro'),
		'desc' => __('abput us text description for footer', 'eaterstop-pro'),
		'id' => 'aboutusdescription',
		'std' => '<p>Donec ut ex ac nulla pellentesque mollis in a enim Suspendisse suscipit velit id ultricies auctor. Duis turpis arcu, aliquet sed sollicitudin seduisque velit nibh.</br > </br >Donec ut ex ac nulla sapien mauris, vitae sodales tellus suspendisse suscipit velit id ultricies auctor.</p>',
		'type' => 'textarea');
		
	$options[] = array(
		'name' => __('Footer Menu Title', 'eaterstop-pro'),
		'desc' => __('footer menu title.', 'eaterstop-pro'),
		'id' => 'footermenutitle',
		'std' => 'Footer Menu',
		'type' => 'text');	
	
	$options[] = array(
		'name' => __('Latest Posts Title', 'eaterstop-pro'),
		'desc' => __('Footer latest posts title.', 'eaterstop-pro'),
		'id' => 'letestpoststitle',
		'std' => 'Latest Posts',
		'type' => 'text');	
		
		
	$options[] = array(
		'name' => __('Footer Contact Us', 'eaterstop-pro'),
		'desc' => __('Add footer contact us title here', 'eaterstop-pro'),
		'id' => 'contacttitle',
		'std' => 'Contact Us',
		'type' => 'text');	
		
	$options[] = array(	
		'desc' => __('Add company address1 here.', 'eaterstop-pro'),
		'id' => 'address',
		'std' => '2180 Meetinghouse Rd, Elberton, GA, 30635',
		'type' => 'textarea');
		
	$options[] = array(		
		'desc' => __('Add phone number here.', 'eaterstop-pro'),
		'id' => 'phone',
		'std' => '+91 123456789',
		'type' => 'text');
		
	$options[] = array(		
		'desc' => __('Add fax number here.', 'eaterstop-pro'),
		'id' => 'fax',
		'std' => '+91 9876543210',
		'type' => 'text');	
		
	$options[] = array(
		'desc' => __('Add email address here.', 'eaterstop-pro'),
		'id' => 'email',
		'std' => 'info@sitename.com',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Footer Social Icons', 'eaterstop-pro'),
		'desc' => __('social icons for footer', 'eaterstop-pro'),
		'id' => 'footersocialicon',
		'std' => '[social_area]
			[social icon="facebook" link="#"]
			[social icon="twitter" link="#"]
			[social icon="linkedin" link="#"]
			[social icon="google-plus" link="#"]
		[/social_area]
		',
		'type' => 'textarea');
		
	$options[] = array(
		'name' => __('Footer Copyright', 'eaterstop-pro'),
		'desc' => __('Copyright Text for your site.', 'eaterstop-pro'),
		'id' => 'copytext',
		'std' => '&copy; 2016 <a href="#">Eaterstop </a>. All Rights Reserved',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Footre Text Link', 'eaterstop-pro'),
		'id' => 'ftrlink',
		'std' => 'Design by <a href="'.esc_url('https://www.gracethemes.com/').'" target="_blank">Grace Themes</a>',
		'type' => 'textarea',);
		
	$options[] = array(
		'desc' => __('Footre Back to Top Button', 'eaterstop-pro'),
		'id' => 'backtotop',
		'std' => '[back-to-top]',
		'type' => 'textarea',);

	//Short codes
	$options[] = array(
		'name' => __('Short Codes', 'eaterstop-pro'),
		'type' => 'heading');	
		
	
	$options[] = array(
		'name' => __('Photo Gallery', 'eaterstop-pro'),
		'desc' => __('[photogallery filter="false"]', 'eaterstop-pro'),
		'type' => 'info');	
		
	$options[] = array(
		'name' => __('Our Special Menu', 'eaterstop-pro'),
		'desc' => __('[ourmenu show="6" filter="true"] ', 'eaterstop-pro'),
		'type' => 'info');			
			
		
	$options[] = array(
		'name' => __('Testimonials', 'eaterstop-pro'),
		'desc' => __('[testimonials]', 'eaterstop-pro'),
		'type' => 'info');
		
	$options[] = array(
		'name' => __('Contact Form', 'eaterstop-pro'),
		'desc' => __('[contactform to_email="test@example.com" title="Contact Form"] 
', 'eaterstop-pro'),
		'type' => 'info');

	$options[] = array(
		'name' => __('Our Staff', 'eaterstop-pro'),
		'desc' => __('[our-staff show="4"] and all [our-staff]', 'eaterstop-pro'),
		'type' => 'info');	
		
	$options[] = array(
		'name' => __('Our Staff', 'eaterstop-pro'),
		'desc' => __('[counter iconname="group" value="9560" title="Our Staff"][counter iconname="gift" value="9560" title="Lucky Visitor"][counter iconname="list" value="9560" title="Our Clients List"] [counter iconname="graduation-cap" value="560" title="Our Awards"]', 'eaterstop-pro'),
		'type' => 'info');
		
	$options[] = array(
		'name' => __('Our Staff', 'eaterstop-pro'),
		'desc' => __('[racipe_lists]<br/>
		 [racipe title="Enter here title" image="enter here image url with http:" link="#" target="_blank"]<br/>
		 [racipe title="Enter here title" image="enter here image url with http:" link="#" target="_blank"]<br/>
		 [racipe title="Enter here title" image="enter here image url with http:" link="#" target="_blank"]<br/>
		 [racipe title="Enter here title" image="enter here image url with http:" link="#" target="_blank"]<br/>
		 [racipe title="Enter here title" image="enter here image url with http:" link="#" target="_blank"]<br/>
		[/racipe_lists]', 'eaterstop-pro'),
		'type' => 'info');			
		
	$options[] = array(
		'name' => __('Latest News', 'eaterstop-pro'),
		'desc' => __('[latest-news showposts="4" comment="show" date="show" author="hide"] and all [latest-news]', 'eaterstop-pro'),
		'type' => 'info');
		
	$options[] = array(
		'name' => __('Custom Button', 'eaterstop-pro'),
		'desc' => __('[button align="center" name="View Gallery" link="#" target="" arrowname="fa-chevron-right"]', 'eaterstop-pro'),
		'type' => 'info');			
			
		
	$options[] = array(
		'name' => __('Search Form', 'eaterstop-pro'),
		'desc' => __('[searchform]', 'eaterstop-pro'),
		'type' => 'info');
		
	$options[] = array(
		'name' => __('Social Icons ( Note: More social icons can be found at: http://fortawesome.github.io/Font-Awesome/icons/)', 'eaterstop-pro'),
		'desc' => __('[social_area]<br />
			[social icon="facebook" link="#"]<br />
			[social icon="twitter" link="#"]<br />
			[social icon="linkedin" link="#"]<br />
			[social icon="google-plus" link="#"]<br />
		[/social_area]', 'eaterstop-pro'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('2 Column Content', 'eaterstop-pro'),
		'desc' => __('<pre>
[column_content type="one_half"]
	Column 1 Content goes here...
[/column_content]

[column_content type="one_half_last"]
	Column 2 Content goes here...
[/column_content]
</pre>', 'eaterstop-pro'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('3 Column Content', 'eaterstop-pro'),
		'desc' => __('<pre>
[column_content type="one_third"]
	Column 1 Content goes here...
[/column_content]

[column_content type="one_third"]
	Column 2 Content goes here...
[/column_content]

[column_content type="one_third_last"]
	Column 3 Content goes here...
[/column_content]
</pre>', 'eaterstop-pro'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('4 Column Content', 'eaterstop-pro'),
		'desc' => __('<pre>
[column_content type="one_fourth"]
	Column 1 Content goes here...
[/column_content]

[column_content type="one_fourth"]
	Column 2 Content goes here...
[/column_content]

[column_content type="one_fourth"]
	Column 3 Content goes here...
[/column_content]

[column_content type="one_fourth_last"]
	Column 4 Content goes here...
[/column_content]
</pre>', 'eaterstop-pro'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('5 Column Content', 'eaterstop-pro'),
		'desc' => __('<pre>
[column_content type="one_fifth"]
	Column 1 Content goes here...
[/column_content]

[column_content type="one_fifth"]
	Column 2 Content goes here...
[/column_content]

[column_content type="one_fifth"]
	Column 3 Content goes here...
[/column_content]

[column_content type="one_fifth"]
	Column 4 Content goes here...
[/column_content]

[column_content type="one_fifth_last"]
	Column 5 Content goes here...
[/column_content]
</pre>', 'eaterstop-pro'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('Tabs', 'eaterstop-pro'),
		'desc' => __('<pre>
[tabs]
	[tab title="TAB TITLE 1"]
		TAB CONTENT 1
	[/tab]
	[tab title="TAB TITLE 2"]
		TAB CONTENT 2
	[/tab]
	[tab title="TAB TITLE 3"]
		TAB CONTENT 3
	[/tab]
[/tabs]
</pre>', 'eaterstop-pro'),
		'type' => 'info');


	$options[] = array(
		'name' => __('Toggle Content', 'eaterstop-pro'),
		'desc' => __('<pre>
[toggle_content title="Toggle Title 1"]
	Toggle content 1...
[/toggle_content]
[toggle_content title="Toggle Title 2"]
	Toggle content 2...
[/toggle_content]
[toggle_content title="Toggle Title 3"]
	Toggle content 3...
[/toggle_content]
</pre>', 'eaterstop-pro'),
		'type' => 'info');


	$options[] = array(
		'name' => __('Accordion Content', 'eaterstop-pro'),
		'desc' => __('<pre>
[accordion]
	[accordion_content title="ACCORDION TITLE 1"]
		ACCORDION CONTENT 1
	[/accordion_content]
	[accordion_content title="ACCORDION TITLE 2"]
		ACCORDION CONTENT 2
	[/accordion_content]
	[accordion_content title="ACCORDION TITLE 3"]
		ACCORDION CONTENT 3
	[/accordion_content]
[/accordion]
</pre>', 'eaterstop-pro'),
		'type' => 'info');
		
	$options[] = array(
		'name' => __('Clear', 'eaterstop-pro'),
		'desc' => __('<pre>
[clear]
</pre>', 'eaterstop-pro'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('HR / Horizontal separation line', 'eaterstop-pro'),
		'desc' => __('<pre>
[hr] or &lt;hr&gt;
</pre>', 'eaterstop-pro'),
		'type' => 'info');
	
	$options[] = array(
		'name' => __('Scroll to Top', 'eaterstop-pro'),
		'desc' => __('[back-to-top] 
', 'eaterstop-pro'),
		'type' => 'info');

	// Support					
	$options[] = array(
		'name' => __('Our Themes', 'eaterstop-pro'),
		'type' => 'heading');

	$options[] = array(
		'desc' => __('Eaterstop Pro WordPress theme has been Designed and Created by <a href="'.esc_url('https://gracethemes.com/').'" target="_blank">Grace Themes</a>', 'eaterstop-pro'),
		'type' => 'info');	

	 $options[] = array(
		'desc' => __('<a href="'.esc_url('https://gracethemes.com/').'" target="_blank"><img src="'.get_template_directory_uri().'/images/themesbunch.jpg"></a>', 'eaterstop-pro'),
		'type' => 'info');	

	return $options;
}