<?php 
/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 */ 

function optionsframework_option_name() {
	// Change this to use your theme slug
	$themename = wp_get_theme();
	$themename = preg_replace("/\W/", "_", strtolower($themename) );
	return $themename;
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 *
 * If you are making your theme translatable, you should replace 'grc-zeroerror'
 * with the actual text domain for your theme.  Read more:
 * http://codex.wordpress.org/Function_Reference/load_theme_textdomain
 */

function optionsframework_options() {
	//array of all custom font types.
	$font_types = array( '' => '', 'Arial' => 'Arial',
		'Comic Sans MS' => 'Comic Sans MS',
		'FreeSans' => 'FreeSans',
		'Georgia' => 'Georgia',
		'Lucida Sans Unicode' => 'Lucida Sans Unicode',
		'Palatino Linotype' => 'Palatino Linotype',
		'Symbol' => 'Symbol',
		'Tahoma' => 'Tahoma',
		'Trebuchet MS' => 'Trebuchet MS',
		'Verdana' => 'Verdana',
		'ABeeZee' => 'ABeeZee',
		'Abel' => 'Abel',
		'Abril Fatface' => 'Abril Fatface',
		'Aclonica' => 'Aclonica',
		'Acme' => 'Acme',
		'Actor' => 'Actor',
		'Adamina' => 'Adamina',
		'Advent Pro' => 'Advent Pro',
		'Aguafina Script' => 'Aguafina Script',
		'Akronim' => 'Akronim',
		'Aladin' => 'Aladin',
		'Aldrich' => 'Aldrich',
		'Alegreya' => 'Alegreya',
		'Alegreya SC' => 'Alegreya SC',
		'Alex Brush' => 'Alex Brush',
		'Alfa Slab One' => 'Alfa Slab One',
		'Alice' => 'Alice',
		'Alike' => 'Alike',
		'Alike Angular' => 'Alike Angular',
		'Allan' => 'Allan',
		'Allerta' => 'Allerta',
		'Allerta Stencil' => 'Allerta Stencil',
		'Allura' => 'Allura',
		'Almendra' => 'Almendra',
		'Almendra Display' => 'Almendra Display',
		'Almendra SC' => 'Almendra SC',
		'Amarante' => 'Amarante',
		'Amaranth' => 'Amaranth',
		'Amatic SC' => 'Amatic SC',
		'Amethysta' => 'Amethysta',
		'Anaheim' => 'Anaheim',
		'Andada' => 'Andada',
		'Andika' => 'Andika',
		'Annie Use Your Telescope' => 'Annie Use Your Telescope',
		'Anonymous Pro' => 'Anonymous Pro',
		'Antic' => 'Antic',
		'Antic Didone' => 'Antic Didone',
		'Antic Slab' => 'Antic Slab',
		'Anton' => 'Anton',
		'Arapey' => 'Arapey',
		'Arbutus' => 'Arbutus',
		'Arbutus Slab' => 'Arbutus Slab',
		'Architects Daughter' => 'Architects Daughter',
		'Archivo White' => 'Archivo White',
		'Archivo Narrow' => 'Archivo Narrow',
		'Arimo' => 'Arimo',
		'Arizonia' => 'Arizonia',
		'Armata' => 'Armata',
		'Artifika' => 'Artifika',
		'Arvo' => 'Arvo',
		'Asap' => 'Asap',
		'Asset' => 'Asset',
		'Astloch' => 'Astloch',
		'Asul' => 'Asul',
		'Atomic Age' => 'Atomic Age',
		'Aubrey' => 'Aubrey',
		'Audiowide' => 'Audiowide',
		'Autour One' => 'Autour One',
		'Average' => 'Average',
		'Average Sans' => 'Average Sans',
		'Averia Gruesa Libre' => 'Averia Gruesa Libre',
		'Averia Libre' => 'Averia Libre',
		'Averia Sans Libre' => 'Averia Sans Libre',
		'Averia Serif Libre' => 'Averia Serif Libre',
		'Bad Script' => 'Bad Script',
		'Balthazar' => 'Balthazar',
		'Bangers' => 'Bangers',
		'Basic' => 'Basic',
		'Baumans' => 'Baumans',
		'Belgrano' => 'Belgrano',
		'Belleza' => 'Belleza',
		'BenchNine' => 'BenchNine',
		'Bentham' => 'Bentham',
		'Berkshire Swash' => 'Berkshire Swash',
		'Bevan' => 'Bevan',
		'Bigelow Rules' => 'Bigelow Rules',
		'Bigshot One' => 'Bigshot One',
		'Bilbo' => 'Bilbo',
		'Bilbo Swash Caps' => 'Bilbo Swash Caps',
		'Bitter' => 'Bitter',
		'White Ops One' => 'White Ops One',
		'Bonbon' => 'Bonbon',
		'Boogaloo' => 'Boogaloo',
		'Bowlby One' => 'Bowlby One',
		'Bowlby One SC' => 'Bowlby One SC',
		'Brawler' => 'Brawler',
		'Bree Serif' => 'Bree Serif',
		'Bubblegum Sans' => 'Bubblegum Sans',
		'Bubbler One' => 'Bubbler One',
		'Buda' => 'Buda',
		'Buenard' => 'Buenard',
		'Butcherman' => 'Butcherman',
		'Butcherman Caps' => 'Butcherman Caps',
		'Butterfly Kids' => 'Butterfly Kids',
		'Cabin' => 'Cabin',
		'Cabin Condensed' => 'Cabin Condensed',
		'Cabin Sketch' => 'Cabin Sketch',
		'Cabin' => 'Cabin',
		'Caesar Dressing' => 'Caesar Dressing',
		'Cagliostro' => 'Cagliostro',
		'Calligraffitti' => 'Calligraffitti',
		'Cambo' => 'Cambo',
		'Candal' => 'Candal',
		'Cantarell' => 'Cantarell',
		'Cantata One' => 'Cantata One',
		'Cantora One' => 'Cantora One',
		'Capriola' => 'Capriola',
		'Cardo' => 'Cardo',
		'Carme' => 'Carme',
		'Carrois Gothic' => 'Carrois Gothic',
		'Carrois Gothic SC' => 'Carrois Gothic SC',
		'Carter One' => 'Carter One',
		'Caudex' => 'Caudex',
		'Cedarville Cursive' => 'Cedarville Cursive',
		'Ceviche One' => 'Ceviche One',
		'Changa One' => 'Changa One',
		'Chango' => 'Chango',
		'Chau Philomene One' => 'Chau Philomene One',
		'Chela One' => 'Chela One',
		'Chelsea Market' => 'Chelsea Market',
		'Cherry Cream Soda' => 'Cherry Cream Soda',
		'Cherry Swash' => 'Cherry Swash',
		'Chewy' => 'Chewy',
		'Chicle' => 'Chicle',
		'Chivo' => 'Chivo',
		'Cinzel' => 'Cinzel',
		'Cinzel Decorative' => 'Cinzel Decorative',
		'Clicker Script' => 'Clicker Script',
		'Coda' => 'Coda',
		'Codystar' => 'Codystar',
		'Combo' => 'Combo',
		'Comfortaa' => 'Comfortaa',
		'Coming Soon' => 'Coming Soon',
		'Condiment' => 'Condiment',
		'Contrail One' => 'Contrail One',
		'Convergence' => 'Convergence',
		'Cookie' => 'Cookie',
		'Copse' => 'Copse',
		'Corben' => 'Corben',
		'Courgette' => 'Courgette',
		'Cousine' => 'Cousine',
		'Coustard' => 'Coustard',
		'Covered By Your Grace' => 'Covered By Your Grace',
		'Crafty Girls' => 'Crafty Girls',
		'Creepster' => 'Creepster',
		'Creepster Caps' => 'Creepster Caps',
		'Crete Round' => 'Crete Round',
		'Crimson' => 'Crimson',
		'Croissant One' => 'Croissant One',
		'Crushed' => 'Crushed',
		'Cuprum' => 'Cuprum',
		'Cutive' => 'Cutive',
		'Cutive Mono' => 'Cutive Mono',
		'Damion' => 'Damion',
		'Dancing Script' => 'Dancing Script',
		'Dawning of a New Day' => 'Dawning of a New Day',
		'Days One' => 'Days One',
		'Delius' => 'Delius',
		'Delius Swash Caps' => 'Delius Swash Caps',
		'Delius Unicase' => 'Delius Unicase',
		'Della Respira' => 'Della Respira',
		'Denk One' => 'Denk One',
		'Devonshire' => 'Devonshire',
		'Didact Gothic' => 'Didact Gothic',
		'Diplomata' => 'Diplomata',
		'Diplomata SC' => 'Diplomata SC',
		'Domine' => 'Domine',
		'Donegal One' => 'Donegal One',
		'Doppio One' => 'Doppio One',
		'Dorsa' => 'Dorsa',
		'Dosis' => 'Dosis',
		'Dr Sugiyama' => 'Dr Sugiyama',
		'Droid Sans' => 'Droid Sans',
		'Droid Sans Mono' => 'Droid Sans Mono',
		'Droid Serif' => 'Droid Serif',
		'Duru Sans' => 'Duru Sans',
		'Dynalight' => 'Dynalight',
		'EB Garamond' => 'EB Garamond',
		'Eagle Lake' => 'Eagle Lake',
		'Eater' => 'Eater',
		'Eater Caps' => 'Eater Caps',
		'Economica' => 'Economica',
		'Electrolize' => 'Electrolize',
		'Elsie' => 'Elsie',
		'Elsie Swash Caps' => 'Elsie Swash Caps',
		'Emblema One' => 'Emblema One',
		'Emilys Candy' => 'Emilys Candy',
		'Engagement' => 'Engagement',
		'Englebert' => 'Englebert',
		'Enriqueta' => 'Enriqueta',
		'Erica One' => 'Erica One',
		'Esteban' => 'Esteban',
		'Euphoria Script' => 'Euphoria Script',
		'Ewert' => 'Ewert',
		'Exo' => 'Exo',
		'Expletus Sans' => 'Expletus Sans',
		'Fanwood Text' => 'Fanwood Text',
		'Fascinate' => 'Fascinate',
		'Fascinate Inline' => 'Fascinate Inline',
		'Faster One' => 'Faster One',
		'Federant' => 'Federant',
		'Federo' => 'Federo',
		'Felipa' => 'Felipa',
		'Fenix' => 'Fenix',
		'Finger Paint' => 'Finger Paint',
		'Fjalla One' => 'Fjalla One',
		'Fjord One' => 'Fjord One',
		'Flamenco' => 'Flamenco',
		'Flavors' => 'Flavors',
		'Fondamento' => 'Fondamento',
		'Fontdiner Swanky' => 'Fontdiner Swanky',
		'Forum' => 'Forum',
		'Francois One' => 'Francois One',
		'Freckle Face' => 'Freckle Face',
		'Fredericka the Great' => 'Fredericka the Great',
		'Fredoka One' => 'Fredoka One',
		'Fresca' => 'Fresca',
		'Frijole' => 'Frijole',
		'Fruktur' => 'Fruktur',
		'Fugaz One' => 'Fugaz One',
		'Gafata' => 'Gafata',
		'Galdeano' => 'Galdeano',
		'Galindo' => 'Galindo',
		'Gentium Basic' => 'Gentium Basic',
		'Gentium Book Basic' => 'Gentium Book Basic',
		'Geo' => 'Geo',
		'Geostar' => 'Geostar',
		'Geostar Fill' => 'Geostar Fill',
		'Germania One' => 'Germania One',
		'Gilda Display' => 'Gilda Display',
		'Give You Glory' => 'Give You Glory',
		'Glass Antiqua' => 'Glass Antiqua',
		'Glegoo' => 'Glegoo',
		'Gloria Hallelujah' => 'Gloria Hallelujah',
		'Goblin One' => 'Goblin One',
		'Gochi Hand' => 'Gochi Hand',
		'Gorditas' => 'Gorditas',
		'Goudy Bookletter 1911' => 'Goudy Bookletter 1911',
		'Graduate' => 'Graduate',
		'Grand Hotel' => 'Grand Hotel',
		'Gravitas One' => 'Gravitas One',
		'Great Vibes' => 'Great Vibes',
		'Griffy' => 'Griffy',
		'Gruppo' => 'Gruppo',
		'Gudea' => 'Gudea',
		'Habibi' => 'Habibi',
		'Hammersmith One' => 'Hammersmith One',
		'Hanalei' => 'Hanalei',
		'Hanalei Fill' => 'Hanalei Fill',
		'Handlee' => 'Handlee',
		'Happy Monkey' => 'Happy Monkey',
		'Headland One' => 'Headland One',
		'Henny Penny' => 'Henny Penny',
		'Herr Von Muellerhoff' => 'Herr Von Muellerhoff',
		'Holtwood One SC' => 'Holtwood One SC',
		'Homemade Apple' => 'Homemade Apple',
		'Homenaje' => 'Homenaje',
		'IM Fell' => 'IM Fell',
		'Iceberg' => 'Iceberg',
		'Iceland' => 'Iceland',
		'Imprima' => 'Imprima',
		'Inconsolata' => 'Inconsolata',
		'Inder' => 'Inder',
		'Indie Flower' => 'Indie Flower',
		'Inika' => 'Inika',
		'Irish Growler' => 'Irish Growler',
		'Istok Web' => 'Istok Web',
		'Italiana' => 'Italiana',
		'Italianno' => 'Italianno',
		'Jacques Francois' => 'Jacques Francois',
		'Jacques Francois Shadow' => 'Jacques Francois Shadow',
		'Jim Nightshade' => 'Jim Nightshade',
		'Jockey One' => 'Jockey One',
		'Jolly Lodger' => 'Jolly Lodger',
		'Josefin Sans' => 'Josefin Sans',
		'Josefin Sans' => 'Josefin Sans',
		'Josefin Slab' => 'Josefin Slab',
		'Joti One' => 'Joti One',
		'Judson' => 'Judson',
		'Julee' => 'Julee',
		'Julius Sans One' => 'Julius Sans One',
		'Junge' => 'Junge',
		'Jura' => 'Jura',
		'Just Another Hand' => 'Just Another Hand',
		'Just Me Again Down Here' => 'Just Me Again Down Here',
		'Kameron' => 'Kameron',
		'Karla' => 'Karla',
		'Kaushan Script' => 'Kaushan Script',
		'Kavoon' => 'Kavoon',
		'Keania One' => 'Keania One',
		'Kelly Slab' => 'Kelly Slab',
		'Kenia' => 'Kenia',
		'Kite One' => 'Kite One',
		'Knewave' => 'Knewave',
		'Kotta One' => 'Kotta One',
		'Kranky' => 'Kranky',
		'Kreon' => 'Kreon',
		'Kristi' => 'Kristi',
		'Krona One' => 'Krona One',
		'La Belle Aurore' => 'La Belle Aurore',
		'Lancelot' => 'Lancelot',
		'Lato' => 'Lato',
		'League Script' => 'League Script',
		'Leckerli One' => 'Leckerli One',
		'Ledger' => 'Ledger',
		'Lekton' => 'Lekton',
		'Lemon' => 'Lemon',
		'Libre Baskerville' => 'Libre Baskerville',
		'Life Savers' => 'Life Savers',
		'Lilita One' => 'Lilita One',
		'Limelight' => 'Limelight',
		'Linden Hill' => 'Linden Hill',
		'Lobster' => 'Lobster',
		'Lobster Two' => 'Lobster Two',
		'Londrina Outline' => 'Londrina Outline',
		'Londrina Shadow' => 'Londrina Shadow',
		'Londrina Sketch' => 'Londrina Sketch',
		'Londrina Solid' => 'Londrina Solid',
		'Lora' => 'Lora',
		'Love Ya Like A Sister' => 'Love Ya Like A Sister',
		'Loved by the King' => 'Loved by the King',
		'Lovers Quarrel' => 'Lovers Quarrel',
		'Luckiest Guy' => 'Luckiest Guy',
		'Lusitana' => 'Lusitana',
		'Lustria' => 'Lustria',
		'Macondo' => 'Macondo',
		'Macondo Swash Caps' => 'Macondo Swash Caps',
		'Magra' => 'Magra',
		'Maiden Orange' => 'Maiden Orange',
		'Mako' => 'Mako',
		'Marcellus' => 'Marcellus',
		'Marcellus SC' => 'Marcellus SC',
		'Marck Script' => 'Marck Script',
		'Margarine' => 'Margarine',
		'Marko One' => 'Marko One',
		'Marmelad' => 'Marmelad',
		'Marvel' => 'Marvel',
		'Mate' => 'Mate',
		'Mate SC' => 'Mate SC',
		'Maven Pro' => 'Maven Pro',
		'McLaren' => 'McLaren',
		'Meddon' => 'Meddon',
		'MedievalSharp' => 'MedievalSharp',
		'Medula One' => 'Medula One',
		'Megrim' => 'Megrim',
		'Meie Script' => 'Meie Script',
		'Merienda' => 'Merienda',
		'Merienda One' => 'Merienda One',
		'Merriweather' => 'Merriweather',
		'Metal Mania' => 'Metal Mania',
		'Metamorphous' => 'Metamorphous',
		'Metrophobic' => 'Metrophobic',
		'Michroma' => 'Michroma',
		'Milonga' => 'Milonga',
		'Miltonian' => 'Miltonian',
		'Miltonian Tattoo' => 'Miltonian Tattoo',
		'Miniver' => 'Miniver',
		'Miss Fajardose' => 'Miss Fajardose',
		'Miss Saint Delafield' => 'Miss Saint Delafield',
		'Modern Antiqua' => 'Modern Antiqua',
		'Molengo' => 'Molengo',
		'Molle' => 'Molle',
		'Monda' => 'Monda',
		'Monofett' => 'Monofett',
		'Monoton' => 'Monoton',
		'Monsieur La Doulaise' => 'Monsieur La Doulaise',
		'Montaga' => 'Montaga',
		'Montez' => 'Montez',
		'Montserrat' => 'Montserrat',
		'Montserrat Alternates' => 'Montserrat Alternates',
		'Montserrat Subrayada' => 'Montserrat Subrayada',
		'Mountains of Christmas' => 'Mountains of Christmas',
		'Mouse Memoirs' => 'Mouse Memoirs',
		'Mr Bedford' => 'Mr Bedford',
		'Mr Bedfort' => 'Mr Bedfort',
		'Mr Dafoe' => 'Mr Dafoe',
		'Mr De Haviland' => 'Mr De Haviland',
		'Mrs Saint Delafield' => 'Mrs Saint Delafield',
		'Mrs Sheppards' => 'Mrs Sheppards',
		'Muli' => 'Muli',
		'Mystery Quest' => 'Mystery Quest',
		'Neucha' => 'Neucha',
		'Neuton' => 'Neuton',
		'New Rocker' => 'New Rocker',
		'News Cycle' => 'News Cycle',
		'Niconne' => 'Niconne',
		'Nixie One' => 'Nixie One',
		'Nobile' => 'Nobile',
		'Norican' => 'Norican',
		'Nosifer' => 'Nosifer',
		'Nosifer Caps' => 'Nosifer Caps',
		'Noticia Text' => 'Noticia Text',
		'Nova Round' => 'Nova Round',
		'Numans' => 'Numans',
		'Nunito' => 'Nunito',
		'Offside' => 'Offside',
		'Oldenburg' => 'Oldenburg',
		'Oleo Script' => 'Oleo Script',
		'Oleo Script Swash Caps' => 'Oleo Script Swash Caps',
		'Open Sans' => 'Open Sans',
		'Open Sans Condensed' => 'Open Sans Condensed',
		'Oranienbaum' => 'Oranienbaum',
		'Orbitron' => 'Orbitron',
		'Oregano' => 'Oregano',
		'Orienta' => 'Orienta',
		'Original Surfer' => 'Original Surfer',
		'Oswald' => 'Oswald',
		'Over the Rainbow' => 'Over the Rainbow',
		'Overlock' => 'Overlock',
		'Overlock SC' => 'Overlock SC',
		'Ovo' => 'Ovo',
		'Oxygen' => 'Oxygen',
		'Oxygen Mono' => 'Oxygen Mono',
		'PT Mono' => 'PT Mono',
		'PT Sans' => 'PT Sans',
		'PT Sans Narrow' => 'PT Sans Narrow',
		'PT Serif' => 'PT Serif',
		'PT Serif Caption' => 'PT Serif Caption',
		'Pacifico' => 'Pacifico',
		'Paprika' => 'Paprika',
		'Parisienne' => 'Parisienne',
		'Passero One' => 'Passero One',
		'Passion One' => 'Passion One',
		'Patrick Hand' => 'Patrick Hand',
		'Patua One' => 'Patua One',
		'Paytone One' => 'Paytone One',
		'Peralta' => 'Peralta',
		'Permanent Marker' => 'Permanent Marker',
		'Petit Formal Script' => 'Petit Formal Script',
		'Petrona' => 'Petrona',
		'Philosopher' => 'Philosopher',
		'Piedra' => 'Piedra',
		'Pinyon Script' => 'Pinyon Script',
		'Pirata One' => 'Pirata One',
		'Plaster' => 'Plaster',
		'Play' => 'Play',
		'Playball' => 'Playball',
		'Playfair Display' => 'Playfair Display',
		'Playfair Display SC' => 'Playfair Display SC',
		'Podkova' => 'Podkova',
		'Poiret One' => 'Poiret One',
		'Poller One' => 'Poller One',
		'Poly' => 'Poly',
		'Pompiere' => 'Pompiere',
		'Pontano Sans' => 'Pontano Sans',
		'Port Lligat Sans' => 'Port Lligat Sans',
		'Port Lligat Slab' => 'Port Lligat Slab',
		'Prata' => 'Prata',
		'Press Start 2P' => 'Press Start 2P',
		'Princess Sofia' => 'Princess Sofia',
		'Prociono' => 'Prociono',
		'Prosto One' => 'Prosto One',
		'Puritan' => 'Puritan',
		'Purple Purse' => 'Purple Purse',
		'Quando' => 'Quando',
		'Quantico' => 'Quantico',
		'Quattrocento' => 'Quattrocento',
		'Quattrocento Sans' => 'Quattrocento Sans',
		'Questrial' => 'Questrial',
		'Quicksand' => 'Quicksand',
		'Quintessential' => 'Quintessential',
		'Qwigley' => 'Qwigley',
		'Racing Sans One' => 'Racing Sans One',
		'Radley' => 'Radley',
		'Raleway Dots' => 'Raleway Dots',
		'Raleway' => 'Raleway',
		'Rambla' => 'Rambla',
		'Rammetto One' => 'Rammetto One',
		'Ranchers' => 'Ranchers',
		'Rancho' => 'Rancho',
		'Rationale' => 'Rationale',
		'Redressed' => 'Redressed',
		'Reenie Beanie' => 'Reenie Beanie',
		'Revalia' => 'Revalia',
		'Ribeye' => 'Ribeye',
		'Ribeye Marrow' => 'Ribeye Marrow',
		'Righteous' => 'Righteous',
		'Risque' => 'Risque',
		'Roboto' => 'Roboto',
		'Roboto Condensed' => 'Roboto Condensed',
		'Roboto Condensed Light' => 'Roboto Condensed Light',
		'Rochester' => 'Rochester',
		'Rock Salt' => 'Rock Salt',
		'Rokkitt' => 'Rokkitt',
		'Romanesco' => 'Romanesco',
		'Ropa Sans' => 'Ropa Sans',
		'Rosario' => 'Rosario',
		'Rosarivo' => 'Rosarivo',
		'Rouge Script' => 'Rouge Script',
		'Ruda' => 'Ruda',
		'Rufina' => 'Rufina',
		'Ruge Boogie' => 'Ruge Boogie',
		'Ruluko' => 'Ruluko',
		'Rum Raisin' => 'Rum Raisin',
		'Ruslan Display' => 'Ruslan Display',
		'Russo One' => 'Russo One',
		'Ruthie' => 'Ruthie',
		'Rye' => 'Rye',
		'Sacramento' => 'Sacramento',
		'Sail' => 'Sail',
		'Salsa' => 'Salsa',
		'Sanchez' => 'Sanchez',
		'Sancreek' => 'Sancreek',
		'Sansita One' => 'Sansita One',
		'Sarina' => 'Sarina',
		'Satisfy' => 'Satisfy',
		'Scada' => 'Scada',
		'Schoolbell' => 'Schoolbell',
		'Seaweed Script' => 'Seaweed Script',
		'Sevillana' => 'Sevillana',
		'Seymour One' => 'Seymour One',
		'Shadows Into Light' => 'Shadows Into Light',
		'Shadows Into Light Two' => 'Shadows Into Light Two',
		'Shanti' => 'Shanti',
		'Share' => 'Share',
		'Share Tech' => 'Share Tech',
		'Share Tech Mono' => 'Share Tech Mono',
		'Shojumaru' => 'Shojumaru',
		'Short Stack' => 'Short Stack',
		'Sigmar One' => 'Sigmar One',
		'Signika' => 'Signika',
		'Signika Negative' => 'Signika Negative',
		'Simonetta' => 'Simonetta',
		'Sirin Stencil' => 'Sirin Stencil',
		'Six Caps' => 'Six Caps',
		'Skranji' => 'Skranji',
		'Slackey' => 'Slackey',
		'Smokum' => 'Smokum',
		'Smythe' => 'Smythe',
		'Sniglet' => 'Sniglet',
		'Snippet' => 'Snippet',
		'Snowburst One' => 'Snowburst One',
		'Sofadi One' => 'Sofadi One',
		'Sofia' => 'Sofia',
		'Sonsie One' => 'Sonsie One',
		'Sorts Mill Goudy' => 'Sorts Mill Goudy',
		'Sorts Mill Goudy' => 'Sorts Mill Goudy',
		'Source Code Pro' => 'Source Code Pro',
		'Source Sans Pro' => 'Source Sans Pro',
		'Special I am one' => 'Special I am one',
		'Spicy Rice' => 'Spicy Rice',
		'Spinnaker' => 'Spinnaker',
		'Spirax' => 'Spirax',
		'Squada One' => 'Squada One',
		'Stalemate' => 'Stalemate',
		'Stalinist One' => 'Stalinist One',
		'Stardos Stencil' => 'Stardos Stencil',
		'Stint Ultra Condensed' => 'Stint Ultra Condensed',
		'Stint Ultra Expanded' => 'Stint Ultra Expanded',
		'Stoke' => 'Stoke',
		'Stoke' => 'Stoke',
		'Strait' => 'Strait',
		'Sue Ellen Francisco' => 'Sue Ellen Francisco',
		'Sunshiney' => 'Sunshiney',
		'Supermercado One' => 'Supermercado One',
		'Swanky and Moo Moo' => 'Swanky and Moo Moo',
		'Syncopate' => 'Syncopate',
		'Tangerine' => 'Tangerine',
		'Telex' => 'Telex',
		'Tenor Sans' => 'Tenor Sans',
		'Terminal Dosis' => 'Terminal Dosis',
		'Terminal Dosis Light' => 'Terminal Dosis Light',
		'Text Me One' => 'Text Me One',
		'The Girl Next Door' => 'The Girl Next Door',
		'Tienne' => 'Tienne',
		'Tinos' => 'Tinos',
		'Titan One' => 'Titan One',
		'Titillium Web' => 'Titillium Web',
		'Trade Winds' => 'Trade Winds',
		'Trocchi' => 'Trocchi',
		'Trochut' => 'Trochut',
		'Trykker' => 'Trykker',
		'Tulpen One' => 'Tulpen One',
		'Ubuntu' => 'Ubuntu',
		'Ubuntu Condensed' => 'Ubuntu Condensed',
		'Ubuntu Mono' => 'Ubuntu Mono',
		'Ultra' => 'Ultra',
		'Uncial Antiqua' => 'Uncial Antiqua',
		'Underdog' => 'Underdog',
		'Unica One' => 'Unica One',
		'UnifrakturCook' => 'UnifrakturCook',
		'UnifrakturMaguntia' => 'UnifrakturMaguntia',
		'Unkempt' => 'Unkempt',
		'Unlock' => 'Unlock',
		'Unna' => 'Unna',
		'VT323' => 'VT323',
		'Vampiro One' => 'Vampiro One',
		'Varela' => 'Varela',
		'Varela Round' => 'Varela Round',
		'Vast Shadow' => 'Vast Shadow',
		'Vibur' => 'Vibur',
		'Vidaloka' => 'Vidaloka',
		'Viga' => 'Viga',
		'Voces' => 'Voces',
		'Volkhov' => 'Volkhov',
		'Vollkorn' => 'Vollkorn',
		'Voltaire' => 'Voltaire',
		'Waiting for the Sunrise' => 'Waiting for the Sunrise',
		'Wallpoet' => 'Wallpoet',
		'Walter Turncoat' => 'Walter Turncoat',
		'Warnes' => 'Warnes',
		'Wellfleet' => 'Wellfleet',
		'Wendy One' => 'Wendy One',
		'Wire One' => 'Wire One',
		'Yanone Kaffeesatz' => 'Yanone Kaffeesatz',
		'Yellowtail' => 'Yellowtail',
		'Yeseva One' => 'Yeseva One',
		'Yesteryear' => 'Yesteryear',
		'Zeyada' => 'Zeyada'
	);

	//array of all font sizes.
	$font_sizes = array( 
		'10px' => '10px',
		'11px' => '11px',
	);
	for($n=12;$n<=100;$n+=1){
		$font_sizes[$n.'px'] = $n.'px';
	}

	// array of section content.
	$section_text = array(
		1 => array(
			'section_title'	=> '',
			'menutitle'		=> 'wrapsecond',
			'bgcolor' 		=> '#F5F5F5',
			'bgimage'		=> '',
			'class'			=> 'services-wrap',
			'content'		=> '[column_content type="one_third"]<a href="#"><i class="fa fa-phone"></i>
			<h4>Free Updates & Support</h4></a><p>Lorem ipsum dolor sit amet, consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus. Cras id magna tempor, porta nunc quis consectetur adipiscinr sed gravida tortor. </p>[/column_content]

[column_content type="one_third"]<a href="#"><i class="fa fa-code"></i>
<h4>Clean Codes</h4></a> <p>Lorem ipsum dolor sit amet, consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus. Cras id magna tempor, porta nunc quis consectetur adipiscinr sed gravida tortor.</p>[/column_content]

[column_content type="one_third_last"]<a href="#"><i class="fa fa-laptop"></i>
<h4>Responsive Design</h4></a> <p>Lorem ipsum dolor sit amet, consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus. Cras id magna tempor, porta nunc quis consectetur adipiscinr sed gravida tortor. </p>[/column_content]',
		),

		2 => array(
			'section_title'	=> 'Welcome to Our Website',
			'menutitle'		=> 'aboutsection',
			'bgcolor' 		=> '#ffffff',
			'bgimage'		=> '',
			'class'			=> 'about-wrap',
			'content'		=> 'Lorem ipsum dolor sit amet, consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus. Cras id magna tempor, porta nunc quis consectetur adipiscinr sed gravida orem ipsum dolor sit amet, consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus. Cras id magna tempor, porta nunc quis consectetur adipiscinr sed gravida tortor.tortor. orem ipsum dolor sit amet, consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus. Cras id magna tempor, porta nunc quis consectetur adipiscinr sed gravida tortor. Lorem ipsum dolor sit amet, consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus. Cras id magna tempor, porta nunc quis consectetur adipiscinr sed gravida orem ipsum dolor sit amet, consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus. Cras id magna tempor, porta nunc quis consectetur adipiscinr sed gravida tortor.tortor. orem ipsum dolor sit amet, consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus. Cras id magna tempor, porta nunc quis consectetur adipiscinr sed gravida tortor.[readmore-link align="center" button="Read More" links="#"]
			<img src="'.get_template_directory_uri().'/images/zeroerror-thumb1.png" alt="" />'
		),
		
		3 => array(
			'section_title'	=> 'Our Theme Featured',
			'menutitle'		=> 'theme-featured',
			'bgcolor' 		=> '#F5F5F5',
			'bgimage'		=> '',
			'class'			=> 'featured-wrap',
			'content'		=> '[column_content type="one_third"]<img src="'.get_template_directory_uri().'/images/thumb2.png" alt="" />
			<h4>100% Responsive Ready</h4><p>Lorem ipsum dolor sit amet, consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus. Cras id magna tempor, porta nunc quis consectetur adipiscinr sed gravida tortor. </p>[/column_content]

[column_content type="one_third"]<img src="'.get_template_directory_uri().'/images/ft1.jpg" alt="" />
<h4>Advanced Theme Option</h4><p>Lorem ipsum dolor sit amet, consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus. Cras id magna tempor, porta nunc quis consectetur adipiscinr sed gravida tortor. </p>[/column_content]

[column_content type="one_third_last"]<img src="'.get_template_directory_uri().'/images/ft2.jpg" alt="" />
<h4>Custom Post Types</h4><p>Lorem ipsum dolor sit amet, consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus. Cras id magna tempor, porta nunc quis consectetur adipiscinr sed gravida tortor. </p>[/column_content]

[column_content type="one_third"]<img src="'.get_template_directory_uri().'/images/ft3.jpg" alt="" />
<h4>Cross-Browser Compatible</h4><p>Lorem ipsum dolor sit amet, consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus. Cras id magna tempor, porta nunc quis consectetur adipiscinr sed gravida tortor. </p>[/column_content]

[column_content type="one_third"]<img src="'.get_template_directory_uri().'/images/ft4.jpg" alt="" />
<h4>SEO Friendly</h4><p>Lorem ipsum dolor sit amet, consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus. Cras id magna tempor, porta nunc quis consectetur adipiscinr sed gravida tortor. </p>[/column_content]

[column_content type="one_third_last"]<img src="'.get_template_directory_uri().'/images/ft5.jpg" alt="" />
<h4>WooCommerce Compatible</h4><p>Lorem ipsum dolor sit amet, consectetur adipiscinr sed gravida tortor, sed ullamcorper tellus. Cras id magna tempor, porta nunc quis consectetur adipiscinr sed gravida tortor. </p>[/column_content]'
		),	
		
		4 => array(
			'section_title'	=> 'Recents Posts',
			'menutitle'		=> 'latestposts',
			'bgcolor' 		=> '#ffffff',
			'bgimage'		=> '',
			'class'			=> 'posts-wrap',
			'content'		=> '[recent-posts show="4"]'
		),
		
		5 => array(
			'section_title'	=> 'Our Success Story',
			'menutitle'		=> 'testimonialsarea',
			'bgcolor' 		=> '#bac0c4',
			'bgimage'		=> get_template_directory_uri()."/images/testimonial-bg.jpg",
			'class'			=> 'testimonials-wrap',
			'content'		=> '[testimonials]'		
		),
		
		6 => array(
			'section_title'	=> 'Photo Gallery Post Type',
			'menutitle'		=> 'ourgallery',
			'bgcolor' 		=> '#ffffff',
			'bgimage'		=> '',
			'class'			=> 'gallery-wrap',
			'content'		=> '[photogallery filter="true" show="8"]'
		),	

	);

	$options = array();

	//Basic Settings
	$options[] = array(
		'name' => __('Basic Settings', 'grc-zeroerror'),
		'type' => 'heading');

	$options[] = array(
		'name' => __('Logo', 'grc-zeroerror'),
		'desc' => __('Upload your main logo here', 'grc-zeroerror'),
		'id' => 'logo',
		'class' => '',
		'std'	=> '',
		'type' => 'upload');
		
	$options[] = array(	
		'desc' => __('enter your custom logo height', 'grc-zeroerror'),
		'id' => 'logoheight',
		'std' => '35',
		'type' => 'text');	
		
	$options[] = array(
		'name' => __('Custom CSS', 'grc-zeroerror'),
		'desc' => __('Some Custom Styling for your site. Place any css codes here instead of the style.css file.', 'grc-zeroerror'),
		'id' => 'style2',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'name' => __('Responsive View Menu Text Changeable', 'grc-zeroerror'),
		'desc' => __('Change menu word on responsive view', 'grc-zeroerror'),
		'id' => 'menutextchange',
		'std' => 'Menu',
		'type' => 'text');		
		
	$options[] = array(
		'name' => __('Header Top Info', 'grc-zeroerror'),
		'desc' => __('Edit header info from here. NOTE: Icon name should be in lowercase without space.(exa.phone) More social icons can be found at: http://fortawesome.github.io/Font-Awesome/icons/', 'grc-zeroerror'),
		'id' => 'headerinfo',
		'std' => '<i class="fa fa-phone"></i> <span class="phno">+11 123 456 7890</span> <i class="fa fa-envelope"></i>demomail@gmail.com ',
		'type' => 'textarea');	
		
	$options[] = array(
		'name' => __('Header Top Social Icons', 'grc-zeroerror'),
		'desc' => __('Edit select social icons for header top', 'grc-zeroerror'),
		'id' => 'headersocial',
		'std' => ' [social_area][social icon="facebook" link="#"] [social icon="twitter" link="#"] [social icon="google-plus" link="#"] [social icon="linkedin" link="#"][/social_area]',
		'type' => 'textarea');	
		
	$options[] = array(
		'name' => __('Sticky Header', 'grc-zeroerror'),
		'desc' => __('Check this to disable sticky header on scroll', 'grc-zeroerror'),
		'id' => 'headstick',
		'std' => '',
		'type' => 'checkbox');
		
	$options[] = array(
		'name' => __('Disable Animation', 'grc-zeroerror'),
		'desc' => __('Check this to disable animation on scroll', 'grc-zeroerror'),
		'id' => 'scrollanimation',
		'std' => '',
		'type' => 'checkbox');		
		
	// font family start 		
	$options[] = array(
		'name' => __('Font Faces', 'grc-zeroerror'),
		'desc' => __('Select font for the body text', 'grc-zeroerror'),
		'id' => 'bodyfontface',
		'type' => 'select',
		'std' => 'PT Sans',
		'options' => $font_types );
		
	$options[] = array(
		'desc' => __('Select font for the textual logo', 'grc-zeroerror'),
		'id' => 'logofontface',
		'type' => 'select',
		'std' => 'Raleway',
		'options' => $font_types );
		
	$options[] = array(
		'desc' => __('Select font for the navigation text', 'grc-zeroerror'),
		'id' => 'navfontface',
		'type' => 'select',
		'std' => 'Raleway',
		'options' => $font_types );
		
	$options[] = array(
		'desc' => __('Select font for heading text. eg: H1, H2, H3, H4, H5, H6', 'grc-zeroerror'),
		'id' => 'headfontface',
		'type' => 'select',
		'std' => 'Raleway',
		'options' => $font_types );
		
	$options[] = array(
		'desc' => __('Select font family for header top bar', 'grc-zeroerror'),
		'id' => 'hdrtopfontface',
		'type' => 'select',
		'std' => 'PT Sans',
		'options' => $font_types );	
		
	// font sizes start	
	$options[] = array(
		'name' => __('Font Sizes', 'grc-zeroerror'),
		'desc' => __('Select font size for body text', 'grc-zeroerror'),
		'id' => 'bodyfontsize',
		'type' => 'select',
		'std' => '13px',
		'options' => $font_sizes );
		
	$options[] = array(
		'desc' => __('Select font size for textual logo', 'grc-zeroerror'),
		'id' => 'logofontsize',
		'type' => 'select',
		'std' => '36px',
		'options' => $font_sizes );
		
	$options[] = array(
		'desc' => __('Select font size for navigation', 'grc-zeroerror'),
		'id' => 'navfontsize',
		'type' => 'select',
		'std' => '15px',
		'options' => $font_sizes );	
		
	$options[] = array(
		'desc' => __('Select font size for section title', 'grc-zeroerror'),
		'id' => 'sectitlesize',
		'type' => 'select',
		'std' => '30px',
		'options' => $font_sizes );
	
		
	$options[] = array(
		'desc' => __('Select font size for footer title', 'grc-zeroerror'),
		'id' => 'ftfontsize',
		'type' => 'select',
		'std' => '18px',
		'options' => $font_sizes );	
		
	$options[] = array(
		'desc' => __('Select font size for header top bar', 'grc-zeroerror'),
		'id' => 'hdrtopfontsize',
		'type' => 'select',
		'std' => '13px',
		'options' => $font_sizes );	
			

	// font colors start

	$options[] = array(
		'name' => __('Font Colors', 'grc-zeroerror'),
		'desc' => __('Select font color for the body text', 'grc-zeroerror'),
		'id' => 'bodyfontcolor',
		'std' => '#333333',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for textual logo', 'grc-zeroerror'),
		'id' => 'logofontcolor',
		'std' => '#8eae0e',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for section title', 'grc-zeroerror'),
		'id' => 'sectitlecolor',
		'std' => '#333333',
		'type' => 'color');			
	

	$options[] = array(
		'desc' => __('Select font color for navigation', 'grc-zeroerror'),
		'id' => 'navfontcolor',
		'std' => '#333333',
		'type' => 'color');

	$options[] = array(
		'desc' => __('Select font color for navigation hover', 'grc-zeroerror'),
		'id' => 'navhovercolor',
		'std' => '#8eae0e',
		'type' => 'color');
	
		
	$options[] = array(
		'desc' => __('Select font color for widget title', 'grc-zeroerror'),
		'id' => 'wdgttitleccolor',
		'std' => '#ffffff',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for footer title', 'grc-zeroerror'),
		'id' => 'foottitlecolor',
		'std' => '#ffffff',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for footer', 'grc-zeroerror'),
		'id' => 'footdesccolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for footer menu ', 'grc-zeroerror'),
		'id' => 'footermenucolor',
		'std' => '#ffffff',
		'type' => 'color');		
		
	$options[] = array(
		'desc' => __('Select hover/active font color for footer menu ', 'grc-zeroerror'),
		'id' => 'footermenucurrent',
		'std' => '#333333',
		'type' => 'color');			
		
	$options[] = array(
		'desc' => __('Select font color for footer left text (copyright)', 'grc-zeroerror'),
		'id' => 'copycolor',
		'std' => '#ffffff',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select font color for footer right text (design by)', 'grc-zeroerror'),
		'id' => 'designcolor',
		'std' => '#ffffff',
		'type' => 'color');

	$options[] = array(
		'desc' => __('Select font color for links / anchor tags', 'grc-zeroerror'),
		'id' => 'linkcolor',
		'std' => '#8eae0e',
		'type' => 'color');

	$options[] = array(
		'desc' => __('Select font color for links / anchor tags on hover', 'grc-zeroerror'),
		'id' => 'linkhovercolor',
		'std' => '#8eae0e',
		'type' => 'color');			
		
	$options[] = array(
		'desc' => __('Select font color for sidebar li a', 'grc-zeroerror'),
		'id' => 'sidebarfontcolor',
		'std' => '#3b3b3b',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font hover color for sidebar li a', 'grc-zeroerror'),
		'id' => 'sidebarfonthvcolor',
		'std' => '#8eae0e',
		'type' => 'color');			
			
	$options[] = array(
		'desc' => __('Select font color for Testimonials title', 'grc-zeroerror'),
		'id' => 'tmn_titlefontcolor',
		'std' => '#cccccc',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for Testimonials section title', 'grc-zeroerror'),
		'id' => 'tmnsectiontitle',
		'std' => '#cccccc',
		'type' => 'color');		
		
	$options[] = array(
		'desc' => __('Select font color for footer links', 'grc-zeroerror'),
		'id' => 'copylinks',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font hover color for footer links', 'grc-zeroerror'),
		'id' => 'copylinkshover',
		'std' => '#8eae0e',
		'type' => 'color');		
		
	$options[] = array(
		'desc' => __('Select font color for social icons', 'grc-zeroerror'),
		'id' => 'socialfontcolor',
		'std' => '#c9c8c8',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select border hover color for social icons', 'grc-zeroerror'),
		'id' => 'socialfonthvcolor',
		'std' => '#333333',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select title color for footer posts', 'grc-zeroerror'),
		'id' => 'footerpoststitle',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select title hover color for footer posts', 'grc-zeroerror'),
		'id' => 'footerpoststitlehv',
		'std' => '#333333',
		'type' => 'color');			
		
	$options[] = array(
		'desc' => __('Select font color for our team title', 'grc-zeroerror'),
		'id' => 'teamtitlecolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font hover color for our team title', 'grc-zeroerror'),
		'id' => 'teamtitlehovercolor',
		'std' => '#8eae0e',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select color for our team social icon', 'grc-zeroerror'),
		'id' => 'teamsicolor',
		'std' => '#cccccc',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select hover color for our team social icon', 'grc-zeroerror'),
		'id' => 'teamsicolorhv',
		'std' => '#8eae0e',
		'type' => 'color');	
		
	$options[] = array(		
		'desc' => __('Select font color for header top bar', 'grc-zeroerror'),
		'id' => 'hdrtopfontcolor',
		'std' => '#8EAE0E',
		'type' => 'color');	
		
	$options[] = array(		
		'desc' => __('Select phone icon color for header top', 'grc-zeroerror'),
		'id' => 'phoneiconcolor',
		'std' => '#8eae0e',
		'type' => 'color');	
		
	$options[] = array(		
		'desc' => __('Select social icon hover color for header top', 'grc-zeroerror'),
		'id' => 'phoneiconcolorhv',
		'std' => '#333333',
		'type' => 'color');		
		
	$options[] = array(
		'desc' => __('Select font color for three column services icon', 'grc-zeroerror'),
		'id' => 'srvciconfc',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font hover color for three column services icon', 'grc-zeroerror'),
		'id' => 'srvciconfchv',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select read more link color for three column services box', 'grc-zeroerror'),
		'id' => 'srvclinkcolor',
		'std' => '#78797c',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select link hover color for three column services box', 'grc-zeroerror'),
		'id' => 'srvclinkcolorhv',
		'std' => '#8eae0e',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select title hover color for three column services box', 'grc-zeroerror'),
		'id' => 'titlecolorhv',
		'std' => '#8eae0e',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select font color for our team paragraph', 'grc-zeroerror'),
		'id' => 'teamparacolor',
		'std' => '#ffffff',
		'type' => 'color');															
	
	// Background start		
	$options[] = array(	
		'name' => __('Background Colors', 'grc-zeroerror'),	
		'desc' => __('Select background color for header', 'grc-zeroerror'),
		'id' => 'headerbg',
		'std' => '#ffffff',
		'type' => 'color');	
	
		
	$options[] = array(
		'desc' => __('Select background color for footer', 'grc-zeroerror'),
		'id' => 'footerbgcolor',
		'std' => '#8EAE0E',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select background color for copyright section', 'grc-zeroerror'),
		'id' => 'copybgcolor',
		'std' => '#617804',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select background color for gallery hover', 'grc-zeroerror'),
		'id' => 'galhvcolor',
		'std' => '#8eae0e',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select background color for sidebar widget', 'grc-zeroerror'),
		'id' => 'sidebarbgcolor',
		'std' => '#f9f9f9',
		'type' => 'color');	
		
	$options[] = array(	
		'desc' => __('Select background color for header top bar', 'grc-zeroerror'),
		'id' => 'hdrtopbgcolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background color for toggle menu', 'grc-zeroerror'),
		'id' => 'togglemenu',
		'std' => '#8eae0e',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select background color for three column services icon', 'grc-zeroerror'),
		'id' => 'srvciconbg',
		'std' => '#A8B1B8',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background hover color for three column services icon', 'grc-zeroerror'),
		'id' => 'srvciconbghv',
		'std' => '#8eae0e',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background color for testimonials pagination', 'grc-zeroerror'),
		'id' => 'tmnpagerbg',
		'std' => '#464d51',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background hover color for testimonials pagination', 'grc-zeroerror'),
		'id' => 'tmnpagerbghv',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background color for sidebat widget title', 'grc-zeroerror'),
		'id' => 'widgettitlebgcolor',
		'std' => '#8eae0e',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background color for toggle menu on responsive view', 'grc-zeroerror'),
		'id' => 'tgmenuresponsivebg',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background color for gallery filter', 'grc-zeroerror'),
		'id' => 'galleryfilterbg',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select background hover color for gallery filter', 'grc-zeroerror'),
		'id' => 'galleryfilterbghv',
		'std' => '#8EAE0E',
		'type' => 'color');																			
		
		
		
	// Border colors		
	$options[] = array(	
		'name' => __('Border Colors', 'grc-zeroerror'),				
		'desc' => __('Select top border color for our team social icon', 'grc-zeroerror'),
		'id' => 'teamsiconborder',
		'std' => '#8EAE0E',
		'type' => 'color');
		
	$options[] = array(			
		'desc' => __('Select border color for header top', 'grc-zeroerror'),
		'id' => 'headerborder',
		'std' => '#8eae0e',
		'type' => 'color');			
		
	$options[] = array(			
		'desc' => __('Select border color for iframe', 'grc-zeroerror'),
		'id' => 'iframeborder',
		'std' => '#e5e5e4',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for sidebar li a', 'grc-zeroerror'),
		'id' => 'sidebarliaborder',
		'std' => '#d0cfcf',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for read more button', 'grc-zeroerror'),
		'id' => 'readmorebutton',
		'std' => '#454545',
		'type' => 'color');	
	
	$options[] = array(			
		'desc' => __('Select border hover color for read more button', 'grc-zeroerror'),
		'id' => 'readmorebuttonhv',
		'std' => '#8eae0e',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border bottom color for section', 'grc-zeroerror'),
		'id' => 'secborderbottom',
		'std' => '#eaeaea',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for footer title', 'grc-zeroerror'),
		'id' => 'foottitleborder',
		'std' => '#cdd99d',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for header top', 'grc-zeroerror'),
		'id' => 'headertopborder',
		'std' => '#E4E8ED',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for header menu active', 'grc-zeroerror'),
		'id' => 'menuactiveborder',
		'std' => '#8EAE0E',
		'type' => 'color');
		
	$options[] = array(			
		'desc' => __('Select border color for about Section', 'grc-zeroerror'),
		'id' => 'aboutsectionborder',
		'std' => '#EAEAEA',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for gallery filter', 'grc-zeroerror'),
		'id' => 'filterborder',
		'std' => '#dedede',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border hover color for gallery filter', 'grc-zeroerror'),
		'id' => 'filterborderhv',
		'std' => '#7a9705',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for footer social icon', 'grc-zeroerror'),
		'id' => 'footersocialbdr',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for team member designation', 'grc-zeroerror'),
		'id' => 'memberdesignation',
		'std' => '#8EAE0E',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for recent post box', 'grc-zeroerror'),
		'id' => 'recentpostbxborder',
		'std' => '#EDE9E9',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for theme featured image box', 'grc-zeroerror'),
		'id' => 'featuredimgbx',
		'std' => '#CCCCCC',
		'type' => 'color');	
		
	$options[] = array(			
		'desc' => __('Select border color for footer recent post image', 'grc-zeroerror'),
		'id' => 'recentpostimgbdr',
		'std' => '#ffffff',
		'type' => 'color');				
		
									
			
		
	// Default Buttons		
	$options[] = array(
		'name' => __('Button Colors', 'grc-zeroerror'),		
		'desc' => __('Select background color for button', 'grc-zeroerror'),
		'id' => 'btnbgcolor',
		'std' => '#8eae0e',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select hover background color for button', 'grc-zeroerror'),
		'id' => 'btnbghvcolor',
		'std' => '#333333',
		'type' => 'color');		

	$options[] = array(
		'desc' => __('Select font color button', 'grc-zeroerror'),
		'id' => 'btntxtcolor',
		'std' => '#ffffff',
		'type' => 'color');

	$options[] = array(
		'desc' => __('Select font color button on hover', 'grc-zeroerror'),
		'id' => 'btntxthvcolor',
		'std' => '#ffffff',
		'type' => 'color');	
		

		
	// Slider Caption colors	
	$options[] = array(	
		'name' => __('Slider Caption Colors', 'grc-zeroerror'),			
		'desc' => __('Select font color for slider title', 'grc-zeroerror'),
		'id' => 'slidetitlecolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(		
		'desc' => __('Select font color for slider description', 'grc-zeroerror'),
		'id' => 'slidedesccolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(		
		'desc' => __('Select font color for slider button', 'grc-zeroerror'),
		'id' => 'slidebtncolor',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(		
		'desc' => __('Select font hover color for slider button', 'grc-zeroerror'),
		'id' => 'slidebtncolorhv',
		'std' => '#8EAE0E',
		'type' => 'color');			
		
	$options[] = array(
		'desc' => __('Select font size for slider title', 'grc-zeroerror'),
		'id' => 'slidetitlefontsize',
		'type' => 'select',
		'std' => '36px',
		'options' => $font_sizes );
		
	$options[] = array(
		'desc' => __('Select font size for slider description', 'grc-zeroerror'),
		'id' => 'slidedescfontsize',
		'type' => 'select',
		'std' => '16px',
		'options' => $font_sizes );
		
		
	// Slider controls colors		
	$options[] = array(
		'name' => __('Slider controls Colors', 'grc-zeroerror'),
		'desc' => __('Select background color for slider pager', 'grc-zeroerror'),
		'id' => 'sldpagebg',
		'std' => '#ffffff',
		'type' => 'color');
		
	$options[] = array(
		'desc' => __('Select background color for slider pager active', 'grc-zeroerror'),
		'id' => 'sldpagehvbg',
		'std' => '#8eae0e',
		'type' => 'color');	
		
	$options[] = array(
		'name' => __('Blog Single Layout', 'grc-zeroerror'),
		'desc' => __('Select layout. eg:Boxed, Wide', 'grc-zeroerror'),
		'id' => 'singlelayout',
		'type' => 'select',
		'std' => 'singleright',
		'options' => array('singleright'=>'Blog Single Right Sidebar', 'singleleft'=>'Blog Single Left Sidebar', 'sitefull'=>'Blog Single Full Width', 'nosidebar'=>'Blog Single No Sidebar') );	
		
	$options[] = array(
		'name' => __('Woocommerce Page Layout', 'grc-zeroerror'),
		'desc' => __('Select layout. eg:right-sidebar, left-sidebar, full-width', 'grc-zeroerror'),
		'id' => 'woocommercelayout',
		'type' => 'select',
		'std' => 'woocommercesitefull',
		'options' => array('woocommerceright'=>'Woocommerce Right Sidebar', 'woocommerceleft'=>'Woocommerce Left Sidebar', 'woocommercesitefull'=>'Woocommerce Full Width') );		
		
	$options[] = array(
		'name' => __('Social Icon Style', 'grc-zeroerror'),
		'desc' => __('Select Style. eg:circle, square', 'grc-zeroerror'),
		'id' => 'socialstyle',		
		'std' => '0',
		'type' => 'select',
		'options' => array('50'=>'Social icons Style in Circle', '0'=>'Social icons Style in Square') );
		
	$options[] = array(
		'name' => __('Custom Read More Text Button', 'grc-zeroerror'),	
		'desc' => __('Chnage read more button text for homepage recent post boxes', 'grc-zeroerror'),
		'id' => 'recentpostreadmoretext',
		'std' => 'Read More >>',
		'type' => 'text');
		
	$options[] = array(			
		'desc' => __('Chnage read more button text for blog template', 'grc-zeroerror'),
		'id' => 'blogreadmoretext',
		'std' => 'Read More >>',
		'type' => 'text');	
		
	$options[] = array(
		'name' => __('Custom Excerpt Length', 'grc-zeroerror'),	
		'desc' => __('Select excerpt length for home page recent posts', 'grc-zeroerror'),
		'id' => 'hmrecentpostlength',
		'std' => '30',
		'type' => 'text');	
		
	$options[] = array(	
		'desc' => __('Select excerpt length for our success story', 'grc-zeroerror'),
		'id' => 'successstoryexcerptlength',
		'std' => '60',
		'type' => 'text');	
		
	$options[] = array(	
		'desc' => __('Select excerpt length for our team member box', 'grc-zeroerror'),
		'id' => 'teamexcerptlength',
		'std' => '22',
		'type' => 'text');	
		
	$options[] = array(	
		'desc' => __('Select excerpt length for footer posts', 'grc-zeroerror'),
		'id' => 'footerpostexcerptlength',
		'std' => '10',
		'type' => 'text');
		
	$options[] = array(	
		'desc' => __('Select excerpt length for blog posts templates', 'grc-zeroerror'),
		'id' => 'blogtemplatelength',
		'std' => '80',
		'type' => 'text');									
		

	//Layout Settings
	$options[] = array(
		'name' => __('Sections', 'grc-zeroerror'),
		'type' => 'heading');

	$options[] = array(
		'name' => __('Number of Sections', 'grc-zeroerror'),
		'desc' => __('Select number of sections', 'grc-zeroerror'),
		'id' => 'numsection',
		'type' => 'select',
		'std' => '6',
		'options' => array_combine(range(1,30), range(1,30)) );

	$numsecs = of_get_option( 'numsection', 6 );

	for( $n=1; $n<=$numsecs; $n++){
		$options[] = array(
			'desc' => __("<h3>Section ".$n."</h3>", 'grc-zeroerror'),
			'class' => 'toggle_title',
			'type' => 'info');	
	
		$options[] = array(
			'name' => __('Section Title', 'grc-zeroerror'),
			'id' => 'sectiontitle'.$n,
			'std' => ( ( isset($section_text[$n]['section_title']) ) ? $section_text[$n]['section_title'] : '' ),
			'type' => 'text');

		$options[] = array(
			'name' => __('Section ID', 'grc-zeroerror'),
			'desc'	=> __('Enter your section ID here. SECTION ID MUST BE IN SMALL LETTERS ONLY AND DO NOT ADD SPACE OR SYMBOL.'),
			'id' => 'menutitle'.$n,
			'std' => ( ( isset($section_text[$n]['menutitle']) ) ? $section_text[$n]['menutitle'] : '' ),
			'type' => 'text');

		$options[] = array(
			'name' => __('Section Background Color', 'grc-zeroerror'),
			'desc' => __('Select background color for section', 'grc-zeroerror'),
			'id' => 'sectionbgcolor'.$n,
			'std' => ( ( isset($section_text[$n]['bgcolor']) ) ? $section_text[$n]['bgcolor'] : '' ),
			'type' => 'color');
			
		$options[] = array(
			'name' => __('Background Image', 'grc-zeroerror'),
			'id' => 'sectionbgimage'.$n,
			'class' => '',
			'std' => ( ( isset($section_text[$n]['bgimage']) ) ? $section_text[$n]['bgimage'] : '' ),
			'type' => 'upload');

		$options[] = array(
			'name' => __('Section CSS Class', 'grc-zeroerror'),
			'desc' => __('Set class for this section.', 'grc-zeroerror'),
			'id' => 'sectionclass'.$n,
			'std' => ( ( isset($section_text[$n]['class']) ) ? $section_text[$n]['class'] : '' ),
			'type' => 'text');
			
		$options[] = array(
			'name'	=> __('Hide Section', 'grc-zeroerror'),
			'desc'	=> __('Check to hide this section', 'grc-zeroerror'),
			'id'	=> 'hidesec'.$n,
			'type'	=> 'checkbox',
			'std'	=> '');

		$options[] = array(
			'name' => __('Section Content', 'grc-zeroerror'),
			'id' => 'sectioncontent'.$n,
			'std' => ( ( isset($section_text[$n]['content']) ) ? $section_text[$n]['content'] : '' ),
			'type' => 'editor');
	}


	//SLIDER SETTINGS
	$options[] = array(
		'name' => __('Homepage Slider', 'grc-zeroerror'),
		'type' => 'heading');
		
	$options[] = array(
		'name' => __('Inner Page Banner', 'grc-zeroerror'),
		'desc' => __('Upload inner page banner for site', 'grc-zeroerror'),
		'id' => 'innerpagebanner',
		'class' => '',
		'std'	=> get_template_directory_uri()."/images/default-banner.jpg",
		'type' => 'upload');
		
	$options[] = array(
		'name' => __('Custom Slider Shortcode Area For Home Page', 'grc-zeroerror'),
		'desc' => __('Enter here your slider shortcode without php tag', 'grc-zeroerror'),
		'id' => 'customslider',
		'std' => '',
		'type' => 'textarea');		
		
	$options[] = array(
		'name' => __('Slider Effects and Timing', 'grc-zeroerror'),
		'desc' => __('Select slider effect.','grc-zeroerror'),
		'id' => 'slideefect',
		'std' => 'fade',
		'type' => 'select',
		'options' => array('random'=>'Random', 'fade'=>'Fade', 'fold'=>'Fold', 'sliceDown'=>'Slide Down', 'sliceDownLeft'=>'Slide Down Left', 'sliceUp'=>'Slice Up', 'sliceUpLeft'=>'Slice Up Left', 'sliceUpDown'=>'Slice Up Down', 'sliceUpDownLeft'=>'Slice Up Down Left', 'slideInRight'=>'SlideIn Right', 'slideInLeft'=>'SlideIn Left', 'boxRandom'=>'Box Random', 'boxRain'=>'Box Rain', 'boxRainReverse'=>'Box Rain Reverse', 'boxRainGrow'=>'Box Rain Grow', 'boxRainGrowReverse'=>'Box Rain Grow Reverse' ));
		
	$options[] = array(
		'desc' => __('Animation speed should be multiple of 100.', 'grc-zeroerror'),
		'id' => 'slideanim',
		'std' => 500,
		'type' => 'text');
		
	$options[] = array(
		'desc' => __('Add slide pause time.', 'grc-zeroerror'),
		'id' => 'slidepause',
		'std' => 4000,
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slide Controllers', 'grc-zeroerror'),
		'desc' => __('Hide/Show Next, Prev arrows of slider.','grc-zeroerror'),
		'id' => 'slidenav',
		'std' => 'true',
		'type' => 'select',
		'options' => array('true'=>'Show', 'false'=>'Hide'));
		
	$options[] = array(
		'desc' => __('Hide/Show pager of slider.','grc-zeroerror'),
		'id' => 'slidepage',
		'std' => 'true',
		'type' => 'select',
		'options' => array('true'=>'Show', 'false'=>'Hide'));
		
	$options[] = array(
		'desc' => __('Pause Slide on Hover.','grc-zeroerror'),
		'id' => 'slidepausehover',
		'std' => 'false',
		'type' => 'select',
		'options' => array('true'=>'Yes', 'false'=>'No'));
		
	$options[] = array(
		'name' => __('Slider Image 1', 'grc-zeroerror'),
		'desc' => __('First Slide', 'grc-zeroerror'),
		'id' => 'slide1',
		'class' => '',
		'std' => get_template_directory_uri()."/images/slides/slider1.jpg",
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 1', 'grc-zeroerror'),
		'id' => 'slidetitle1',
		'std' => '<strong>Multipurpose</strong> Wordpress themes ',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'grc-zeroerror'),
		'id' => 'slidedesc1',
		'std' => 'Nunc sed lorem pretium, volutpat tortor id, adipiscing sem. Sed bibendum quis augue nec porta. Ut molestie tortor pulvinar, faucibus justo vitae, interdum nunc. Vestibulum imperdiet nisl vel condimentum faucibus. Vivamus rutrum ipsum vel luctus. ',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'grc-zeroerror'),
		'id' => 'slidebutton1',
		'std' => 'Read More',
		'type' => 'text');		
		
	$options[] = array(
		'desc' => __('Slide Url', 'grc-zeroerror'),
		'id' => 'slideurl1',
		'std' => '#',
		'type' => 'text');		
		
	
	$options[] = array(
		'name' => __('Slider Image 2', 'grc-zeroerror'),
		'desc' => __('Second Slide', 'grc-zeroerror'),
		'class' => '',
		'id' => 'slide2',
		'std' => get_template_directory_uri()."/images/slides/slider2.jpg",
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 2', 'grc-zeroerror'),
		'id' => 'slidetitle2',
		'std' => '<strong>Responsive</strong> Wordpress themes',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'grc-zeroerror'),
		'id' => 'slidedesc2',
		'std' => 'Nunc sed lorem pretium, volutpat tortor id, adipiscing sem. Sed bibendum quis augue nec porta. Ut molestie tortor pulvinar, faucibus justo vitae, interdum nunc. Vestibulum imperdiet nisl vel condimentum faucibus. Vivamus rutrum ipsum vel luctus. ',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'grc-zeroerror'),
		'id' => 'slidebutton2',
		'std' => 'Read More',
		'type' => 'text');			
			
	$options[] = array(
		'desc' => __('Slide Url', 'grc-zeroerror'),
		'id' => 'slideurl2',
		'std' => '#',
		'type' => 'text');	
	
		
	$options[] = array(
		'name' => __('Slider Image 3', 'grc-zeroerror'),
		'desc' => __('Third Slide', 'grc-zeroerror'),
		'id' => 'slide3',
		'class' => '',
		'std' => get_template_directory_uri()."/images/slides/slider3.jpg",
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 3', 'grc-zeroerror'),
		'id' => 'slidetitle3',
		'std' => 'Easy <strong> Customization </strong> theme option',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'grc-zeroerror'),
		'id' => 'slidedesc3',
		'std' => 'Nunc sed lorem pretium, volutpat tortor id, adipiscing sem. Sed bibendum quis augue nec porta. Ut molestie tortor pulvinar, faucibus justo vitae, interdum nunc. Vestibulum imperdiet nisl vel condimentum faucibus. Vivamus rutrum ipsum vel luctus.',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'grc-zeroerror'),
		'id' => 'slidebutton3',
		'std' => 'Read More',
		'type' => 'text');			
	
	$options[] = array(
		'desc' => __('Slide Url', 'grc-zeroerror'),
		'id' => 'slideurl3',
		'std' => '#',
		'type' => 'text');	
			
	
	$options[] = array(
		'name' => __('Slider Image 4', 'grc-zeroerror'),
		'desc' => __('Fourth Slide', 'grc-zeroerror'),
		'id' => 'slide4',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 4', 'grc-zeroerror'),
		'id' => 'slidetitle4',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'grc-zeroerror'),
		'id' => 'slidedesc4',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'grc-zeroerror'),
		'id' => 'slidebutton4',
		'std' => '',
		'type' => 'text');		
				
		
	$options[] = array(
		'desc' => __('Slide Url', 'grc-zeroerror'),
		'id' => 'slideurl4',
		'std' => '',
		'type' => 'text');				
	
	$options[] = array(
		'name' => __('Slider Image 5', 'grc-zeroerror'),
		'desc' => __('Fifth Slide', 'grc-zeroerror'),
		'id' => 'slide5',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 5', 'grc-zeroerror'),
		'id' => 'slidetitle5',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'grc-zeroerror'),
		'id' => 'slidedesc5',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'grc-zeroerror'),
		'id' => 'slidebutton5',
		'std' => '',
		'type' => 'text');			
		
	$options[] = array(
		'desc' => __('Slide Url', 'grc-zeroerror'),
		'id' => 'slideurl5',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 6', 'grc-zeroerror'),
		'desc' => __('Sixth Slide', 'grc-zeroerror'),
		'id' => 'slide6',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
		
	$options[] = array(
		'desc' => __('Title 6', 'grc-zeroerror'),
		'id' => 'slidetitle6',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'grc-zeroerror'),
		'id' => 'slidedesc6',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'grc-zeroerror'),
		'id' => 'slidebutton6',
		'std' => '',
		'type' => 'text');		
		
	$options[] = array(
		'desc' => __('Slide Url', 'grc-zeroerror'),
		'id' => 'slideurl6',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 7', 'grc-zeroerror'),
		'desc' => __('Seventh Slide', 'grc-zeroerror'),
		'id' => 'slide7',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 7', 'grc-zeroerror'),
		'id' => 'slidetitle7',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'grc-zeroerror'),
		'id' => 'slidedesc7',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'grc-zeroerror'),
		'id' => 'slidebutton7',
		'std' => '',
		'type' => 'text');					
		
	$options[] = array(
		'desc' => __('Slide Url', 'grc-zeroerror'),
		'id' => 'slideurl7',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 8', 'grc-zeroerror'),
		'desc' => __('Eighth Slide', 'grc-zeroerror'),
		'id' => 'slide8',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 8', 'grc-zeroerror'),
		'id' => 'slidetitle8',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'grc-zeroerror'),
		'id' => 'slidedesc8',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'grc-zeroerror'),
		'id' => 'slidebutton8',
		'std' => '',
		'type' => 'text');		
		
	$options[] = array(
		'desc' => __('Slide Url', 'grc-zeroerror'),
		'id' => 'slideurl8',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 9', 'grc-zeroerror'),
		'desc' => __('Ninth Slide', 'grc-zeroerror'),
		'id' => 'slide9',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 9', 'grc-zeroerror'),
		'id' => 'slidetitle9',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'grc-zeroerror'),
		'id' => 'slidedesc9',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'grc-zeroerror'),
		'id' => 'slidebutton9',
		'std' => '',
		'type' => 'text');		
		
	$options[] = array(
		'desc' => __('Slide Url', 'grc-zeroerror'),
		'id' => 'slideurl9',
		'std' => '',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slider Image 10', 'grc-zeroerror'),
		'desc' => __('Tenth Slide', 'grc-zeroerror'),
		'id' => 'slide10',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 10', 'grc-zeroerror'),
		'id' => 'slidetitle10',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'grc-zeroerror'),
		'id' => 'slidedesc10',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Read More Button Text', 'grc-zeroerror'),
		'id' => 'slidebutton10',
		'std' => '',
		'type' => 'text');					
	
	$options[] = array(
		'desc' => __('Slide Url', 'grc-zeroerror'),
		'id' => 'slideurl10',
		'std' => '',
		'type' => 'text');

	//Footer SETTINGS
	$options[] = array(
		'name' => __('Footer', 'grc-zeroerror'),
		'type' => 'heading');
		
	$options[] = array(
		'name' => __('Footer Layout', 'grc-zeroerror'),
		'desc' => __('footer Select layout. eg:Boxed, 1, 2, 3 and 4', 'grc-zeroerror'),
		'id' => 'footerlayout',
		'type' => 'select',
		'std' => 'fourcolumn',
		'options' => array('onecolumn'=>'Footer 1 column', 
		'twocolumn'=>'Footer 2 column', 'threecolumn'=>'Footer 3 column', 'fourcolumn'=>'Footer 4 column', ) );		
				
	$options[] = array(
		'name' => __('Footer About Us', 'grc-zeroerror'),
		'desc' => __('about us text title for footer', 'grc-zeroerror'),
		'id' => 'aboutustitle',
		'std' => 'About Us',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('About kraft Description', 'grc-zeroerror'),
		'desc' => __('about kraft text description for footer', 'grc-zeroerror'),
		'id' => 'aboutdescription',
		'std' => '<p>Nam aliquet aliquam ipsum eget volutpat. Duis nec porta purus. Integer adipiscing augue sit amet libero vulputate, et fermentum nibh rutrum. In bibendum nisi sed consequat hendrerit. Aliquam.</p>
<p>Quisque elementum, dolor nec tempus eleifend, nibh mauris aliquet ante, eu tempus sapien nisi non nunc. Nulla facilisi. </p> ',
		'type' => 'textarea');
		
	$options[] = array(
		'name' => __('Our Menu', 'grc-zeroerror'),
		'desc' => __('Footer menu title.', 'grc-zeroerror'),
		'id' => 'usefullinktitle',
		'std' => 'Our Menu',
		'type' => 'text');	
		
	$options[] = array(
		'desc' => __('add social icon name and link in the shortcodes.', 'grc-zeroerror'),
		'id' => 'footersocialicons',
		'std' => '[social_area]
    [social icon="facebook" link="#"]
    [social icon="twitter" link="#"]
    [social icon="linkedin" link="#"]
    [social icon="pinterest" link="#"]
    [social icon="google-plus" link="#"]	
[/social_area]',
		'type' => 'textarea');		
		
	$options[] = array(
		'name' => __(' Recent Posts Title', 'grc-zeroerror'),
		'desc' => __('recent posts title for footer.', 'grc-zeroerror'),
		'id' => 'frptitle',
		'std' => 'Recent Posts',
		'type' => 'text');	
		
		
	$options[] = array(
		'name' => __('Footer Address Title', 'grc-zeroerror'),
		'desc' => __('Add contact title here', 'grc-zeroerror'),
		'id' => 'contacttitle',
		'std' => 'Contact Info',
		'type' => 'text');	
		
	$options[] = array(	
		'desc' => __('Add company address1 here.', 'grc-zeroerror'),
		'id' => 'address',
		'std' => '100 King St, Melbourne PIC 4000, Australia',
		'type' => 'textarea');
		
	$options[] = array(		
		'desc' => __('Add phone number here.', 'grc-zeroerror'),
		'id' => 'phone',
		'std' => '+1 800 234 5678',
		'type' => 'text');
		
	$options[] = array(
		'desc' => __('Add email address here.', 'grc-zeroerror'),
		'id' => 'email',
		'std' => 'info@sitename.com',
		'type' => 'text');
		
	$options[] = array(
		'desc' => __('Add company url here with http://.', 'grc-zeroerror'),
		'id' => 'weblink',
		'std' => 'http://demo.com',
		'type' => 'text');
		
		$options[] = array(
		'name' => __('Google Map', 'grc-zeroerror'),
		'desc' => __('Use iframe code url here. DO NOT APPLY IFRAME TAG', 'grc-zeroerror'),
		'id' => 'googlemap',
		'std' => 'https://www.google.com/maps/embed?pb=!1m18!1m12!1m3!1d336003.6066860609!2d2.349634820486094!3d48.8576730786213!2m3!1f0!2f0!3f0!3m2!1i1024!2i768!4f13.1!3m3!1m2!1s0x47e66e1f06e2b70f%3A0x040b82c3688c9460!2sParis%2C+France!5e0!3m2!1sen!2sin!4v1433482358672',
		'type' => 'textarea');
			
	
		
	$options[] = array(
		'name' => __('Footer Copyright', 'grc-zeroerror'),
		'desc' => __('Copyright Text for your site.', 'grc-zeroerror'),
		'id' => 'copytext',
		'std' => '&copy; 2015 <a href="#">GRC Zeroerror. </a> All Rights Reserved',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Footre Text Link', 'grc-zeroerror'),
		'id' => 'ftlink',
		'std' => 'Design by <a href="'.esc_url('http://www.gracethemes.com/').'" target="_blank">Grace Themes</a>',
		'type' => 'textarea',);

	//Short codes
	$options[] = array(
		'name' => __('Short Codes', 'grc-zeroerror'),
		'type' => 'heading');	
		
	
	$options[] = array(
		'name' => __('Photo Gallery', 'grc-zeroerror'),
		'desc' => __('[photogallery filter="true" show="8"]', 'grc-zeroerror'),
		'type' => 'info');			
			
		
	$options[] = array(
		'name' => __('Testimonials', 'grc-zeroerror'),
		'desc' => __('[testimonials]', 'grc-zeroerror'),
		'type' => 'info');
		
	$options[] = array(
		'name' => __('Testimonials Listing', 'grc-zeroerror'),
		'desc' => __('[testimonials-lists show="10"]', 'grc-zeroerror'),
		'type' => 'info');	
		
	$options[] = array(
		'name' => __('Contact Form', 'grc-zeroerror'),
		'desc' => __('[contactform to_email="test@example.com" title="Contact Form"] 
', 'grc-zeroerror'),
		'type' => 'info');		
		
	$options[] = array(
		'name' => __('Footer posts', 'grc-zeroerror'),
		'desc' => __('[footer-posts show="2"]', 'grc-zeroerror'),
		'type' => 'info');	
		
	$options[] = array(
		'name' => __('Team Member', 'grc-zeroerror'),
		'desc' => __('[ourteam show="3"]', 'grc-zeroerror'),
		'type' => 'info');					
	
				
	$options[] = array(
		'name' => __('Search Form', 'grc-zeroerror'),
		'desc' => __('[searchform] 
', 'grc-zeroerror'),
		'type' => 'info');
			
		
	$options[] = array(
		'name' => __('Headings', 'grc-zeroerror'),
		'desc' => __('[heading underline="yes" align="left"]Our Team[/heading]', 'grc-zeroerror'),
		'type' => 'info');					

	$options[] = array(
		'name' => __('View More Button', 'grc-zeroerror'),
		'desc' => __('[readmore-link align="left" button="Read More" links="#"]', 'grc-zeroerror'),
		'type' => 'info');	

		
	$options[] = array(
		'name' => __('Social Icons ( Note: More social icons can be found at: http://fortawesome.github.io/Font-Awesome/icons/)', 'grc-zeroerror'),
		'desc' => __('[social_area]
    [social icon="facebook" link="#"]
    [social icon="twitter" link="#"]
    [social icon="linkedin" link="#"]
    [social icon="pinterest" link="#"]
    [social icon="google-plus" link="#"]
	[social icon="youtube" link="#"]
	[social icon="wordpress" link="#"]
	[social icon="flickr" link="#"]
	[social icon="skype" link="#"]
[/social_area]', 'grc-zeroerror'),
		'type' => 'info');	
		
		

	$options[] = array(
		'name' => __('2 Column Content', 'grc-zeroerror'),
		'desc' => __('<pre>
[column_content type="one_half"]
	Column 1 Content goes here...
[/column_content]

[column_content type="one_half_last"]
	Column 2 Content goes here...
[/column_content]
</pre>', 'grc-zeroerror'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('3 Column Content', 'grc-zeroerror'),
		'desc' => __('<pre>
[column_content type="one_third"]
	Column 1 Content goes here...
[/column_content]

[column_content type="one_third"]
	Column 2 Content goes here...
[/column_content]

[column_content type="one_third_last"]
	Column 3 Content goes here...
[/column_content]
</pre>', 'grc-zeroerror'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('4 Column Content', 'grc-zeroerror'),
		'desc' => __('<pre>
[column_content type="one_fourth"]
	Column 1 Content goes here...
[/column_content]

[column_content type="one_fourth"]
	Column 2 Content goes here...
[/column_content]

[column_content type="one_fourth"]
	Column 3 Content goes here...
[/column_content]

[column_content type="one_fourth_last"]
	Column 4 Content goes here...
[/column_content]
</pre>', 'grc-zeroerror'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('5 Column Content', 'grc-zeroerror'),
		'desc' => __('<pre>
[column_content type="one_fifth"]
	Column 1 Content goes here...
[/column_content]

[column_content type="one_fifth"]
	Column 2 Content goes here...
[/column_content]

[column_content type="one_fifth"]
	Column 3 Content goes here...
[/column_content]

[column_content type="one_fifth"]
	Column 4 Content goes here...
[/column_content]

[column_content type="one_fifth_last"]
	Column 5 Content goes here...
[/column_content]
</pre>', 'grc-zeroerror'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('Clear', 'grc-zeroerror'),
		'desc' => __('<pre>
[clear]
</pre>', 'grc-zeroerror'),
		'type' => 'info');	

	$options[] = array(
		'name' => __('HR / Horizontal separation line', 'grc-zeroerror'),
		'desc' => __('<pre>
[hr] or &lt;hr&gt;
</pre>', 'grc-zeroerror'),
		'type' => 'info');

	$options[] = array(
		'name' => __('Separator / blank space', 'grc-zeroerror'),
		'desc' => __('<pre>
[separator height="20"]
</pre>', 'grc-zeroerror'),
		'type' => 'info');	
		
	$options[] = array(
		'name' => __('Blank space without image', 'grc-zeroerror'),
		'desc' => __('<pre>
[blankspace height="20"]
</pre>', 'grc-zeroerror'),
		'type' => 'info');

	$options[] = array(
		'name' => __('Tabs', 'grc-zeroerror'),
		'desc' => __('<pre>
[tabs]
	[tab title="TAB TITLE 1"]
		TAB CONTENT 1
	[/tab]
	[tab title="TAB TITLE 2"]
		TAB CONTENT 2
	[/tab]
	[tab title="TAB TITLE 3"]
		TAB CONTENT 3
	[/tab]
[/tabs]
</pre>', 'grc-zeroerror'),
		'type' => 'info');


	$options[] = array(
		'name' => __('Toggle Content', 'grc-zeroerror'),
		'desc' => __('<pre>
[toggle_content title="Toggle Title 1"]
	Toggle content 1...
[/toggle_content]
[toggle_content title="Toggle Title 2"]
	Toggle content 2...
[/toggle_content]
[toggle_content title="Toggle Title 3"]
	Toggle content 3...
[/toggle_content]
</pre>', 'grc-zeroerror'),
		'type' => 'info');


	$options[] = array(
		'name' => __('Accordion Content', 'grc-zeroerror'),
		'desc' => __('<pre>
[accordion]
	[accordion_content title="ACCORDION TITLE 1"]
		ACCORDION CONTENT 1
	[/accordion_content]
	[accordion_content title="ACCORDION TITLE 2"]
		ACCORDION CONTENT 2
	[/accordion_content]
	[accordion_content title="ACCORDION TITLE 3"]
		ACCORDION CONTENT 3
	[/accordion_content]
[/accordion]
</pre>', 'grc-zeroerror'),
		'type' => 'info');

		
	$options[] = array(
		'name' => __('Horizontal Separator', 'grc-zeroerror'),
		'desc' => __('[hr_top] 
', 'grc-zeroerror'),
		'type' => 'info');
	

	// Support					
	$options[] = array(
		'name' => __('Our Themes', 'grc-zeroerror'),
		'type' => 'heading');

	$options[] = array(
		'desc' => __('GRC Zeroerror WordPress theme has been Designed and Created by <a href="'.esc_url('http://gracethemes.com/').'" target="_blank">Grace Themes</a>', 'grc-zeroerror'),
		'type' => 'info');	

	 $options[] = array(
		'desc' => __('<a href="'.esc_url('http://gracethemes.com/').'" target="_blank"><img src="'.get_template_directory_uri().'/images/themesbunch.jpg"></a>', 'grc-zeroerror'),
		'type' => 'info');	

	return $options;
}