<?php
/**
* pulsing functions and definitions
*
* @package Pulsing
*/

/**
* Set the content width based on the theme's design and stylesheet.
*/
function content($limit) {
$content = explode(' ', get_the_excerpt(), $limit);
if (count($content)>=$limit) {
array_pop($content);
$content = implode(" ",$content).'...';
} else {
$content = implode(" ",$content);
}	
$content = preg_replace('/\[.+\]/','', $content);
$content = apply_filters('the_content', $content);
$content = str_replace(']]>', ']]&gt;', $content);
return $content;
}

if ( ! function_exists( 'pulsing_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 */
function pulsing_setup() {

	if ( ! isset( $content_width ) )
		$content_width = 640; /* pixels */
	load_theme_textdomain( 'pulsing', get_template_directory() . '/languages' );
	add_theme_support( 'automatic-feed-links' );
	add_theme_support( 'post-thumbnails' );
	add_theme_support( 'woocommerce' );
	add_filter('widget_text', 'do_shortcode');
	add_theme_support( 'title-tag' );
	add_image_size('homepage-thumb',240,145,true);	
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'pulsing' ),
		'footer' => __( 'Footer Menu', 'pulsing' ),
	) );
	add_theme_support( 'custom-background', array(
	'default-color' => 'ffffff',
	'default-image' => '',
//	'default-image' => get_template_directory_uri().'/images/body-bg.jpg',

	) );
	add_editor_style( 'editor-style.css' );
	add_theme_support( 'wc-product-gallery-zoom' );
	add_theme_support( 'wc-product-gallery-lightbox' );
	add_theme_support( 'wc-product-gallery-slider' );
}
endif; // pulsing_setup
add_action( 'after_setup_theme', 'pulsing_setup' );


function pulsing_widgets_init() {

	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'pulsing' ),
		'description'   => __( 'Appears on blog page sidebar', 'pulsing' ),
		'id'            => 'sidebar-1',
		'before_widget' => '',		
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3><aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
	) );

	register_sidebar( array(
		'name'          => __( 'Sidebar Main', 'pulsing' ),
		'description'   => __( 'Appears on page sidebar', 'pulsing' ),
		'id'            => 'sidebar-main',
		'before_widget' => '',		
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3><aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
	) );	

	register_sidebar( array(
		'name'          => __( 'Footer Widget 1', 'pulsing' ),
		'description'   => __( 'Appears on footer', 'pulsing' ),
		'id'            => 'footer-1',
		'before_widget' => '<div id="%1$s" class="widget-column-1">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3>',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget 2', 'pulsing' ),
		'description'   => __( 'Appears on footer', 'pulsing' ),
		'id'            => 'footer-2',
		'before_widget' => '<div id="%1$s" class="widget-column-2">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3>',
		'after_title'   => '</h3>',
	) );
	
	register_sidebar( array(
		'name'          => __( 'Footer Widget 3', 'pulsing' ),
		'description'   => __( 'Appears on footer', 'pulsing' ),
		'id'            => 'footer-3',
		'before_widget' => '<div id="%1$s" class="widget-column-3">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3>',
		'after_title'   => '</h3>',
	) );
	
		register_sidebar( array(
		'name'          => __( 'Footer Widget 4', 'pulsing' ),
		'description'   => __( 'Appears on footer', 'pulsing' ),
		'id'            => 'footer-4',
		'before_widget' => '<div id="%1$s" class="widget-column-4">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3>',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Sidebar Contact Page', 'pulsing' ),
		'description'   => __( 'Appears on contact page', 'pulsing' ),
		'id'            => 'sidebar-contact',
		'before_widget' => '',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3><aside class="widget %2$s">',
		'after_widget'  => '</aside>',
		
	) );		

}
add_action( 'widgets_init', 'pulsing_widgets_init' );

define( 'OPTIONS_FRAMEWORK_DIRECTORY', get_template_directory_uri() . '/inc/' );
require_once get_template_directory() . '/inc/options-framework.php';

function pulsing_scripts() {
	wp_enqueue_style( 'pulsing-oswald-gfonts', '//fonts.googleapis.com/css?family=Oswald:400,700,300' );
	wp_enqueue_style( 'pulsing-robotocond-gfonts', '//fonts.googleapis.com/css?family=Roboto+Condensed:400,300,700' );
	wp_enqueue_style( 'pulsing-roboto-gfonts', '//fonts.googleapis.com/css?family=Roboto:100,100italic,300,300italic,400,400italic,500,700,500italic,700italic,900,900italic' );
	wp_enqueue_style( 'pulsing-cabin-gfonts', '//fonts.googleapis.com/css?family=Cabin:400,700,400italic' );
	wp_enqueue_style( 'pulsing-basic-style', get_stylesheet_uri() );
	wp_enqueue_style( 'pulsing-editor-style', get_template_directory_uri().'/editor-style.css' );
	wp_enqueue_style( 'pulsing-base-style', get_template_directory_uri().'/css/style_base.css' );	

	if ( is_home() || is_front_page() ) { 
		wp_enqueue_style( 'pulsing-nivo-style', get_template_directory_uri().'/css/nivo-slider.css' );
		wp_enqueue_script( 'pulsing-nivo-slider', get_template_directory_uri() . '/js/jquery.nivo.slider.js', array('jquery') );
	}	

	/**** Owl Testimonial Style/JS ***/	
	wp_enqueue_script( 'pulsing-owl-scripts', get_template_directory_uri().'/js/owl.carousel.js' );
	wp_enqueue_style( 'pulsing-owl-style', get_template_directory_uri().'/css/owl.carousel.min.css' );		
	wp_enqueue_style( 'pulsing-owl-default-style', get_template_directory_uri().'/css/owl.theme.default.min.css' );		

	wp_enqueue_style( 'pulsing-prettyphoto-style', get_template_directory_uri().'/css/prettyPhoto.css' );
	wp_enqueue_script( 'pulsing-prettyphoto-script', get_template_directory_uri() . '/js/jquery.prettyPhoto.js', array('jquery') );
	wp_enqueue_script( 'pulsing-customscripts', get_template_directory_uri() . '/js/custom.js', array('jquery') );	
	wp_enqueue_style( 'pulsing-fontawesome-all-style', get_template_directory_uri().'/fontsawesome/css/fontawesome-all.css' );
	wp_enqueue_style( 'pulsing-responsive-style', get_template_directory_uri().'/css/responsive.css' );		
	wp_enqueue_script( 'pulsing-date-picker-scripts', get_template_directory_uri().'/js/date-picker.js' );

	//Mixit Up
	wp_enqueue_style( 'pulsing-mixitup-style', get_template_directory_uri().'/mixitup/demo.css' );
	wp_enqueue_script( 'pulsing-mixitup-script', get_template_directory_uri() . '/mixitup/jquery_mixitup.js', array('jquery') );
	
	wp_enqueue_style( 'pulsing-animation', get_template_directory_uri().'/css/animation.css' );
	
	if( of_get_option('scrollanimation',true) != true) {
		wp_enqueue_style( 'pulsing-animation-style', get_template_directory_uri().'/css/animation-style.css' );
		wp_enqueue_script( 'pulsing-custom-animation', get_template_directory_uri() . '/js/custom-animation.js', array('jquery') );	
	}
	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'pulsing_scripts' );

function media_css_hook(){ ?>

<script>

jQuery(window).bind('scroll', function() {
	var wwd = jQuery(window).width();
	if( wwd > 939 ){
		var navHeight = jQuery( window ).height() - 560;
		<?php if( of_get_option('headstick',true) != true) { ?>
		if (jQuery(window).scrollTop() > navHeight) {
			jQuery(".header").addClass('fixed');
		}else {
			jQuery(".header").removeClass('fixed');
		}
		<?php } ?>
	}
});	

/*********** Owl Testimonial **********/
jQuery(window).load(function(){
  jQuery('.owl-carousel').owlCarousel({
    responsiveClass:true,
	smartSpeed:<?php echo of_get_option('testimonialspped',true); ?>,
	autoplay:<?php echo of_get_option('autoplaytestimonial', true); ?>,
    responsive:{
        0:{
            items:1,
        },
        600:{
            items:2,
            nav:false
        },
        1000:{
            items:3,
            loop:true,
        }
    }
});
});

</script>

<?php if ( is_home() || is_front_page() ) { ?>        
<script>
		jQuery(window).load(function() {
        jQuery('#slider').nivoSlider({
        	effect:'<?php echo of_get_option('slideefect',true); ?>',
		  	animSpeed: <?php echo of_get_option('slideanim',true); ?>,
			pauseTime: <?php echo of_get_option('slidepause',true); ?>,
			directionNav: <?php echo of_get_option('slidenav',true); ?>,
			controlNav: <?php echo of_get_option('slidepage',true); ?>,
			pauseOnHover: <?php echo of_get_option('slidepausehover',true); ?>,
    });
});
</script>
<?php } ?>
<?php }
add_action('wp_head','media_css_hook'); 


function pulsing_custom_head_codes() {
	if ( (function_exists( 'of_get_option' )) && (of_get_option('style2', true) != 1) ) {
		echo "<style>". esc_html( of_get_option('style2', true) ) ."</style>";
	}
	if ( function_exists( 'of_get_option' )  )  {
			$typebody 		  		  = of_get_option('bodyfontface');
			$typelogo 		  		  = of_get_option('logotype');
			$typetag  		  		  = of_get_option('tagtype');
			$typenav  		  		  = of_get_option('navtype');
			$typeslidertitle		  = of_get_option('slidertitletype');
			$typesliderdesc	  		  = of_get_option('sliderdesctype');
			$typesectiontitle	  	  = of_get_option('sectiontitletype');
			$typefootertitle	  	  = of_get_option('footertitletype');
			$typeheadingh1	  		  = of_get_option('headingh1type');
			$typeheadingh2	  		  = of_get_option('headingh2type');
			$typeheadingh3	  		  = of_get_option('headingh3type');
			$typeheadingh4	  		  = of_get_option('headingh4type');
			$typeheadingh5	  		  = of_get_option('headingh5type');
			$typeheadingh6	  		  = of_get_option('headingh6type');			
			
			
			
 		if( $typebody['face'] != '' && is_google_font( $typebody['face'] ) ){
			echo "<link href='http://fonts.googleapis.com/css?family=".str_replace(' ','+',$typebody['face'])."' rel='stylesheet' type='text/css' />";
		}
		if( $typelogo['face'] != '' && is_google_font( $typelogo['face'] ) ){
			echo "<link href='http://fonts.googleapis.com/css?family=".str_replace(' ','+',$typelogo['face'])."' rel='stylesheet' type='text/css' />";
		}
		if( $typetag['face'] != '' && is_google_font( $typetag['face'] ) ){
			echo "<link href='http://fonts.googleapis.com/css?family=".str_replace(' ','+',$typetag['face'])."' rel='stylesheet' type='text/css' />";
		}
		if( $typenav['face'] != '' && is_google_font( $typenav['face'] ) ){
			echo "<link href='http://fonts.googleapis.com/css?family=".str_replace(' ','+',$typenav['face'])."' rel='stylesheet' type='text/css' />";
		}
		if( $typeslidertitle['face'] != '' && is_google_font( $typeslidertitle['face'] ) ){
			echo "<link href='http://fonts.googleapis.com/css?family=".str_replace(' ','+',$typeslidertitle['face'])."' rel='stylesheet' type='text/css' />";
		}		
		if( $typesliderdesc['face'] != '' && is_google_font( $typesliderdesc['face'] ) ){
			echo "<link href='http://fonts.googleapis.com/css?family=".str_replace(' ','+',$typesliderdesc['face'])."' rel='stylesheet' type='text/css' />";
		}
		if( $typesectiontitle['face'] != '' && is_google_font( $typesectiontitle['face'] ) ){
			echo "<link href='http://fonts.googleapis.com/css?family=".str_replace(' ','+',$typesectiontitle['face'])."' rel='stylesheet' type='text/css' />";
		}
		if( $typefootertitle['face'] != '' && is_google_font( $typefootertitle['face'] ) ){
			echo "<link href='http://fonts.googleapis.com/css?family=".str_replace(' ','+',$typefootertitle['face'])."' rel='stylesheet' type='text/css' />";
		}
		if( $typeheadingh1['face'] != '' && is_google_font( $typeheadingh1['face'] ) ){
			echo "<link href='http://fonts.googleapis.com/css?family=".str_replace(' ','+',$typeheadingh1['face'])."' rel='stylesheet' type='text/css' />";
		}
		if( $typeheadingh2['face'] != '' && is_google_font( $typeheadingh2['face'] ) ){
			echo "<link href='http://fonts.googleapis.com/css?family=".str_replace(' ','+',$typeheadingh2['face'])."' rel='stylesheet' type='text/css' />";
		}
		if( $typeheadingh3['face'] != '' && is_google_font( $typeheadingh3['face'] ) ){
			echo "<link href='http://fonts.googleapis.com/css?family=".str_replace(' ','+',$typeheadingh3['face'])."' rel='stylesheet' type='text/css' />";
		}
		if( $typeheadingh4['face'] != '' && is_google_font( $typeheadingh4['face'] ) ){
			echo "<link href='http://fonts.googleapis.com/css?family=".str_replace(' ','+',$typeheadingh4['face'])."' rel='stylesheet' type='text/css' />";
		}
		if( $typeheadingh5['face'] != '' && is_google_font( $typeheadingh5['face'] ) ){
			echo "<link href='http://fonts.googleapis.com/css?family=".str_replace(' ','+',$typeheadingh5['face'])."' rel='stylesheet' type='text/css' />";
		}
		if( $typeheadingh6['face'] != '' && is_google_font( $typeheadingh6['face'] ) ){
			echo "<link href='http://fonts.googleapis.com/css?family=".str_replace(' ','+',$typeheadingh6['face'])."' rel='stylesheet' type='text/css' />";
		}
		echo "<style>";
			
	if( of_get_option('bodyfontface',true) != '' || of_get_option('bodybgcolor' , true)){
		echo "body{font-family:".$typebody['face']."; font-size:".$typebody['size']."; color:".$typebody['color']."; font-weight:".$typebody['weight']."; text-transform:".$typebody['transform']."; font-style:".$typebody['style']."; background:".of_get_option('bodybgcolor', true).";}";
	}

	if( of_get_option('bodyfontface',true) != ''){
		echo "#sidebar ul li a, .postmeta, .entry-meta{color:".$typebody['color'].";}";
	}

	if( of_get_option('logotype',true) != ''){
		echo ".header .header-inner .logo h1{font-family:".$typelogo['face']."; font-size:".$typelogo['size']."; color:".$typelogo['color']."; font-weight:".$typelogo['weight']."; text-transform:".$typelogo['transform']."; font-style:".$typelogo['style'].";}";
	}
	if( of_get_option('tagtype',true) != ''){
		echo ".header .header-inner .logo span.tagline{font-family:".$typetag['face']."; font-size:".$typetag['size']."; color:".$typetag['color']."; font-weight:".$typetag['weight']."; text-transform:".$typetag['transform']."; font-style:".$typetag['style'].";}";
	}
	if( of_get_option('logoheight',true) != '' ){
			echo ".header .header-inner .logo img{height:".of_get_option('logoheight',true)."px;}";
	}
	if( of_get_option('headertopcolor',true) != '' ){
		echo ".header-left a, .header-left i{color:".of_get_option('headertopcolor',true).";}";
	}
	if( of_get_option('headertopcolorhover',true) != '' ){
		echo ".header-left a:hover{color:".of_get_option('headertopcolorhover',true).";}";
	}
	
// Header top navigation

		$byadmincathex = of_get_option('headerbgcolor',true); 
			list($r,$g,$b) = sscanf($byadmincathex,'#%02x%02x%02x');
		if ( of_get_option('headerbgcolor', true) != '' ) {
			echo ".header .header-inner {background:rgba(".$r.",".$g.",".$b.",".of_get_option('headerbgopacity',true).");}";
		}


	if ( of_get_option('headerbtncolor', true) != '' || of_get_option('headerbtnbgcolor', true) != '') {
			echo '.book-btn a  { color:'. esc_html( of_get_option('headerbtncolor', true) ) .' !important; background:'. esc_html( of_get_option('headerbtnbgcolor', true) ) .';}';
		}

	if( of_get_option('navtype',true) != ''){
		echo ".header .header-inner .nav ul li a, .book-btn a{font-family:".$typenav['face']."; font-size:".$typenav['size']."; color:".$typenav['color']."; font-weight:".$typenav['weight']."; text-transform:".$typenav['transform']."; font-style:".$typenav['style'].";}";
	}
	if ( of_get_option('navhovercolor', true) != '') {
	echo '.header .header-inner .nav ul li a:hover, .header .header-inner .nav ul li.current_page_item a, .header .header-inner .nav ul li.menu-item-has-children:hover ul li.current_page_item a, .header .header-inner .nav ul li.current_page_item ul li a:hover, .header .header-inner .nav ul li.menu-item-has-children:hover a, .header .header-inner .nav ul li.menu-item-has-children:hover ul li a:hover, .header .header-inner .nav ul li.menu-item-has-children:hover ul li.current_page_item ul li a:hover, .header .header-inner .nav ul li.current-menu-ancestor a, .header .header-inner .nav ul li.menu-item-has-children:hover ul li.current-menu-ancestor a, .header .header-inner .nav ul li.menu-item-has-children:hover ul li.current-menu-ancestor ul li a:hover, .header .header-inner .nav ul li.menu-item-has-children:hover ul li.current-menu-ancestor ul li.current_page_item a, .header .header-inner .nav ul li.menu-item-has-children ul li.menu-item-has-children:hover a, .header .header-inner .nav ul li.menu-item-has-children ul li.menu-item-has-children:hover ul li a:hover{ color:'. esc_html( of_get_option('navhovercolor', true) ) .';}';
	}
	
	if ( of_get_option('tgmenuresponsivecolor', true) != '') {
	echo ".header .header-inner .nav ul li ul li a, .header .header-inner .nav ul li.menu-item-has-children:hover ul li a, .header .header-inner .nav ul li.menu-item-has-children:hover ul li.current_page_item ul li a, .header .header-inner .nav ul li.menu-item-has-children:hover ul li.current-menu-ancestor ul li a, .header .header-inner .nav ul li.menu-item-has-children ul li.menu-item-has-children:hover ul li a {color: ".of_get_option('tgmenuresponsivecolor', true).";}";
	}
	
	// Header top navigation in responsive
	if( of_get_option('tgmenuresponsivecolor',true) != ''){
	echo "@media screen and (max-width:1023px){.header .header-inner .nav ul li a{color: ".of_get_option('tgmenuresponsivecolor', true)." !important;}}";
	}

	// Header top navigation in responsive
	if( of_get_option('navhovercolor',true) != ''){
	echo "@media screen and (max-width:1023px){.header .header-inner .nav ul li a:hover{color: ".of_get_option('navhovercolor', true)." !important;}}";
	}
	
	if ( of_get_option('tgmenuresponsivebg', true) != '') {
	echo "@media screen and (max-width:1023px){.header .header-inner .nav ul {background-color: ".of_get_option('tgmenuresponsivebg', true).";}}";
	}

	if ( of_get_option('tgmenuresponsivebg', true) != '') {
	echo ".header .header-inner .nav ul li:hover ul {background-color: ".of_get_option('tgmenuresponsivebg', true).";}";
	}

	if ( of_get_option('togglebgcolor', true) != '') {
	echo "@media screen and (max-width:1023px){.toggle a {background-color: ".of_get_option('togglebgcolor', true).";}}";
	}

// Slider Setting


	if( of_get_option('slidertitletype',true) != ''){
		echo ".slide_info h2{font-family:".$typeslidertitle['face']."; font-size:".$typeslidertitle['size']."; color:".$typeslidertitle['color']."; font-weight:".$typeslidertitle['weight']."; text-transform:".$typeslidertitle['transform']."; font-style:".$typeslidertitle['style'].";}";
	}
	if( of_get_option('sliderdesctype',true) != ''){
		echo ".slide_info p{font-family:".$typesliderdesc['face']."; font-size:".$typesliderdesc['size']."; color:".$typesliderdesc['color']."; font-weight:".$typesliderdesc['weight']."; text-transform:".$typesliderdesc['transform']."; font-style:".$typesliderdesc['style'].";}";
	}	
	if ( of_get_option('sliderbutbgcolor', true) != '' ||  of_get_option('sliderbutcolor', true) != '') {
			echo '.slide_info a.sldbutton:hover{ background-color:'. esc_html( of_get_option('sliderbutbgcolor', true) ) .';  color:'. esc_html( of_get_option('sliderbutcolor', true) ) .'; }';
	}

	if ( of_get_option('sliderbutbghvcolor', true) != '') {
			echo '.slide_info a.sldbutton:hover{ background-color:'. esc_html( of_get_option('sliderbutbghvcolor', true) ) .';}';
	}	
	if ( of_get_option('sliderbuthvcolor', true) != '') {
			echo '.slide_info a.sldbutton:hover{ color:'. esc_html( of_get_option('sliderbuthvcolor', true) ) .';}';
	}	

// Slider controls colors		
	if( of_get_option('sldnavbg',true) != ''){
			echo ".nivo-directionNav a{background:url(".get_template_directory_uri()."/images/slide-nav.png) no-repeat".of_get_option('sldnavbg',true)." -4px 4px;}";
		}
	if( of_get_option('sldpagebg',true) != ''){
		echo ".nivo-controlNav a, ol.nav-numbers li a, .owl-theme .owl-dots .owl-dot span{background-color:".of_get_option('sldpagebg',true)."}";
	}
	if( of_get_option('sldpagehvbg',true) != ''){
		echo ".nivo-controlNav a.active, ol.nav-numbers li.active a, .owl-theme .owl-dots .owl-dot.active span, .owl-theme .owl-dots .owl-dot:hover span{background-color:".of_get_option('sldpagehvbg',true).";}";
	}	
	if( of_get_option('sldpagehvbg',true) != ''){
		echo "ol.nav-numbers li a{border-color:".of_get_option('sldpagehvbg',true)."}";
	}

// Section title color	
	if( of_get_option('sectiontitletype',true) != ''){
		echo "h2.section_title{font-family:".$typesectiontitle['face']."; font-size:".$typesectiontitle['size']."; color:".$typesectiontitle['color']."; font-weight:".$typesectiontitle['weight']."; text-transform:".$typesectiontitle['transform']."; font-style:".$typesectiontitle['style'].";}";
	}	
	if( of_get_option('sectiontitlebrcl',true) != '' ){
	echo "h2.section_title {border-color:".of_get_option('sectiontitlebrcl',true).";}";
	}


// Latest Blog News	
		if( of_get_option('bgcolorpost',true) != '' || of_get_option('txtcolorpost',true) != '' ){
		echo ".latestnews .news-box {background:".of_get_option('bgcolorpost',true)."; color:".of_get_option('txtcolorpost',true).";}";
		}
		if( of_get_option('bordercolorpost',true) != '' ){
		echo ".news, .news h4  {border-color:".of_get_option('bordercolorpost',true).";}";
		}

// Our Team Social Icon
	if( of_get_option('teamcontentbgcolor',true) != ''){
		echo ".ourteam_col:hover .ourteam_content {background:".of_get_option('teamcontentbgcolor',true).";}";
	}	
	if( of_get_option('teamcontenttextcolor',true) != ''){
		echo ".ourteam_col:hover h3, .ourteam_col:hover .ourteam_content h6, .ourteam_col:hover .team-social-icon a i {color:".of_get_option('teamcontenttextcolor',true).";}";
	}	

	if( of_get_option('teamcontentbgbtncolor',true) != '' || of_get_option('teamcontenttextbtncolor',true) != ''){
		echo ".ourteam_col:hover .ourteam_content .read-more {background:".of_get_option('teamcontentbgbtncolor',true)."; color:".of_get_option('teamcontenttextbtncolor',true).";}";
	}	

	if( of_get_option('teamcontentbgbtncolor',true) != '' || of_get_option('teamcontenttextbtncolor',true) != ''){
		echo ".ourteam_col:hover .ourteam_content .read-more:hover {background:".of_get_option('teamcontenttextbtncolor',true)."; color:".of_get_option('teamcontentbgbtncolor',true).";}";
	}	

	if( of_get_option('teamboxbgcolor',true) != ''){
		echo ".ourteam_col {background:".of_get_option('teamboxbgcolor',true).";}";
	}	

//testimonial color
	$byadmincathex = of_get_option('testimonialbgcolor',true); 
			list($r,$g,$b) = sscanf($byadmincathex,'#%02x%02x%02x');
		if ( of_get_option('testimonialcolor', true) != '' || of_get_option('testimonialbgcolor', true) != '') {
				echo ".tm_description, .carousel-content {background-color:rgba(".$r.",".$g.",".$b.",".of_get_option('testimonialbgop',true)."); color:".of_get_option('testimonialcolor',true).";}";
		}
		
		if (of_get_option('testimonialbordercl', true) != '') {
				echo ".tm_description:after {border-top-color:".of_get_option('testimonialbordercl',true).";}";
		}

		if (of_get_option('testimonialbordercl', true) != '') {
				echo ".tm_description {border-color:".of_get_option('testimonialbordercl',true).";}";
		}

	if( of_get_option('testimonialh5color',true) != ''){
		echo ".testimonial-info h5 {color:".of_get_option('testimonialh5color',true).";}";
	}	
	if( of_get_option('testimonialh6color',true) != ''){
		echo ".testimonial-info h6, #testimonials h2.section_title {color:".of_get_option('testimonialh6color',true).";}";
	}

if( of_get_option('testimonialpageractive',true) != ''){
		echo ".testimonials-home ol.nav-numbers li.active a, .testimonials-home .owl-theme .owl-dots .owl-dot.active span, .testimonials-home .owl-theme .owl-dots .owl-dot:hover span{background-color:".of_get_option('testimonialpageractive',true)." !important;}"; 
	}

//Gallery
	if( of_get_option('gallerynavigationcolor',true) != ''){
		echo ".controls li{color:".of_get_option('gallerynavigationcolor',true).";}";
	}	
	if( of_get_option('gallerynavtxtcolor',true) != ''){
		echo ".controls li.active, .controls li:hover{color:".of_get_option('gallerynavtxtcolor',true).";}";
	}	

	if( of_get_option('gallerybgcolor',true) != '' ){
		echo "#Grid .mix{background-color:".of_get_option('gallerybgcolor',true).";}";
	}	

// All site anchor tag
	if( of_get_option('anchortagcolor',true) != '' ){
		echo "a, .hourse-day, .footer a:hover, .copyright-wrapper a:hover, #some-facts .everydaytime .everydays, .footer .cols-1 .widget-column-1 ul li a:hover, .cols-1 .widget-column-1 ul li.current_page_item a, .footer ul li.current_page_item, .footer ul li:hover a, .footer ul li:hover:before, .phone-no span, .footer .phone-no a:hover, #about-section h3 span, .product-col h4 a:hover, .woocommerce table.shop_table th, .woocommerce-page table.shop_table th, .one_four_page:hover a h4, #sidebar ul li a:hover {color:".of_get_option('anchortagcolor',true).";}";
	}
	if( of_get_option('anchortagcolor',true) != '' ){
		echo ".recent-post a:hover img {border-color:".of_get_option('anchortagcolor',true).";}";
	}
		if( of_get_option('anchortagcolorhover',true) != '' ){
		echo "a:hover{color:".of_get_option('anchortagcolorhover',true).";}";
	}
// Default Social color/background
	if( of_get_option('socialfontcolor',true) != '' || of_get_option('socialbgcolor',true) != '' ){
		echo ".social-icons a{color:".of_get_option('socialfontcolor',true)."; background:".of_get_option('socialbgcolor',true).";}";
	}
	if( of_get_option('socialbghvcolor',true) != ''){
		echo ".social-icons a:hover {background:".of_get_option('socialbghvcolor',true).";}";
	}
	if( of_get_option('socialfonthvcolor',true) != ''){
		echo ".social-icons a:hover, .header-right .column2 .social-icons a:hover, .social-icons a:hover {color:".of_get_option('socialfonthvcolor',true).";}";
	}	

// Default Button contact/blog/single comment
	if( of_get_option('btnbgcolor',true) != '' || of_get_option('btntxtcolor', true) != ''){
		echo ".view-all-btn a:hover, #contactform_main input[type='submit'], .wpcf7 form input[type='submit'], .button, #commentform input#submit, input.search-submit, .post-password-form input[type=submit], .read-more:hover , .accordion-box h2:before, .pagination ul li span, .pagination ul li a, #about-section .read-more, #buynowtheme .read-more, .woocommerce #respond input#submit.alt, .woocommerce a.button.alt, .woocommerce button.button.alt, .woocommerce input.button.alt, .one_four_page:hover .read-more, .news-box:hover .read-more {background-color:".of_get_option('btnbgcolor',true)."; color:". of_get_option('btntxtcolor', true) .";}";
	}
	if( of_get_option('btnbghvcolor',true) != '' || of_get_option('btntxthvcolor', true) != '' ){
		echo ".view-all-btn a, #contactform_main input[type='submit']:hover, .wpcf7 form input[type='submit']:hover, .button:hover, #commentform input#submit:hover, input.search-submit:hover, .post-password-form input[type=submit]:hover, .read-more, .pagination ul li .current, .pagination ul li a:hover, #about-section .read-more:hover, #buynowtheme .read-more:hover, .woocommerce #respond input#submit.alt:hover, .woocommerce a.button.alt:hover, .woocommerce button.button.alt:hover , .woocommerce input.button.alt:hover, a.added_to_cart:hover {background-color:".of_get_option('btnbghvcolor',true)."; color:". esc_html( of_get_option('btntxthvcolor', true) ) .";}";
	}

// Footer Anchor tag
	if( of_get_option('footerwpbgcolor',true) != ''){
		echo "#footer-wrapper{background-color:".of_get_option('footerwpbgcolor',true).";}";
	}
	if( of_get_option('footerwpcolor',true) != '' ){
		echo "#footer-wrapper, .footer ul li a, .footer .phone-no a {color:".of_get_option('footerwpcolor',true).";}";
	}
	if( of_get_option('copyrightbgcolor',true) != ''){
		echo ".copyright-wrapper{background-color:".of_get_option('copyrightbgcolor',true).";}";
	}
	if( of_get_option('fttitletype',true) != ''){
		echo ".footer h3{font-family:".$typefootertitle['face']."; font-size:".$typefootertitle['size']."; color:".$typefootertitle['color']."; font-weight:".$typefootertitle['weight']."; text-transform:".$typefootertitle['transform']."; font-style:".$typefootertitle['style'].";}";
	}
	if( of_get_option('footerpostimagebd',true) != '' ){
		echo ".recent-post img, .recent-post, .footer ul li{border-color:".of_get_option('footerpostimagebd',true).";}";
	}

// Sidebar option
	if( of_get_option('widgettitlebgcolor',true) != '' || of_get_option('widgettitlecolor',true) != '' ){
		echo "h3.widget-title, .searchbox-icon, #sidebar .woocommerce-product-search input, .searchbox input[type='submit'][type='submit']{background-color:".of_get_option('widgettitlebgcolor',true)."; color:".of_get_option('widgettitlecolor',true).";}";
	}
	if( of_get_option('sidebarbgcolor',true) != '' ){
		echo "aside.widget{background-color:".of_get_option('sidebarbgcolor',true).";}";
	}
	if( of_get_option('sidebarliaborder',true) != '' ){
		echo "#sidebar ul li{border-color:".of_get_option('sidebarliaborder',true).";}";
	}
	if( of_get_option('searchbgcolor',true) != ''){
		echo ".searchbox-input{background-color:".of_get_option('searchbgcolor',true).";}";
	}


//input field
	if( of_get_option('inputbgcolor',true) != '' ||  of_get_option('inputtextbgcolor',true) != '' ||  of_get_option('inputbrcolor',true) != ''){
		echo "#contactform_main input[type='text'], #contactform_main input[type='email'], #contactform_main input[type='tel'], #contactform_main input[type='url'], #contactform_main textarea, .wpcf7 form input[type='text'], .wpcf7 form input[type='email'], .wpcf7 form input[type='tel'], .wpcf7 form textarea, select, input.appointfield[type='text'], #sidebar select, #commentform input#email, #commentform input#url, #commentform input#author, #commentform textarea, #commentform input#eazycfc_captcha {background-color:".of_get_option('inputbgcolor',true)." !important; color:".of_get_option('inputtextbgcolor',true)."; border-color:".of_get_option('inputbrcolor',true).";}";
	}

// Gallery Option
	if ( of_get_option('ifrmabrcolor', true) != '') {
		echo "iframe, h1.entry-title, h1.page-title {border-color:".of_get_option('ifrmabrcolor', true)."; }";
	}		
	
// Heading Tag
	if( of_get_option('headingh1type',true) != ''){
		echo "h1{font-family:".$typeheadingh1['face']."; font-size:".$typeheadingh1['size']."; color:".$typeheadingh1['color']."; font-weight:".$typeheadingh1['weight']."; text-transform:".$typeheadingh1['transform']."; font-style:".$typeheadingh1['style'].";}";
	}
	if( of_get_option('headingh2type',true) != ''){
		echo "h2{font-family:".$typeheadingh2['face']."; font-size:".$typeheadingh2['size']."; color:".$typeheadingh2['color']."; font-weight:".$typeheadingh2['weight']."; text-transform:".$typeheadingh2['transform']."; font-style:".$typeheadingh2['style'].";}";
	}
	if( of_get_option('headingh3type',true) != ''){
		echo "h3{font-family:".$typeheadingh3['face']."; font-size:".$typeheadingh3['size']."; color:".$typeheadingh3['color']."; font-weight:".$typeheadingh3['weight']."; text-transform:".$typeheadingh1['transform']."; font-style:".$typeheadingh1['style'].";}";
	}
	if( of_get_option('headingh4type',true) != ''){
		echo "h4{font-family:".$typeheadingh4['face']."; font-size:".$typeheadingh4['size']."; color:".$typeheadingh4['color']."; font-weight:".$typeheadingh4['weight']."; text-transform:".$typeheadingh4['transform']."; font-style:".$typeheadingh4['style'].";}";
	}
	if( of_get_option('headingh5type',true) != ''){
		echo "h5{font-family:".$typeheadingh5['face']."; font-size:".$typeheadingh5['size']."; color:".$typeheadingh5['color']."; font-weight:".$typeheadingh5['weight']."; text-transform:".$typeheadingh5['transform']."; font-style:".$typeheadingh5['style'].";}";
	}
	if( of_get_option('headingh6type',true) != ''){
		echo "h6{font-family:".$typeheadingh6['face']."; font-size:".$typeheadingh6['size']."; color:".$typeheadingh6['color']."; font-weight:".$typeheadingh6['weight']."; text-transform:".$typeheadingh6['transform']."; font-style:".$typeheadingh6['style'].";}";
	}
	
// Woocommerce price Filter
	if ( of_get_option('pricesliderbg', true) != '' ) {
			echo '#sidebar .price_slider_wrapper .ui-widget-content{background-color:'. esc_html( of_get_option('pricesliderbg', true) ) .';}';
	}
	if ( of_get_option('pricehandlebg', true) != '' ) {
			echo '#sidebar .ui-slider .ui-slider-handle{background-color:'. esc_html( of_get_option('pricehandlebg', true) ) .';}';
	}
	if ( of_get_option('pricerangebg', true) != '' ) {
			echo '#sidebar .ui-slider .ui-slider-range{background-color:'. esc_html( of_get_option('pricerangebg', true) ) .';}';
	}
	
	// Color Scheme For hole site
	if ( of_get_option('colorscheme', true) != '' ) {
			echo '.one_four_thumb,
			.news-box .news-thumb,
			.product-thumb
			 {background-color:'. esc_html( of_get_option('colorscheme', true) ) .';}';
	}
	
	if ( of_get_option('colorscheme', true) != '' ) {
			echo '.one_four_page:hover h3,
			.themefeatures .one_third:hover i
			{color:'. esc_html( of_get_option('colorscheme', true) ) .';}';
	}
	
	if ( of_get_option('colorscheme', true) != '' ) {
			echo '.themefeatures .one_third:hover,
			.about-image:hover:after{border-color:'. esc_html( of_get_option('colorscheme', true) ) .';}';
	}
		
		echo "</style>";
	} 

}	
add_action('wp_head', 'pulsing_custom_head_codes');


function pulsing_pagination() {
	global $wp_query;
	$big = 12345678;
	$page_format = paginate_links( array(
	    'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
	    'format' => '?paged=%#%',
	    'current' => max( 1, get_query_var('paged') ),
	    'total' => $wp_query->max_num_pages,
	    'type'  => 'array'
	) );
	if( is_array($page_format) ) {
		$paged = ( get_query_var('paged') == 0 ) ? 1 : get_query_var('paged');
		echo '<div class="pagination"><div><ul>';
		echo '<li><span>'. $paged . ' of ' . $wp_query->max_num_pages .'</span></li>';
		foreach ( $page_format as $page ) {
			echo "<li>$page</li>";
		}
		echo '</ul></div></div>';
	}
}
/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';


/**
 * Load custom functions file.
 */
require get_template_directory() . '/inc/custom-functions.php';


function pulsing_custom_blogpost_pagination( $wp_query ){
	$big = 999999999; // need an unlikely integer
	if ( get_query_var('paged') ) { $pageVar = 'paged'; }
	elseif ( get_query_var('page') ) { $pageVar = 'page'; }
	else { $pageVar = 'paged'; }
	$pagin = paginate_links( array(
		'base' 			=> str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
		'format' 		=> '?'.$pageVar.'=%#%',
		'current' 		=> max( 1, get_query_var($pageVar) ),
		'total' 		=> $wp_query->max_num_pages,
		'prev_text'		=> '&laquo; Prev',
		'next_text' 	=> 'Next &raquo;',
		'type'  => 'array'
	) ); 
	if( is_array($pagin) ) {
		$paged = ( get_query_var('paged') == 0 ) ? 1 : get_query_var('paged');
		echo '<div class="pagination"><div><ul>';
		echo '<li><span>'. $paged . ' of ' . $wp_query->max_num_pages .'</span></li>';
		foreach ( $pagin as $page ) {
			echo "<li>$page</li>";
		}
		echo '</ul></div></div>';
	} 
}

function pulsing_get_slug_by_id($id) {
	$post_data = get_post($id, ARRAY_A);
	$slug = $post_data['post_name'];
	return $slug; 
}


/**
 * Include the Plugin_Activation class.
 */
require_once dirname( __FILE__ ) . '/class-plugin-activation.php';
add_action( 'tgmpa_register', 'spirited_register_required_plugins' );
 
function spirited_register_required_plugins() {
	$plugins = array(
		array(
			'name'      => 'Shortcodes Ultimate',
			'slug'      => 'shortcodes-ultimate',
			'required'  => false,
		),
 
	);

	$config = array(
		'id'           => 'tgmpa',                 // Unique ID for hashing notices for multiple instances of TGMPA.
		'default_path' => '',                      // Default absolute path to bundled plugins.
		'menu'         => 'grc-install-plugins', // Menu slug.
		'parent_slug'  => 'themes.php',            // Parent menu slug.
		'capability'   => 'edit_theme_options',    // Capability needed to view plugin install page, should be a capability associated with the parent menu used.
		'has_notices'  => true,                    // Show admin notices or not.
		'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
		'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
		'is_automatic' => false,                   // Automatically activate plugins after installation or not.
		'message'      => '',                      // Message to output right before the plugins table.
	);

	tgmpa( $plugins, $config );
}