<?php   

/**
 * A unique identifier is defined to store the options in the database and reference them from the theme.
 * By default it uses the theme name, in lowercase and without spaces, but this can be changed if needed.
 * If the identifier changes, it'll appear as if the options have been reset.
 */ 

function optionsframework_option_name() {
	// Change this to use your theme slug
	$themename = wp_get_theme();
	$themename = preg_replace("/\W/", "_", strtolower($themename) );
	return $themename;
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 * 
 * If you are making your theme translatable, you should replace 'pulsing'
 * with the actual text domain for your theme.  Read more:
 * http://codex.wordpress.org/Function_Reference/load_theme_textdomain
*/

function optionsframework_options() {

	//Pull all the pages into an array
	 $options_pages = array();
	 $options_pages_obj = get_pages('sort_column=post_parent,menu_order');
	 $options_pages[''] = 'Select a page:';
	 foreach ($options_pages_obj as $page) {
	  $options_pages[$page->ID] = $page->post_title;
	 }

	// array of section content.
	$section_text = array(
		1 => array(
			'section_title'		=> '',
			'menutitle'			=> 'about-section',
			'bgcolor' 			=> '#faf9f9',
			'bgimage'			=> '',
			'class'				=> '',
			'content'			=> '<div class="about-image"><img src="'.get_template_directory_uri().'/images/about-img.jpg" alt=""></div>
<div class="about-content">								
<h3>About Us</h3>
<p>Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean commodo ligula eget dolor. Aenean massa fringilla vel, aliquet nec, vulputate eget, arcu.In enim justo, vulputate eget, arcu.In enim justo, rhoncus consectetuer adipiscing rhoncus consectetuer adipiscing elit.</p><p>Nulla consequat massa quis enim.Donec pede justo, fringilla vel, aliquet nec, vulputate eget, arcu.In enim justo, rhoncus ut, imperdiet a, venenatis vitae, justo. Nullam dictum felis eu pede mollis pretium.Integer tincidunt. Cras dapibus. Nulla consequat massa quis enim.Donec pede justo, fringilla vel aliquet nec vulputate eget arcu..</p>
<a href="#" class="read-more">Read More</a>',
		),
		
		2 => array(
			'section_title'	=> 'Theme Features',
			'menutitle'		=> 'featuresection',
			'bgcolor' 		=> '',
			'bgimage'		=> '',
			'class'			=> 'themefeatures',
			'content'		=> '[column_content type="one_third"]<i class="fas fa-tablet-alt"></i>
<h3>Responsive Design</h3>Nulla consequat massa quis enim.Donec pede justo, fringilla vel, aliquet nec, vulputate eget, arcu.In enim justo, rhoncus ut, imperdiet a, venenatis vitae, justo. Nullam dictum felis.
[/column_content]

[column_content type="one_third"]<i class="far fa-eye"></i>
<h3>Retina Ready</h3>Nulla consequat massa quis enim.Donec pede justo, fringilla vel, aliquet nec, vulputate eget, arcu.In enim justo, rhoncus ut, imperdiet a, venenatis vitae, justo. Nullam dictum felis.
[/column_content]

[column_content type="one_third_last"]<i class="fas fa-cog"></i>
<h3>Easy Customize</h3>Nulla consequat massa quis enim.Donec pede justo, fringilla vel, aliquet nec, vulputate eget, arcu.In enim justo, rhoncus ut, imperdiet a, venenatis vitae, justo. Nullam dictum.
[/column_content]

[column_content type="one_third"]<i class="fas fa-search"></i>
<h3>SEO Friendly</h3>Nulla consequat massa quis enim.Donec pede justo, fringilla vel, aliquet nec, vulputate eget, arcu.In enim justo, rhoncus ut, imperdiet a, venenatis vitae, justo. Nullam dictum felis.	
[/column_content]

[column_content type="one_third"]<i class="far fa-envelope"></i>
<h3>Great Support Team</h3>Nulla consequat massa quis enim.Donec pede justo, fringilla vel, aliquet nec, vulputate eget, arcu.In enim justo, rhoncus ut, imperdiet a, venenatis vitae, justo. Nullam dictum felis.
[/column_content]

[column_content type="one_third_last"]<i class="fas fa-shopping-cart"></i>
<h3>Woocommerce Compatible</h3>Nulla consequat massa quis enim.Donec pede justo, fringilla vel, aliquet nec, vulputate eget, arcu.In enim justo, rhoncus ut, imperdiet a, venenatis vitae, justo. Nullam dictum.	
[/column_content]
',
		),
		
		3 => array(
			'section_title'	=> '',
			'menutitle'		=> 'buynowtheme',
			'bgcolor' 		=> '',
			'bgimage'		=> get_template_directory_uri().'/images/purchasebg.jpg',
			'class'			=> 'buynowwrap',
			'content'		=> '<h2>Buy Pulsing WordPress Theme only for $29</h2>
<p>Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean commodo ligula eget dolor. Aenean massa fringilla vel, aliquet nec, vulputate eget, arcu.In enim justo, vulputate eget, arcu.In enim justo, rhoncus consectetuer adipiscing rhoncus consectetuer adipiscing elit.</p>
<div class="custombtn"><a href="#" class="read-more" target="">Purchase Theme</a></div>'
		 ),

		4 => array(
			'section_title'		=> 'Latest Posts',
			'menutitle'			=> '',
			'bgcolor' 			=> '#faf9f9',
			'bgimage'			=> '',
			'class'				=> '',
			'content'			=> '[latestposts show="4"]',
		),

		5 => array(
			'section_title'	=> 'Expert Team',
			'menutitle'		=> 'expert-team',
			'bgcolor' 		=> '',
			'bgimage'		=> '',
			'class'			=> '',
			'content'		=> '[ourteam show="4"]'
		),
		
		6 => array(
			'section_title'	=> 'Client Testimonials',
			'menutitle'		=> 'testimonials',
			'bgcolor' 		=> '',
			'bgimage'		=> get_template_directory_uri().'/images/testimonial.jpg',
			'class'			=> 'testimonials-home',
			'content'		=> '[testimonials]',
		),		
		
		7 => array(
			'section_title'	=> 'Featured Project',
			'menutitle'		=> '',
			'bgcolor' 		=> '#faf9f9',
			'bgimage'		=> '',
			'class'			=> 'product-section',
			'content'		=> '[products_main][ourproduct title="Graphics Design" image="'.get_template_directory_uri().'/images/product1.jpg" link="#"][ourproduct title="Multimedia Marketing" image="'.get_template_directory_uri().'/images/product2.jpg" link="#"][ourproduct title="Bulk Messaging" image="'.get_template_directory_uri().'/images/product3.jpg" link="#"][ourproduct title="Mobile Apps" image="'.get_template_directory_uri().'/images/product4.jpg" link="#" class="last"][/products_main]'
		),

		8 => array(
			'section_title'	=> 'Photo Gallery',
			'menutitle'		=> '',
			'bgcolor' 		=> '',
			'bgimage'		=> '',
			'class'			=> '',
			'content'		=> '[photogallery filter="true" show="8"]'
		),

		
	);

	// Typography Body
	$typography_body = array(
		'size' => '16px',
		'face' => 'Assistant',
		'style' => 'normal',
		'weight' => 'normal',
		'transform' => 'none',
		'color' => '#4c4c4c' );
		
	// Typography Logo
	$typography_logo = array(
		'size' => '36px',
		'face' => 'Roboto Condensed',
		'style' => 'normal',
		'weight' => '700',
		'transform' => 'uppercase',
		'color' => '#ffffff' );
	
	// Typography Logo Tag
	$typography_tagline = array(
		'size' => '13px',
		'face' => 'Roboto',
		'style' => 'normal',
		'weight' => '400',
		'transform' => 'none',
		'color' => '#e3e3e3' );
		
	// Typography Navigation
	$typography_navigation = array(
		'size' => '13px',
		'face' => 'Roboto',
		'style' => 'normal',
		'weight' => '700',
		'transform' => 'uppercase',
		'color' => '#ffffff' );

	// Typography Slider Title
	$typography_slidertitle = array(
		'size' => '40px',
		'face' => 'Roboto',
		'style' => 'normal',
		'weight' => '700',
		'transform' => 'capitalize',
		'color' => '#ffffff' );

	// Typography Slider Description
	$typography_sliderdesc = array(
		'size' => '14px',
		'face' => 'Roboto',
		'style' => 'normal',
		'weight' => '500',
		'transform' => 'capitalize',
		'color' => '#ffffff' );
		
	// Section Title
	$typography_sectiontitle = array(
		'size' => '26px',
		'face' => 'Roboto',
		'style' => 'normal',
		'weight' => '500',
		'transform' => 'uppercase',
		'color' => '#1f1f1f' );
		
	// Section Title
	$typography_footertitle = array(
		'size' => '20px',
		'face' => 'Roboto',
		'style' => 'normal',
		'weight' => '400',
		'transform' => 'uppercase',
		'color' => '#ffffff' );
		
	// Heading Title h1
	$typography_headingh1 = array(
		'size' => '32px',
		'face' => 'Roboto Condensed',
		'style' => 'normal',
		'weight' => '700',
		'transform' => 'none',
		'color' => '#242424' );
		
	// Heading Title h2
	$typography_headingh2 = array(
		'size' => '28px',
		'face' => 'Roboto Condensed',
		'style' => 'normal',
		'weight' => '700',
		'transform' => 'none',
		'color' => '#242424' );
		
	// Heading Title h3
	$typography_headingh3 = array(
		'size' => '20px',
		'face' => 'Roboto',
		'style' => 'normal',
		'weight' => '400',
		'transform' => 'none',
		'color' => '#242424' );

	// Heading Title h4
	$typography_headingh4 = array(
		'size' => '17px',
		'face' => 'Roboto',
		'style' => 'normal',
		'weight' => '500',
		'transform' => 'uppercase',
		'color' => '#3b3b3b' );
		
	// Heading Title h5
	$typography_headingh5 = array(
		'size' => '16px',
		'face' => 'Roboto',
		'style' => 'normal',
		'weight' => '500',
		'transform' => 'none',
		'color' => '#010101' );
		
	// Heading Title h6
	$typography_headingh6 = array(
		'size' => '14px',
		'face' => 'Roboto',
		'style' => 'normal',
		'weight' => '500',
		'transform' => 'uppercase',
		'color' => '#26bdef' );


	//Basic Settings
	$options[] = array(
		'name' => __('Basic Settings', 'pulsing'),
		'type' => 'heading');

	$options[] = array(
		'name' => __('Logo', 'pulsing'),
		'desc' => __('Upload your main logo here', 'pulsing'),
		'id' => 'logo',
		'std'	=> '',
		'type' => 'upload');
		
	$options[] = array(	
		'name' => __('Site title & Description', 'pulsing'),		
		'desc'	=> __('check to hide site title and description', 'pulsing'),
		'id'	=> 'hide_titledesc',
		'type'	=> 'checkbox',
		'std'	=> '');			

	$options[] = array(
		'name' => __('Logo Height', 'pulsing'),
		'desc' => __('If your logo is large, you can reduce this number to allow for more height.', 'pulsing'),
		'id' => 'logoheight',
		'std' => '50',
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Sticky Header', 'pulsing'),
		'desc' => __('Check this to hide sticky header on scroll', 'pulsing'),
		'id' => 'headstick',
		'std' => '',
		'type' => 'checkbox');	
		
	$options[] = array(
		'name' => __('Hide Animation', 'pulsing'),
		'desc' => __('Check to hide animation on scroll', 'pulsing'),
		'id' => 'scrollanimation',
		'std' => '',
		'type' => 'checkbox');		
		
	$options[] = array(
		'name' => __('Excerpt Length ( increase this number to allow for more content)', 'pulsing'),
		'desc' => __('change excerpt length for the homepage latest posts.', 'pulsing'),
		'id' => 'newscontentlength',
		'std' => '15',
		'type' => 'text');

	$options[] = array(
		'desc' => __('Blog post page change text content lenth here ', 'pulsing'),
		'id' => 'blogpostpagecontent',
		'std' => '80',
		'type' => 'text');	
		
	$options[] = array(
		'desc' => __('Change excerpt length for the footer posts', 'pulsing'),
		'id' => 'footerexcerptlength',
		'std' => '12',
		'type' => 'text');				

	$options[] = array(
		'desc' => __('Change Read More button text for homepage latest posts.', 'pulsing'),
		'id' => 'homereadmoretext',
		'std' => 'Read More',
		'type' => 'text');	
		
	$options[] = array(
		'desc' => __('Change Read More button text for blog templates.', 'pulsing'),
		'id' => 'blogtemplatereadmoretext',
		'std' => 'Read More',
		'type' => 'text');	
		
	$options[] = array(
		'desc' => __('Change Read More button text for our professionals boxes', 'pulsing'),
		'id' => 'teamreadmoretext',
		'std' => 'Read More',
		'type' => 'text');	
		
	$options[] = array(
		'desc' => __('Change Read More button text for footer recent posts', 'pulsing'),
		'id' => 'footerpostreadmoretext',
		'std' => 'Read More',
		'type' => 'text');
		
	$options[] = array(
		'desc' => __('Change Show all  button text for our gallery', 'pulsing'),
		'id' => 'galleryshowall',
		'std' => 'Show All',
		'type' => 'text');						

	$options[] = array(
		'name' => __('Custom CSS', 'pulsing'),
		'desc' => __('Some Custom Styling for your site. Place any css codes here instead of the style.css file.', 'pulsing'),
		'id' => 'style2',
		'std' => '',
		'type' => 'textarea');

// Body Typography	
	$options[] = array(
		'name' => __('Body Typography', 'pulsing'),
		'desc' => __('Change font size/family/style/weight/transform/color for body text', 'pulsing'),
		'id' => 'bodyfontface',
		'std'	=> $typography_body,
		'type' => 'typography');

	$options[] = array(
		'desc'	=> __('Select backgound color for Body','pulsing'),
		'id' 	=> 'bodybgcolor',
		'std'   => '#ffffff',
		'type'	=> 'color');
		
// Logo Typography	
	$options[] = array(
		'name' => __('Textual Logo Typography', 'pulsing'),
		'desc' => __('Change font size/family/style/weight/transform/color for logo text', 'pulsing'),
		'id' => 'logotype',
		'std'	=> $typography_logo,
		'type' => 'typography');

// Logo Tag Typography	
	$options[] = array(
		'name' => __('Textual Logo Tag Typography', 'pulsing'),
		'desc' => __('Change font size/family/style/weight/transform/color for logo tag text', 'pulsing'),
		'id' => 'tagtype',
		'std'	=> $typography_tagline,
		'type' => 'typography');

// Color Scheme
	$options[] = array(	
		'name' => __('Color Scheme', 'pulsing'),	
		'desc' => __('Manage Color Scheme', 'pulsing'),
		'id' => 'colorscheme',
		'std' => '#26bdef',
		'type' => 'color');

// header Appointment
	$options[] = array(	
		'name' => __('Header background and color', 'pulsing'),	
		'desc' => __('Select header background color', 'pulsing'),
		'id' => 'headerbgcolor',
		'std' => '#000000',
		'type' => 'color');

	$options[] = array(		
		'desc' => __('Select opacity background for Header', 'pulsing'),
		'id' => 'headerbgopacity',
		'std' => '0.8',
		'type' => 'select',
		'options'	=> array('1'=>1, '0.9'=>0.9,'0.8'=>0.8,'0.7'=>0.7,'0.6'=>0.6,'0.5'=>0.5,'0.4'=>0.4,'0.3'=>0.3,'0.2'=>0.2,'0.1'=>0.1,'0'=>0,));		
		

	$options[] = array(	
		'desc' => __('Select Headaer Right Round Button', 'pulsing'),
		'id' => 'headerbtncolor',
		'std' => '#ffffff',
		'type' => 'color');

	$options[] = array(	
		'desc' => __('Select Menu Round Button background color', 'pulsing'),
		'id' => 'headerbtnbgcolor',
		'std' => '#26bdef',
		'type' => 'color');

// Header Navigation
	$options[] = array(
		'name' => __('Navigation Typography', 'pulsing'),
		'desc' => __('Change font size/family/style/weight/transform/color for navigation', 'pulsing'),
		'id' => 'navtype',
		'std'	=> $typography_navigation,
		'type' => 'typography');
	
	$options[] = array(	
		'desc' => __('Select color hover/active color for header navigation', 'pulsing'),
		'id' => 'navhovercolor',
		'std' => '#26bdef',
		'type' => 'color');
	$options[] = array(
		'desc' => __('Select color for toggle menu', 'pulsing'),
		'id' => 'togglemenucolor',
		'std' => '#ffffff',
		'type' => 'color');	
	$options[] = array(
		'desc' => __('Select Dropdown Color for navigation', 'pulsing'),
		'id' => 'tgmenuresponsivecolor',
		'std' => '#222222',
		'type' => 'color');	
	$options[] = array(
		'desc' => __('Select background color for toggle menu on responsive view', 'pulsing'),
		'id' => 'tgmenuresponsivebg',
		'std' => '#ffffff',
		'type' => 'color');	

	$options[] = array(	
		'desc' => __('Select toggle background for responsive', 'pulsing'),
		'id' => 'togglebgcolor',
		'std' => '#26bdef',
		'type' => 'color');

// Slider Title Typography	
	$options[] = array(
		'name' => __('Slider Title Typography', 'pulsing'),
		'desc' => __('Change font size/family/style/weight/transform/color for slider title', 'pulsing'),
		'id' => 'slidertitletype',
		'std'	=> $typography_slidertitle,
		'type' => 'typography');

// Slider Description Typography	
	$options[] = array(
		'name' => __('Slider Description Typography', 'pulsing'),
		'desc' => __('Change font size/family/style/weight/transform/color for logo tag text', 'pulsing'),
		'id' => 'sliderdesctype',
		'std'	=> $typography_sliderdesc,
		'type' => 'typography');
	$options[] = array(	
		'desc' => __('Select color for Slider Read More', 'pulsing'),
		'id' => 'sliderbutcolor',
		'std' => '#ffffff',
		'type' => 'color');
	$options[] = array(	
		'desc' => __('Select background color for Slider Read More', 'pulsing'),
		'id' => 'sliderbutbgcolor',
		'std' => '#26bdef',
		'type' => 'color');
	$options[] = array(	
		'desc' => __('Select background hover color for Slider Read More', 'pulsing'),
		'id' => 'sliderbutbghvcolor',
		'std' => '#26bdef',
		'type' => 'color');
	$options[] = array(	
		'desc' => __('Select hover color for Slider Read More', 'pulsing'),
		'id' => 'sliderbuthvcolor',
		'std' => '#ffffff',
		'type' => 'color');

// Slider controls colors		
	$options[] = array(
		'name' => __('Slider Control Colors ', 'pulsing'),
		'desc' => __('Select background color for slider navigation', 'pulsing'),
		'id' => 'sldnavbg',
		'std' => '#000000',
		'type' => 'color');
	$options[] = array(
		'desc' => __('Select background color for slider navigation hover', 'pulsing'),
		'id' => 'sldnavhvbg',
		'std' => '#ffffff',
		'type' => 'color');
	$options[] = array(
		'desc' => __('Select background color for slider pager', 'pulsing'),
		'id' => 'sldpagebg',
		'std' => '#ffffff',
		'type' => 'color');
	$options[] = array(
		'desc' => __('Select background color for slider pager active', 'pulsing'),
		'id' => 'sldpagehvbg',
		'std' => '#26bdef',
		'type' => 'color');	

// Section Title Typography	
	$options[] = array(
		'name' => __('Section title Typography', 'pulsing'),
		'desc' => __('Change font size/family/style/weight/transform/color for Section title', 'pulsing'),
		'id' => 'sectiontitletype',
		'std'	=> $typography_sectiontitle,
		'type' => 'typography');

// Section Title border color	
	$options[] = array(
		'desc' => __('Section title Border Color', 'pulsing'),
		'id' => 'sectiontitlebrcl',
		'std'	=> '#ededed',
		'type' => 'color');

	$options[] = array(
		'desc' => __('Select text color Our Advatages Boxes', 'pulsing'),
		'id' => 'textcoloradvantage',
		'std' => '#000000',
		'type' => 'color');		

	$options[] = array(
		'desc' => __('Select hover background color Our Advatages Boxes', 'pulsing'),
		'id' => 'hvrbgcoloradvantage',
		'std' => '#26bdef',
		'type' => 'color');		

	$options[] = array(
		'desc' => __('Select hover text color Our Advatages Boxes', 'pulsing'),
		'id' => 'hvrtextcoloradvantage',
		'std' => '#ffffff',
		'type' => 'color');		


// Latest News Section
	$options[] = array(
		'name' => __('Posts Background & color Setting ', 'pulsing'),		
		'desc' => __('Select background color latest post', 'pulsing'),
		'id' => 'bgcolorpost',
		'std' => '#ffffff',
		'type' => 'color');		

	$options[] = array(
		'desc' => __('Select color latest post', 'pulsing'),
		'id' => 'txtcolorpost',
		'std' => '#000000',
		'type' => 'color');		

	$options[] = array(
		'desc' => __('Select border color for all posts section', 'pulsing'),
		'id' => 'bordercolorpost',
		'std' => '#efeeee',
		'type' => 'color');		

// Testimonial setting
	$options[] = array(
		'name' => __('Select color setting for Testimonial', 'pulsing'),		
		'desc' => __('Select color Testimonial content', 'pulsing'),
		'id' => 'testimonialcolor',
		'std' => '#ffffff',
		'type' => 'color');		

	$options[] = array(
		'desc' => __('Select background color Testimonial content', 'pulsing'),
		'id' => 'testimonialbgcolor',
		'std' => '#000000',
		'type' => 'color');		

	$options[] = array(		
		'desc' => __('Select opacity background for Testimonial', 'pulsing'),
		'id' => 'testimonialbgop',
		'std' => '0.2',
		'type' => 'select',
		'options'	=> array('1'=>1, '0.9'=>0.9,'0.8'=>0.8,'0.7'=>0.7,'0.6'=>0.6,'0.5'=>0.5,'0.4'=>0.4,'0.3'=>0.3,'0.2'=>0.2,));		

	$options[] = array(
		'desc' => __('Select testimonial Client Name color', 'pulsing'),
		'id' => 'testimonialh5color',
		'std' => '#3a3a3a',
		'type' => 'color');		

	$options[] = array(
		'desc' => __('Select testimonial Client Designation color', 'pulsing'),
		'id' => 'testimonialh6color',
		'std' => '#ffffff',
		'type' => 'color');	
		
	$options[] = array(
		'desc' => __('Select testimonial border color', 'pulsing'),
		'id' => 'testimonialbordercl',
		'std' => '#ffffff',
		'type' => 'color');		

	$options[] = array(
		'desc' => __('Select testimonial page active color', 'pulsing'),
		'id' => 'testimonialpageractive',
		'std' => '#3a3a3a',
		'type' => 'color');		

	$options[] = array(
		'desc' => __('Select testimonial speed', 'pulsing'),
		'id' => 'testimonialspped',
		'std' => '500',
		'type' => 'text');		

	$options[] = array(
		'desc' => __('Select auto on/off for testimonial','pulsing'),
		'id' => 'autoplaytestimonial',
		'std' => 'true',
		'type' => 'select',
		'options' => array('true'=>'Autoplay', 'false'=>'Autoplay Off'));

// Our Team Social Icon
	$options[] = array(
		'name' => __('Our Professional Background and Color setting', 'pulsing'),		
		'desc' => __('Select background color for professinal boxes', 'pulsing'),
		'id' => 'teamboxbgcolor',
		'std' => '#ffffff',
		'type' => 'color');		

	$options[] = array(
		'desc' => __('Select background hover color bottom content', 'pulsing'),
		'id' => 'teamcontentbgcolor',
		'std' => '#26bdef',
		'type' => 'color');		

	$options[] = array(
		'desc' => __('Select text color for Prefessional content', 'pulsing'),
		'id' => 'teamcontenttextcolor',
		'std' => '#ffffff',
		'type' => 'color');		

	$options[] = array(
		'desc' => __('Select background color for Professional button', 'pulsing'),
		'id' => 'teamcontentbgbtncolor',
		'std' => '#ffffff',
		'type' => 'color');		

	$options[] = array(
		'desc' => __('Select color for Professional button', 'pulsing'),
		'id' => 'teamcontenttextbtncolor',
		'std' => '#3e3e3e',
		'type' => 'color');		

//Gallery			
	$options[] = array(
		'name' => __('Gallery background & color setting', 'pulsing'),
		'desc' => __('Select navigation color', 'pulsing'),
		'id' => 'gallerynavigationcolor',
		'std' => '#000000',
		'type' => 'color');	
	$options[] = array(
		'desc' => __('Select navigation active color', 'pulsing'),
		'id' => 'gallerynavtxtcolor',
		'std' => '#26bdef',
		'type' => 'color');	

	$options[] = array(
		'desc' => __('Select background color for gallery image', 'pulsing'),
		'id' => 'gallerybgcolor',
		'std' => '#26bdef',
		'type' => 'color');	

	// All anchor tag link/hover 
	$options[] = array(	
		'name' => __('Site All Anchor tag link/hover Colors', 'pulsing'),	
		'desc' => __('Select color for site anchar tag link', 'pulsing'),
		'id' => 'anchortagcolor',
		'std' => '#26bdef',
		'type' => 'color');
	$options[] = array(	
		'desc' => __('Select color for site anchor tah link hover', 'pulsing'),
		'id' => 'anchortagcolorhover',
		'std' => '#313131',
		'type' => 'color');


	// Default Buttons		
	$options[] = array(
		'name' => __('Read More Button Colors', 'pulsing'),		
		'desc' => __('Select background color for button', 'pulsing'),
		'id' => 'btnbgcolor',
		'std' => '#26bdef',
		'type' => 'color');
	$options[] = array(
		'desc' => __('Select hover background color for button', 'pulsing'),
		'id' => 'btnbghvcolor',
		'std' => '#383737',
		'type' => 'color');		
	$options[] = array(
		'desc' => __('Select font color button', 'pulsing'),
		'id' => 'btntxtcolor',
		'std' => '#ffffff',
		'type' => 'color');
	$options[] = array(
		'desc' => __('Select font color button on hover', 'pulsing'),
		'id' => 'btntxthvcolor',
		'std' => '#ffffff',
		'type' => 'color');	

// Default Social Icon
	$options[] = array(
		'name' => __('Social icon color setting', 'pulsing'),
		'desc' => __('Select color for social icon', 'pulsing'),
		'id' => 'socialfontcolor',
		'std' => '#ffffff',
		'type' => 'color');		
	$options[] = array(
		'desc' => __('Select background color for social icon', 'pulsing'),
		'id' => 'socialbgcolor',
		'std' => '#666666',
		'type' => 'color');		
	$options[] = array(
		'desc' => __('Select background hover color for social icon', 'pulsing'),
		'id' => 'socialfonthvcolor',
		'std' => '#ffffff',
		'type' => 'color');				
	$options[] = array(
		'desc' => __('Select background hover color for social icon', 'pulsing'),
		'id' => 'socialbghvcolor',
		'std' => '#26bdef',
		'type' => 'color');				
	
// Footer Settings
 	$options[] = array(
		'name' => __('Footer title Typography', 'pulsing'),
		'desc' => __('Change font size/family/style/weight/transform/color for Section title', 'pulsing'),
		'id' => 'footertitletype',
		'std'	=> $typography_footertitle,
		'type' => 'typography');

	$options[] = array(	
		'name' => __('Background color for footer and copyright', 'pulsing'),	
		'desc' => __('Select background color for footer', 'pulsing'),
		'id' => 'footerwpbgcolor',
		'std' => '#1c1c1c',
		'type' => 'color');
		
	$options[] = array(	
		'desc' => __('Select color for footer', 'pulsing'),
		'id' => 'footerwpcolor',
		'std' => '#ffffff',
		'type' => 'color');
	$options[] = array(	
		'desc' => __('Select background color for copyright', 'pulsing'),
		'id' => 'copyrightbgcolor',
		'std' => '#151515',
		'type' => 'color');

	$options[] = array(	
		'desc' => __('Select border color for footer post image', 'pulsing'),
		'id' => 'footerpostimagebd',
		'std' => '#3b3b3b',
		'type' => 'color');

// Sidebar option
	$options[] = array(
		'name' => __('Sidebar for background/border color', 'pulsing'),	
		'desc' => __('Select background color for sidebar widget title', 'pulsing'),
		'id' => 'widgettitlebgcolor',
		'std' => '#26bdef ',
		'type' => 'color');	
	
	$options[] = array(
		'desc' => __('Select color for sidebar title ', 'pulsing'),
		'id' => 'widgettitlecolor',
		'std' => '#ffffff',
		'type' => 'color');	
			
	$options[] = array(
		'desc' => __('Select background color for sidebar widget', 'pulsing'),
		'id' => 'sidebarbgcolor',
		'std' => '#f5f5f5',
		'type' => 'color');	
				
	$options[] = array(			
		'desc' => __('Select border color for sidebar li a', 'pulsing'),
		'id' => 'sidebarliaborder',
		'std' => '#d0cfcf',
		'type' => 'color');		

	$options[] = array(
		'desc' => __('Select background color for search form', 'pulsing'),
		'id' => 'searchbgcolor',
		'std' => '#ece8e8',
		'type' => 'color');	

// Input field color setting
	$options[] = array(
		'name' => __('Select All Input field background & text color', 'pulsing'),
		'desc' => __('Select background color for input field and textarea', 'pulsing'),
		'id' => 'inputbgcolor',
		'std' => '#ffffff',
		'type' => 'color');	
	$options[] = array(
		'desc' => __('Select color for input field and textarea', 'pulsing'),
		'id' => 'inputtextbgcolor',
		'std' => '#cacaca',
		'type' => 'color');	
	$options[] = array(
		'desc' => __('Select border color for input field and textarea', 'pulsing'),
		'id' => 'inputbrcolor',
		'std' => '#dbdbdb',
		'type' => 'color');	

	$options[] = array(
		'name' => __('Select iframe Color', 'pulsing'),
		'desc' => __('Select border color for iframe', 'pulsing'),
		'id' => 'ifrmabrcolor',
		'std' => '#dbdbdb',
		'type' => 'color');	
		
// Site title heading Settings
 	$options[] = array(
		'name' => __('Heading Heading h1, h2, h3, h4, h5, h6 Typography', 'pulsing'),
		'desc' => __('Change Heading h1 tag font size/family/style/weight/transform/color for heading title', 'pulsing'),
		'id' => 'headingh1type',
		'std'	=> $typography_headingh1,
		'type' => 'typography');
		
	$options[] = array(
		'desc' => __('Change Heading h2 tag font size/family/style/weight/transform/color for heading title', 'pulsing'),
		'id' => 'headingh2type',
		'std'	=> $typography_headingh2,
		'type' => 'typography');
		
	$options[] = array(
		'desc' => __('Change Heading h3 tag font size/family/style/weight/transform/color for heading title', 'pulsing'),
		'id' => 'headingh3type',
		'std'	=> $typography_headingh3,
		'type' => 'typography');

	$options[] = array(
		'desc' => __('Change Heading h4 tag font size/family/style/weight/transform/color for heading title', 'pulsing'),
		'id' => 'headingh4type',
		'std'	=> $typography_headingh4,
		'type' => 'typography');

	$options[] = array(
		'desc' => __('Change Heading h5 tag font size/family/style/weight/transform/color for heading title', 'pulsing'),
		'id' => 'headingh5type',
		'std'	=> $typography_headingh5,
		'type' => 'typography');

	$options[] = array(
		'desc' => __('Change Heading h6 tag font size/family/style/weight/transform/color for heading title', 'pulsing'),
		'id' => 'headingh6type',
		'std'	=> $typography_headingh6,
		'type' => 'typography');
		
	$options[] = array(
		'name' => __('Blog Single Layout', 'pulsing'),
		'desc' => __('Select layout. eg:Boxed, Wide', 'pulsing'),
		'id' => 'singlelayout',
		'type' => 'select',
		'std' => 'singleright',
		'options' => array('singleright'=>'Blog Single Right Sidebar', 'singleleft'=>'Blog Single Left Sidebar', 'sitefull'=>'Blog Single Full Width', 'nosidebar'=>'Blog Single No Sidebar') );
		
	$options[] = array(
		'name' => __('Woocommerce Page Layout', 'pulsing'),
		'desc' => __('Select layout. eg:Boxed, Wide', 'pulsing'),
		'id' => 'woocomercelayout',
		'type' => 'select',
		'std' => 'woocomerceright',
		'options' => array('woocomerceright'=>'Woocomerce Right Sidebar', 'woocomerceleft'=>'Woocomerce Left Sidebar', 'woocomercesitefull'=>'Woocomerce Full Width') );			
		
	$options[] = array(			
		'name' => __('Woocommerce Price filter color setting', 'pulsing'),
		'desc' => __('Select color for Price slider background', 'pulsing'),
		'id' => 'pricesliderbg',
		'std' => '#cccccc',
		'type' => 'color');	

	$options[] = array(			
		'desc' => __('Select color for Price slider handle background', 'pulsing'),
		'id' => 'pricehandlebg',
		'std' => '#26bdef',
		'type' => 'color');	

	$options[] = array(			
		'desc' => __('Select color for Price slider Range background', 'pulsing'),
		'id' => 'pricerangebg',
		'std' => '#515151',
		'type' => 'color');


	//Layout Settings
	$options[] = array(
		'name' => __('Sections', 'pulsing'),
		'type' => 'heading');
		
	$options[] = array(
		'name' => __('Welcome to Website Section', 'pulsing'),
		'desc'	=> __('select page for welcome section','pulsing'),
		'id' 	=> 'welcomebox',
		'type'	=> 'select',
		'options' => $options_pages,
	);
		
	$options[] = array(		
		'desc' => __('Select excerpt length for welcome page section', 'pulsing'),
		'id' => 'welcomepagelength',
		'std' => '125',
		'type' => 'text');
		
	$options[] = array(			
			'desc'	=> __('Check to hide welcome section', 'pulsing'),
			'id'	=> 'hidewelcomesection',
			'type'	=> 'checkbox',
			'std'	=> '');	

		
	$options[] = array(
		'name' => __('Services Section Title','pulsing'),
		'desc'	=> __('Select title for topsection','pulsing'),
		'id' 	=> 'pageservicestitle',
		'std' 	=> 'Our Services',
		'type'	=> 'text',
	);

	$options[] = array(
		'name' => __('Services Boxes','pulsing'),
		'desc'	=> __('Service box 1','pulsing'),
		'id' 	=> 'box1',
		'type'	=> 'select',
		'options' => $options_pages,
	);

	$options[] = array(
		'desc' => __('Upload Image here for services box with image size (130px/130px)', 'pulsing'),
		'id' => 'boximage1',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(	
		'desc'	=> __('Service box 2','pulsing'),
		'id' 	=> 'box2',
		'type'	=> 'select',
		'options' => $options_pages,
	);

	$options[] = array(
		'desc' => __('Upload Image here for services box with image size (130px/130px)', 'pulsing'),
		'id' => 'boximage2',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(	
		'desc'	=> __('Service box 3','pulsing'),
		'id' 	=> 'box3',
		'type'	=> 'select',
		'options' => $options_pages,
	);	
	
	$options[] = array(
		'desc' => __('Upload Image here for services box with image size (130px/130px)', 'pulsing'),
		'id' => 'boximage3',
		'std' => '',
		'type' => 'upload');
	
	$options[] = array(	
		'desc'	=> __('Service box 4','pulsing'),
		'id' 	=> 'box4',
		'type'	=> 'select',
		'options' => $options_pages,
	);	

	$options[] = array(
		'desc' => __('Upload Image here for Our Services box with image size(130px/130px)', 'pulsing'),
		'id' => 'boximage4',
		'std' => '',
		'type' => 'upload');

	$options[] = array(	
		'desc'	=> __('Service box 5','pulsing'),
		'id' 	=> 'box5',
		'type'	=> 'select',
		'options' => $options_pages,
	);	

	$options[] = array(
		'desc' => __('Upload Image here for services box with image size (130px/130px)', 'pulsing'),
		'id' => 'boximage5',
		'std' => '',
		'type' => 'upload');

	$options[] = array(	
		'desc'	=> __('Service box 6','pulsing'),
		'id' 	=> 'box6',
		'type'	=> 'select',
		'options' => $options_pages,
	);	

	$options[] = array(
		'desc' => __('Upload Image here for Our Services box with image size (130px/130px)', 'pulsing'),
		'id' => 'boximage6',
		'std' => '',
		'type' => 'upload');
	
	$options[] = array(
		'name' => __('Services content lenght','pulsing'),
		'desc'	=> __('Change content lenght for services pages','pulsing'),
		'id' 	=> 'servicescontentlenght',
		'std' 	=> '15',
		'type'	=> 'text',
	);

	$options[] = array(
		'desc'	=> __('Select button text for services pages','pulsing'),
		'id' 	=> 'servicesbtntxt',
		'std' 	=> 'Read More',
		'type'	=> 'text',
	);
	
	$options[] = array(			
			'desc'	=> __('Check to hide four column services section', 'pulsing'),
			'id'	=> 'hidefourcolservicessec',
			'type'	=> 'checkbox',
			'std'	=> '');	

	$options[] = array(
		'name' => __('Number of Sections', 'pulsing'),
		'desc' => __('Select number of sections', 'pulsing'),
		'id' => 'numsection',
		'type' => 'select',
		'std' => '8',
		'options' => array_combine(range(1,30), range(1,30)) );
	$numsecs = of_get_option( 'numsection', 8 );


	for( $n=1; $n<=$numsecs; $n++){
		$options[] = array(
			'desc' => __("<h3>Section ".$n."</h3>", 'pulsing'),
			'class' => 'toggle_title',
			'type' => 'info');	
	
		$options[] = array(
			'name' => __('Section Title', 'pulsing'),
			'id' => 'sectiontitle'.$n,
			'std' => ( ( isset($section_text[$n]['section_title']) ) ? $section_text[$n]['section_title'] : '' ),
			'type' => 'text');

		$options[] = array(
			'name' => __('Section ID', 'pulsing'),
			'desc'	=> __('Enter your section ID here. SECTION ID MUST BE IN SMALL LETTERS ONLY AND DO NOT ADD SPACE OR SYMBOL.'),
			'id' => 'menutitle'.$n,
			'std' => ( ( isset($section_text[$n]['menutitle']) ) ? $section_text[$n]['menutitle'] : '' ),
			'type' => 'text');

		$options[] = array(
			'name' => __('Section Background Color', 'pulsing'),
			'desc' => __('Select background color for section', 'pulsing'),
			'id' => 'sectionbgcolor'.$n,
			'std' => ( ( isset($section_text[$n]['bgcolor']) ) ? $section_text[$n]['bgcolor'] : '' ),
			'type' => 'color');
			
		$options[] = array(
			'name' => __('Background Image', 'pulsing'),
			'id' => 'sectionbgimage'.$n,
			'class' => '',
			'std' => ( ( isset($section_text[$n]['bgimage']) ) ? $section_text[$n]['bgimage'] : '' ),
			'type' => 'upload');

		$options[] = array(
			'name' => __('Section CSS Class', 'pulsing'),
			'desc' => __('Set class for this section.', 'pulsing'),
			'id' => 'sectionclass'.$n,
			'std' => ( ( isset($section_text[$n]['class']) ) ? $section_text[$n]['class'] : '' ),
			'type' => 'text');
			
		$options[] = array(
			'name'	=> __('Hide Section', 'pulsing'),
			'desc'	=> __('Check to hide this section', 'pulsing'),
			'id'	=> 'hidesec'.$n,
			'type'	=> 'checkbox',
			'std'	=> '');

		$options[] = array(
			'name' => __('Section Content', 'pulsing'),
			'id' => 'sectioncontent'.$n,
			'std' => ( ( isset($section_text[$n]['content']) ) ? $section_text[$n]['content'] : '' ),
			'type' => 'editor');
	}

	//SLIDER SETTINGS
	$options[] = array(
		'name' => __('Homepage Slider', 'pulsing'),
		'type' => 'heading');
		
	$options[] = array(
		'name' => __('Inner Page Banner', 'pulsing'),
		'desc' => __('Upload inner page banner for site', 'pulsing'),
		'id' => 'innerpagebanner',
		'class' => '',
		'std'	=> get_template_directory_uri()."/images/default-banner.jpg",
		'type' => 'upload');	
		
	$options[] = array(
		'name' => __('Slider Effects and Timing', 'pulsing'),
		'desc' => __('Select slider effect.','pulsing'),
		'id' => 'slideefect',
		'std' => 'fade',
		'type' => 'select',
		'options' => array('random'=>'Random', 'fade'=>'Fade', 'fold'=>'Fold', 'sliceDown'=>'Slide Down', 'sliceDownLeft'=>'Slide Down Left', 'sliceUp'=>'Slice Up', 'sliceUpLeft'=>'Slice Up Left', 'sliceUpDown'=>'Slice Up Down', 'sliceUpDownLeft'=>'Slice Up Down Left', 'slideInRight'=>'SlideIn Right', 'slideInLeft'=>'SlideIn Left', 'boxRandom'=>'Box Random', 'boxRain'=>'Box Rain', 'boxRainReverse'=>'Box Rain Reverse', 'boxRainGrow'=>'Box Rain Grow', 'boxRainGrowReverse'=>'Box Rain Grow Reverse' ));
		
	$options[] = array(
		'desc' => __('Animation speed should be multiple of 100.', 'pulsing'),
		'id' => 'slideanim',
		'std' => 500,
		'type' => 'text');
		
	$options[] = array(
		'desc' => __('Add slide pause time.', 'pulsing'),
		'id' => 'slidepause',
		'std' => 4000,
		'type' => 'text');
		
	$options[] = array(
		'name' => __('Slide Controllers', 'pulsing'),
		'desc' => __('Hide/Show Direction Naviagtion of slider.','pulsing'),
		'id' => 'slidenav',
		'std' => 'true',
		'type' => 'select',
		'options' => array('true'=>'Show', 'false'=>'Hide'));
		
	$options[] = array(
		'desc' => __('Hide/Show pager of slider.','pulsing'),
		'id' => 'slidepage',
		'std' => 'true',
		'type' => 'select',
		'options' => array('true'=>'Show', 'false'=>'Hide'));
		
	$options[] = array(
		'desc' => __('Pause Slide on Hover.','pulsing'),
		'id' => 'slidepausehover',
		'std' => 'false',
		'type' => 'select',
		'options' => array('true'=>'Yes', 'false'=>'No'));
		
		
	$options[] = array(
		'name' => __('Use any slider shortcode', 'pulsing'),
		'desc' => __('you add any slider plugin shortcode here', 'pulsing'),
		'id' => 'slidershortcode',
		'std' => '',
		'type' => 'textarea');
		
		
	$options[] = array(
		'name' => __('Slider Image 1', 'pulsing'),
		'desc' => __('First Slide', 'pulsing'),
		'id' => 'slide1',
		'class' => '',
		'std' => get_template_directory_uri()."/images/slides/slider1.jpg",
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 1', 'pulsing'),
		'id' => 'slidetitle1',
		'std' => 'Pulsing WordPress Theme',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'pulsing'),
		'id' => 'slidedesc1',
		'std' => 'Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industry when an unknown printer took a galley of type and scrambled it to make a',
		'type' => 'textarea');

	$options[] = array(
		'desc' => __('Slide Button Text', 'pulsing'),
		'id' => 'slidebutton1',
		'std' => 'Read More',
		'type' => 'text');		
	
	$options[] = array(
		'desc' => __('Slide Button Url', 'pulsing'),
		'id' => 'slideurl1',
		'std' => '#',
		'type' => 'text');		
	
	$options[] = array(
		'name' => __('Slider Image 2', 'pulsing'),
		'desc' => __('Second Slide', 'pulsing'),
		'class' => '',
		'id' => 'slide2',
		'std' => get_template_directory_uri()."/images/slides/slider2.jpg",
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 2', 'pulsing'),
		'id' => 'slidetitle2',
		'std' => 'Business WordPress Theme',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'pulsing'),
		'id' => 'slidedesc2',
		'std' => 'It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout. The point of using Lorem Ipsum is that it has a more-or-less normal.',
		'type' => 'textarea');	
		
	$options[] = array(
		'desc' => __('Slide Button Text', 'pulsing'),
		'id' => 'slidebutton2',
		'std' => 'Read More',
		'type' => 'text');		
	
	$options[] = array(
		'desc' => __('Slide Button Url', 'pulsing'),
		'id' => 'slideurl2',
		'std' => '#',
		'type' => 'text');		
	
	$options[] = array(
		'name' => __('Slider Image 3', 'pulsing'),
		'desc' => __('Third Slide', 'pulsing'),
		'id' => 'slide3',
		'class' => '',
		'std' => get_template_directory_uri()."/images/slides/slider3.jpg",
		'type' => 'upload');
		
$options[] = array(
		'desc' => __('Title 3', 'pulsing'),
		'id' => 'slidetitle3',
		'std' => 'Corporate WordPress Theme',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'pulsing'),
		'id' => 'slidedesc3',
		'std' => 'It has survived not only five centuries, but also the leap into electronic typesetting, remaining essentially unchanged. and more recently with desktop publishing software.',
		'type' => 'textarea');	
	$options[] = array(
		'desc' => __('Slide Button Text', 'pulsing'),
		'id' => 'slidebutton3',
		'std' => 'Read More',
		'type' => 'text');		
	
	$options[] = array(
		'desc' => __('Slide Button Url', 'pulsing'),
		'id' => 'slideurl3',
		'std' => '#',
		'type' => 'text');		
			
	$options[] = array(
		'name' => __('Slider Image 4', 'pulsing'),
		'desc' => __('Fourth Slide', 'pulsing'),
		'id' => 'slide4',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 4', 'pulsing'),
		'id' => 'slidetitle4',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'pulsing'),
		'id' => 'slidedesc4',
		'std' => '',
		'type' => 'textarea');	
		
	$options[] = array(
		'desc' => __('Slide Button Text', 'pulsing'),
		'id' => 'slidebutton4',
		'std' => '',
		'type' => 'text');		
	
	$options[] = array(
		'desc' => __('Slide Button Url', 'pulsing'),
		'id' => 'slideurl4',
		'std' => '#',
		'type' => 'text');		
	
	$options[] = array(
		'name' => __('Slider Image 5', 'pulsing'),
		'desc' => __('Fifth Slide', 'pulsing'),
		'id' => 'slide5',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 5', 'pulsing'),
		'id' => 'slidetitle5',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'pulsing'),
		'id' => 'slidedesc5',
		'std' => '',
		'type' => 'textarea');	
		
	$options[] = array(
		'desc' => __('Slide Button Text', 'pulsing'),
		'id' => 'slidebutton5',
		'std' => '',
		'type' => 'text');		
	
	$options[] = array(
		'desc' => __('Slide Button Url', 'pulsing'),
		'id' => 'slideurl5',
		'std' => '#',
		'type' => 'text');	
		
	$options[] = array(
		'name' => __('Slider Image 6', 'pulsing'),
		'desc' => __('Sixth Slide', 'pulsing'),
		'id' => 'slide6',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 6', 'pulsing'),
		'id' => 'slidetitle6',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'pulsing'),
		'id' => 'slidedesc6',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Slide Button Text', 'pulsing'),
		'id' => 'slidebutton6',
		'std' => '',
		'type' => 'text');		
	
	$options[] = array(
		'desc' => __('Slide Button Url', 'pulsing'),
		'id' => 'slideurl6',
		'std' => '',
		'type' => 'text');	
		
	$options[] = array(
		'name' => __('Slider Image 7', 'pulsing'),
		'desc' => __('Seventh Slide', 'pulsing'),
		'id' => 'slide7',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 7', 'pulsing'),
		'id' => 'slidetitle7',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'pulsing'),
		'id' => 'slidedesc7',
		'std' => '',
		'type' => 'textarea');

	$options[] = array(
		'desc' => __('Slide Button Text', 'pulsing'),
		'id' => 'slidebutton7',
		'std' => '',
		'type' => 'text');		
	
	$options[] = array(
		'desc' => __('Slide Button Url', 'pulsing'),
		'id' => 'slideurl7',
		'std' => '',
		'type' => 'text');	
		
	$options[] = array(
		'name' => __('Slider Image 8', 'pulsing'),
		'desc' => __('Eighth Slide', 'pulsing'),
		'id' => 'slide8',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 8', 'pulsing'),
		'id' => 'slidetitle8',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'pulsing'),
		'id' => 'slidedesc8',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Slide Button Text', 'pulsing'),
		'id' => 'slidebutton8',
		'std' => '',
		'type' => 'text');		
	
	$options[] = array(
		'desc' => __('Slide Button Url', 'pulsing'),
		'id' => 'slideurl8',
		'std' => '',
		'type' => 'text');	
		
	$options[] = array(
		'name' => __('Slider Image 9', 'pulsing'),
		'desc' => __('Ninth Slide', 'pulsing'),
		'id' => 'slide9',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 9', 'pulsing'),
		'id' => 'slidetitle9',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'pulsing'),
		'id' => 'slidedesc9',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Slide Button Text', 'pulsing'),
		'id' => 'slidebutton9',
		'std' => '',
		'type' => 'text');		
	
	$options[] = array(
		'desc' => __('Slide Button Url', 'pulsing'),
		'id' => 'slideurl9',
		'std' => '',
		'type' => 'text');	
		
	$options[] = array(
		'name' => __('Slider Image 10', 'pulsing'),
		'desc' => __('Tenth Slide', 'pulsing'),
		'id' => 'slide10',
		'class' => '',
		'std' => '',
		'type' => 'upload');
		
	$options[] = array(
		'desc' => __('Title 10', 'pulsing'),
		'id' => 'slidetitle10',
		'std' => '',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Description or Tagline', 'pulsing'),
		'id' => 'slidedesc10',
		'std' => '',
		'type' => 'textarea');
	
	$options[] = array(
		'desc' => __('Slide Button Text', 'pulsing'),
		'id' => 'slidebutton10',
		'std' => '',
		'type' => 'text');		
	
	$options[] = array(
		'desc' => __('Slide Button Url', 'pulsing'),
		'id' => 'slideurl10',
		'std' => '',
		'type' => 'text');	
	
	//Header top right SETTINGS
	$options[] = array(
		'name' => __('Header', 'pulsing'),
		'type' => 'heading');

	$options[] = array(
		'name' => __('Header Mobile menu text', 'pulsing'),
		'desc' => __('Header header menu chenge text (Menu).', 'pulsing'),
		'id' => 'mobilemenuname',
		'std' => 'Menu',
		'type' => 'text');

	//Footer SETTINGS
	$options[] = array(
		'name' => __('Footer', 'pulsing'),
		'type' => 'heading');

	$options[] = array(
		'name' => __('Footer Layout', 'pulsing'),
		'desc' => __('footer Select layout. eg:Boxed, 1, 2, 3 and 4', 'pulsing'),
		'id' => 'footerlayout',
		'type' => 'select',
		'std' => 'fourcolumn',
		'options' => array('onecolumn'=>'Footer 1 column', 
		'twocolumn'=>'Footer 2 column', 'threecolumn'=>'Footer 3 column', 'fourcolumn'=>'Footer 4 column', ) );	
		
	$options[] = array(
		'name' => __('About US', 'pulsing'),
		'desc' => __('About Us text title for footer', 'pulsing'),
		'id' => 'footeraboutustitle',
		'std' => 'About Us',
		'type' => 'text');

	$options[] = array(
		'name' => __('Recent Post Title', 'pulsing'),
		'desc' => __('Recent post title for footer.', 'pulsing'),
		'id' => 'footerrcposttitle',
		'std' => 'Recent Post',
		'type' => 'text');	

	$options[] = array(
		'name' => __('Footer menu Title', 'pulsing'),
		'desc' => __('Footer menu title for footer.', 'pulsing'),
		'id' => 'footermenutitle',
		'std' => 'Footer Menu',
		'type' => 'text');	

	$options[] = array(
		'name' => __('Footer Contact Title', 'pulsing'),
		'desc' => __('Add contact title here', 'pulsing'),
		'id' => 'contacttitle',
		'std' => 'Contact Us',
		'type' => 'text');	

	$options[] = array(
		'name' => __('About Us', 'pulsing'),
		'desc' => __('About Us content for footer.', 'pulsing'),
		'id' => 'openinghoursefooter',
		'std' => '<p>Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Aenean commodo ligula eget dolor. Aenean massa fringilla vel, aliquet nec, vulputate eget, arcu.In enim justo. Lorem ipsum dolor sit amet, consectetuer adipiscing elit.</p> 
<p>Donec ut ex ac nulla sapien mauris, vitae sodales tellus suspendisse suscipit velit id ultricies auctor.</p>',
		'type' => 'textarea');	


	$options[] = array(	
		'name' => __('Footer Address', 'pulsing'),
		'desc' => __('Add company address1 here.', 'pulsing'),
		'id' => 'address',
		'std' => '1600 Amphitheatre Parkway ,',
		'type' => 'text');
		
	$options[] = array(	
		'desc' => __('Add company address2 here.', 'pulsing'),
		'id' => 'address2',
		'std' => 'Mountain View, CA 94043',
		'type' => 'text');	
		
	$options[] = array(		
		'desc' => __('Add phone number here.', 'pulsing'),
		'id' => 'phone',
		'std' => '+1 800 234 5678',
		'type' => 'text');
		
	$options[] = array(		
		'desc' => __('Add phone number 2 here.', 'pulsing'),
		'id' => 'phone2',
		'std' => '',
		'type' => 'text');

	$options[] = array(
		'desc' => __('Add email address here.', 'pulsing'),
		'id' => 'email',
		'std' => 'info@sitename.com',
		'type' => 'text');
		
	$options[] = array(
		'desc' => __('Add company url here with http://.', 'pulsing'),
		'id' => 'weblink',
		'std' => 'http://yourdomain.com',
		'type' => 'text');

	$options[] = array(
		'name' => __('Footer social Media'),
		'desc' => __('Add here footr social media.', 'pulsing'),
		'id' => 'footersocialmedia',
		'std' => '[social_area]
[social icon="facebook" link="#"]
[social icon="twitter" link="#"]
[social icon="linkedin" link="#"]
[social icon="google-plus" link="#"]
[social icon="pinterest-p" link="#"]
[/social_area]',
		'type' => 'textarea');
		
		$options[] = array(
		'name' => __('Google Map', 'pulsing'),
		'desc' => __('Use iframe code here for Contact Page Map', 'pulsing'),
		'id' => 'googlemap',
		'std' => '<iframe src="https://www.google.com/maps/embed?pb=!1m18!1m12!1m3!1d168033.52643408478!2d2.2170919015949493!3d48.84822036209216!2m3!1f0!2f0!3f0!3m2!1i1024!2i768!4f13.1!3m3!1m2!1s0x47e66e1f06e2b70f%3A0x40b82c3688c9460!2sParis%2C+France!5e0!3m2!1sen!2sin!4v1468286846072" width="100%" height="400" frameborder="0" allowfullscreen></iframe>',
		'type' => 'editor');
			
	$options[] = array(
		'name' => __('Footer Copyright', 'pulsing'),
		'desc' => __('Copyright Text for your site.', 'pulsing'),
		'id' => 'copytext',
		'std' => '&copy; 2019 <a href="#">Pulsing.</a> All Rights Reserved',
		'type' => 'textarea');
		
	$options[] = array(
		'desc' => __('Footre Text Link', 'pulsing'),
		'id' => 'ftlink',
		'std' => 'Design by Grace Themes - <a href="'.esc_url('https://gracethemes.com/themes/commercial-wordpress-theme/').'" target="_blank">Pulsing</a>',
		'type' => 'textarea',);
		
	$options[] = array(
		'desc' => __('Footer Back to Top Button', 'pulsing'),
		'id' => 'backtotop',
		'std' => '[back-to-top]',
		'type' => 'textarea',);	

	//Short codes
	$options[] = array(
		'name' => __('Short Codes', 'pulsing'),
		'type' => 'heading');	

	$options[] = array(
		'name' => __('Photo Gallery', 'pulsing'),
		'desc' => __('[photogallery filter="true"]', 'pulsing'),
		'type' => 'info');		
		
	$options[] = array(
		'name' => __('Testimonials', 'pulsing'),
		'desc' => __('[testimonials]', 'pulsing'),
		'type' => 'info');
		
	$options[] = array(
		'name' => __('All Testimonials Listing', 'pulsing'),
		'desc' => __('[all-testimonials show="10"]', 'pulsing'),
		'type' => 'info');	
		
	$options[] = array(
		'name' => __('Contact Form', 'pulsing'),
		'desc' => __('[contactform to_email="test@example.com" title="Contact Form"] 
', 'pulsing'),
		'type' => 'info');

	$options[] = array(
		'name' => __('latest from our blog', 'pulsing'),
		'desc' => __('[latestposts show="4"]', 'pulsing'),
		'type' => 'info');		

	$options[] = array(
		'name' => __('Footer posts', 'pulsing'),
		'desc' => __('[footer-posts show="2"]', 'pulsing'),
		'type' => 'info');	
		
	$options[] = array(
		'name' => __('Our Professional', 'pulsing'),
		'desc' => __('[ourteam show="4"]', 'pulsing'),
		'type' => 'info');					

	$options[] = array(
		'name' => __('Search Form', 'pulsing'),
		'desc' => __('[searchform] 
', 'pulsing'),
		'type' => 'info');
			
		
	$options[] = array(
		'name' => __('Headings', 'pulsing'),
		'desc' => __('[heading underline="yes" align="left"]Our Professional[/heading]', 'pulsing'),
		'type' => 'info');					

	$options[] = array(
		'name' => __('Read More Button', 'pulsing'),
		'desc' => __('[readmore-link align="left" button="Read More" links="#" target=""]', 'pulsing'),
		'type' => 'info');
		
	$options[] = array(
		'name' => __('Social Icons ( Note: More social icons can be found at: http://fortawesome.github.io/Font-Awesome/icons/)', 'pulsing'),
		'desc' => __('[social_area]
    [social icon="facebook" link="#"]
    [social icon="twitter" link="#"]
    [social icon="linkedin" link="#"]
    [social icon="pinterest" link="#"]
    [social icon="google-plus" link="#"]
	[social icon="youtube" link="#"]
	[social icon="wordpress" link="#"]
	[social icon="flickr" link="#"]
	[social icon="skype" link="#"]
[/social_area]', 'pulsing'),
		'type' => 'info');	
		
	return $options;
}